@@ -92,6 +92,7 @@ struct _ValaCCodeCommentPrivate {
 };
 
 
+static gpointer vala_ccode_comment_parent_class = NULL;
 
 gpointer vala_ccode_node_ref (gpointer instance);
 void vala_ccode_node_unref (gpointer instance);
@@ -113,11 +114,9 @@ enum  {
 void vala_ccode_comment_set_text (ValaCCodeComment* self, const char* value);
 ValaCCodeComment* vala_ccode_comment_new (const char* _text);
 ValaCCodeComment* vala_ccode_comment_construct (GType object_type, const char* _text);
-ValaCCodeComment* vala_ccode_comment_new (const char* _text);
 void vala_ccode_writer_write_comment (ValaCCodeWriter* self, const char* text);
 const char* vala_ccode_comment_get_text (ValaCCodeComment* self);
 static void vala_ccode_comment_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
-static gpointer vala_ccode_comment_parent_class = NULL;
 static void vala_ccode_comment_finalize (ValaCCodeNode* obj);
 
 
@@ -145,18 +144,20 @@ static void vala_ccode_comment_real_write (ValaCCodeNode* base, ValaCCodeWriter*
 
 
 const char* vala_ccode_comment_get_text (ValaCCodeComment* self) {
+	const char* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_text;
+	result = self->priv->_text;
+	return result;
 }
 
 
 void vala_ccode_comment_set_text (ValaCCodeComment* self, const char* value) {
-	char* _tmp2_;
-	const char* _tmp1_;
+	char* _tmp1_;
+	const char* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2_ = NULL;
 	_tmp1_ = NULL;
-	self->priv->_text = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : g_strdup (_tmp1_)), self->priv->_text = (g_free (self->priv->_text), NULL), _tmp2_);
+	_tmp0_ = NULL;
+	self->priv->_text = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_)), self->priv->_text = (g_free (self->priv->_text), NULL), _tmp1_);
 }
 
 
