@@ -82,16 +82,6 @@ typedef struct _ValaCCodeDeclarationPrivate ValaCCodeDeclarationPrivate;
 typedef struct _ValaCCodeDeclarator ValaCCodeDeclarator;
 typedef struct _ValaCCodeDeclaratorClass ValaCCodeDeclaratorClass;
 
-#define VALA_TYPE_CCODE_LINE_DIRECTIVE (vala_ccode_line_directive_get_type ())
-#define VALA_CCODE_LINE_DIRECTIVE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_CCODE_LINE_DIRECTIVE, ValaCCodeLineDirective))
-#define VALA_CCODE_LINE_DIRECTIVE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_CCODE_LINE_DIRECTIVE, ValaCCodeLineDirectiveClass))
-#define VALA_IS_CCODE_LINE_DIRECTIVE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_CCODE_LINE_DIRECTIVE))
-#define VALA_IS_CCODE_LINE_DIRECTIVE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_CCODE_LINE_DIRECTIVE))
-#define VALA_CCODE_LINE_DIRECTIVE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_CCODE_LINE_DIRECTIVE, ValaCCodeLineDirectiveClass))
-
-typedef struct _ValaCCodeLineDirective ValaCCodeLineDirective;
-typedef struct _ValaCCodeLineDirectiveClass ValaCCodeLineDirectiveClass;
-
 #define VALA_TYPE_CCODE_VARIABLE_DECLARATOR (vala_ccode_variable_declarator_get_type ())
 #define VALA_CCODE_VARIABLE_DECLARATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_CCODE_VARIABLE_DECLARATOR, ValaCCodeVariableDeclarator))
 #define VALA_CCODE_VARIABLE_DECLARATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_CCODE_VARIABLE_DECLARATOR, ValaCCodeVariableDeclaratorClass))
@@ -112,6 +102,16 @@ typedef struct _ValaCCodeVariableDeclaratorClass ValaCCodeVariableDeclaratorClas
 typedef struct _ValaCCodeExpression ValaCCodeExpression;
 typedef struct _ValaCCodeExpressionClass ValaCCodeExpressionClass;
 
+#define VALA_TYPE_CCODE_LINE_DIRECTIVE (vala_ccode_line_directive_get_type ())
+#define VALA_CCODE_LINE_DIRECTIVE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_CCODE_LINE_DIRECTIVE, ValaCCodeLineDirective))
+#define VALA_CCODE_LINE_DIRECTIVE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_CCODE_LINE_DIRECTIVE, ValaCCodeLineDirectiveClass))
+#define VALA_IS_CCODE_LINE_DIRECTIVE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_CCODE_LINE_DIRECTIVE))
+#define VALA_IS_CCODE_LINE_DIRECTIVE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_CCODE_LINE_DIRECTIVE))
+#define VALA_CCODE_LINE_DIRECTIVE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_CCODE_LINE_DIRECTIVE, ValaCCodeLineDirectiveClass))
+
+typedef struct _ValaCCodeLineDirective ValaCCodeLineDirective;
+typedef struct _ValaCCodeLineDirectiveClass ValaCCodeLineDirectiveClass;
+
 /**
  * Represents a node in the C code tree.
  */
@@ -169,6 +169,7 @@ struct _ValaCCodeDeclarationPrivate {
 };
 
 
+static gpointer vala_ccode_declaration_parent_class = NULL;
 
 gpointer vala_ccode_node_ref (gpointer instance);
 void vala_ccode_node_unref (gpointer instance);
@@ -193,26 +194,24 @@ enum  {
 void vala_ccode_declaration_set_type_name (ValaCCodeDeclaration* self, const char* value);
 ValaCCodeDeclaration* vala_ccode_declaration_new (const char* type_name);
 ValaCCodeDeclaration* vala_ccode_declaration_construct (GType object_type, const char* type_name);
-ValaCCodeDeclaration* vala_ccode_declaration_new (const char* type_name);
 void vala_ccode_declaration_add_declarator (ValaCCodeDeclaration* self, ValaCCodeDeclarator* decl);
 ValaCCodeModifiers vala_ccode_declaration_get_modifiers (ValaCCodeDeclaration* self);
-GType vala_ccode_line_directive_get_type (void);
-void vala_ccode_writer_write_indent (ValaCCodeWriter* self, ValaCCodeLineDirective* line);
-ValaCCodeLineDirective* vala_ccode_node_get_line (ValaCCodeNode* self);
-void vala_ccode_writer_write_string (ValaCCodeWriter* self, const char* s);
-static gboolean vala_ccode_declaration_has_initializer (ValaCCodeDeclaration* self);
-const char* vala_ccode_declaration_get_type_name (ValaCCodeDeclaration* self);
-void vala_ccode_node_write (ValaCCodeNode* self, ValaCCodeWriter* writer);
-void vala_ccode_writer_write_newline (ValaCCodeWriter* self);
 void vala_ccode_declarator_write_initialization (ValaCCodeDeclarator* self, ValaCCodeWriter* writer);
 static void vala_ccode_declaration_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
 GType vala_ccode_variable_declarator_get_type (void);
 GType vala_ccode_expression_get_type (void);
 ValaCCodeExpression* vala_ccode_variable_declarator_get_initializer (ValaCCodeVariableDeclarator* self);
+static gboolean vala_ccode_declaration_has_initializer (ValaCCodeDeclaration* self);
+GType vala_ccode_line_directive_get_type (void);
+void vala_ccode_writer_write_indent (ValaCCodeWriter* self, ValaCCodeLineDirective* line);
+ValaCCodeLineDirective* vala_ccode_node_get_line (ValaCCodeNode* self);
+void vala_ccode_writer_write_string (ValaCCodeWriter* self, const char* s);
+const char* vala_ccode_declaration_get_type_name (ValaCCodeDeclaration* self);
+void vala_ccode_node_write (ValaCCodeNode* self, ValaCCodeWriter* writer);
+void vala_ccode_writer_write_newline (ValaCCodeWriter* self);
 void vala_ccode_node_write_declaration (ValaCCodeNode* self, ValaCCodeWriter* writer);
 static void vala_ccode_declaration_real_write_declaration (ValaCCodeNode* base, ValaCCodeWriter* writer);
 void vala_ccode_declaration_set_modifiers (ValaCCodeDeclaration* self, ValaCCodeModifiers value);
-static gpointer vala_ccode_declaration_parent_class = NULL;
 static void vala_ccode_declaration_finalize (ValaCCodeNode* obj);
 
 
@@ -247,8 +246,74 @@ static void vala_ccode_declaration_real_write (ValaCCodeNode* base, ValaCCodeWri
 	ValaCCodeDeclaration * self;
 	self = (ValaCCodeDeclaration*) base;
 	g_return_if_fail (writer != NULL);
+	if ((self->priv->_modifiers & (VALA_CCODE_MODIFIERS_STATIC | VALA_CCODE_MODIFIERS_EXTERN)) == 0) {
+		{
+			GeeIterator* _decl_it;
+			_decl_it = gee_iterable_iterator ((GeeIterable*) self->priv->declarators);
+			while (TRUE) {
+				ValaCCodeDeclarator* decl;
+				if (!gee_iterator_next (_decl_it)) {
+					break;
+				}
+				decl = (ValaCCodeDeclarator*) gee_iterator_get (_decl_it);
+				vala_ccode_declarator_write_initialization (decl, writer);
+				(decl == NULL) ? NULL : (decl = (vala_ccode_node_unref (decl), NULL));
+			}
+			(_decl_it == NULL) ? NULL : (_decl_it = (gee_collection_object_unref (_decl_it), NULL));
+		}
+	}
+}
+
+
+static gboolean vala_ccode_declaration_has_initializer (ValaCCodeDeclaration* self) {
+	gboolean result;
+	g_return_val_if_fail (self != NULL, FALSE);
+	{
+		GeeIterator* _decl_it;
+		_decl_it = gee_iterable_iterator ((GeeIterable*) self->priv->declarators);
+		while (TRUE) {
+			ValaCCodeDeclarator* decl;
+			ValaCCodeVariableDeclarator* _tmp1_;
+			ValaCCodeDeclarator* _tmp0_;
+			ValaCCodeVariableDeclarator* var_decl;
+			gboolean _tmp2_;
+			if (!gee_iterator_next (_decl_it)) {
+				break;
+			}
+			decl = (ValaCCodeDeclarator*) gee_iterator_get (_decl_it);
+			_tmp1_ = NULL;
+			_tmp0_ = NULL;
+			var_decl = (_tmp1_ = (_tmp0_ = decl, VALA_IS_CCODE_VARIABLE_DECLARATOR (_tmp0_) ? ((ValaCCodeVariableDeclarator*) _tmp0_) : NULL), (_tmp1_ == NULL) ? NULL : vala_ccode_node_ref (_tmp1_));
+			_tmp2_ = FALSE;
+			if (var_decl != NULL) {
+				_tmp2_ = vala_ccode_variable_declarator_get_initializer (var_decl) == NULL;
+			} else {
+				_tmp2_ = FALSE;
+			}
+			if (_tmp2_) {
+				result = FALSE;
+				(decl == NULL) ? NULL : (decl = (vala_ccode_node_unref (decl), NULL));
+				(var_decl == NULL) ? NULL : (var_decl = (vala_ccode_node_unref (var_decl), NULL));
+				(_decl_it == NULL) ? NULL : (_decl_it = (gee_collection_object_unref (_decl_it), NULL));
+				return result;
+			}
+			(decl == NULL) ? NULL : (decl = (vala_ccode_node_unref (decl), NULL));
+			(var_decl == NULL) ? NULL : (var_decl = (vala_ccode_node_unref (var_decl), NULL));
+		}
+		(_decl_it == NULL) ? NULL : (_decl_it = (gee_collection_object_unref (_decl_it), NULL));
+	}
+	result = TRUE;
+	return result;
+}
+
+
+static void vala_ccode_declaration_real_write_declaration (ValaCCodeNode* base, ValaCCodeWriter* writer) {
+	ValaCCodeDeclaration * self;
+	gboolean first;
+	self = (ValaCCodeDeclaration*) base;
+	g_return_if_fail (writer != NULL);
 	if ((self->priv->_modifiers & (VALA_CCODE_MODIFIERS_STATIC | VALA_CCODE_MODIFIERS_EXTERN)) != 0) {
-		gboolean _tmp0;
+		gboolean _tmp0_;
 		gboolean first;
 		/* combined declaration and initialization for static and extern variables*/
 		vala_ccode_writer_write_indent (writer, vala_ccode_node_get_line ((ValaCCodeNode*) self));
@@ -258,13 +323,13 @@ static void vala_ccode_declaration_real_write (ValaCCodeNode* base, ValaCCodeWri
 		if ((self->priv->_modifiers & VALA_CCODE_MODIFIERS_VOLATILE) != 0) {
 			vala_ccode_writer_write_string (writer, "volatile ");
 		}
-		_tmp0 = FALSE;
+		_tmp0_ = FALSE;
 		if ((self->priv->_modifiers & VALA_CCODE_MODIFIERS_EXTERN) != 0) {
-			_tmp0 = !vala_ccode_declaration_has_initializer (self);
+			_tmp0_ = !vala_ccode_declaration_has_initializer (self);
 		} else {
-			_tmp0 = FALSE;
+			_tmp0_ = FALSE;
 		}
-		if (_tmp0) {
+		if (_tmp0_) {
 			vala_ccode_writer_write_string (writer, "extern ");
 		}
 		vala_ccode_writer_write_string (writer, self->priv->_type_name);
@@ -273,8 +338,11 @@ static void vala_ccode_declaration_real_write (ValaCCodeNode* base, ValaCCodeWri
 		{
 			GeeIterator* _decl_it;
 			_decl_it = gee_iterable_iterator ((GeeIterable*) self->priv->declarators);
-			while (gee_iterator_next (_decl_it)) {
+			while (TRUE) {
 				ValaCCodeDeclarator* decl;
+				if (!gee_iterator_next (_decl_it)) {
+					break;
+				}
 				decl = (ValaCCodeDeclarator*) gee_iterator_get (_decl_it);
 				if (!first) {
 					vala_ccode_writer_write_string (writer, ", ");
@@ -288,63 +356,6 @@ static void vala_ccode_declaration_real_write (ValaCCodeNode* base, ValaCCodeWri
 		}
 		vala_ccode_writer_write_string (writer, ";");
 		vala_ccode_writer_write_newline (writer);
-	} else {
-		{
-			GeeIterator* _decl_it;
-			_decl_it = gee_iterable_iterator ((GeeIterable*) self->priv->declarators);
-			while (gee_iterator_next (_decl_it)) {
-				ValaCCodeDeclarator* decl;
-				decl = (ValaCCodeDeclarator*) gee_iterator_get (_decl_it);
-				vala_ccode_declarator_write_initialization (decl, writer);
-				(decl == NULL) ? NULL : (decl = (vala_ccode_node_unref (decl), NULL));
-			}
-			(_decl_it == NULL) ? NULL : (_decl_it = (gee_collection_object_unref (_decl_it), NULL));
-		}
-	}
-}
-
-
-static gboolean vala_ccode_declaration_has_initializer (ValaCCodeDeclaration* self) {
-	g_return_val_if_fail (self != NULL, FALSE);
-	{
-		GeeIterator* _decl_it;
-		_decl_it = gee_iterable_iterator ((GeeIterable*) self->priv->declarators);
-		while (gee_iterator_next (_decl_it)) {
-			ValaCCodeDeclarator* decl;
-			ValaCCodeVariableDeclarator* _tmp1;
-			ValaCCodeDeclarator* _tmp0;
-			ValaCCodeVariableDeclarator* var_decl;
-			gboolean _tmp2;
-			decl = (ValaCCodeDeclarator*) gee_iterator_get (_decl_it);
-			_tmp1 = NULL;
-			_tmp0 = NULL;
-			var_decl = (_tmp1 = (_tmp0 = decl, VALA_IS_CCODE_VARIABLE_DECLARATOR (_tmp0) ? ((ValaCCodeVariableDeclarator*) _tmp0) : NULL), (_tmp1 == NULL) ? NULL : vala_ccode_node_ref (_tmp1));
-			_tmp2 = FALSE;
-			if (var_decl != NULL) {
-				_tmp2 = vala_ccode_variable_declarator_get_initializer (var_decl) == NULL;
-			} else {
-				_tmp2 = FALSE;
-			}
-			if (_tmp2) {
-				gboolean _tmp3;
-				return (_tmp3 = FALSE, (decl == NULL) ? NULL : (decl = (vala_ccode_node_unref (decl), NULL)), (var_decl == NULL) ? NULL : (var_decl = (vala_ccode_node_unref (var_decl), NULL)), (_decl_it == NULL) ? NULL : (_decl_it = (gee_collection_object_unref (_decl_it), NULL)), _tmp3);
-			}
-			(decl == NULL) ? NULL : (decl = (vala_ccode_node_unref (decl), NULL));
-			(var_decl == NULL) ? NULL : (var_decl = (vala_ccode_node_unref (var_decl), NULL));
-		}
-		(_decl_it == NULL) ? NULL : (_decl_it = (gee_collection_object_unref (_decl_it), NULL));
-	}
-	return TRUE;
-}
-
-
-static void vala_ccode_declaration_real_write_declaration (ValaCCodeNode* base, ValaCCodeWriter* writer) {
-	ValaCCodeDeclaration * self;
-	gboolean first;
-	self = (ValaCCodeDeclaration*) base;
-	g_return_if_fail (writer != NULL);
-	if ((self->priv->_modifiers & (VALA_CCODE_MODIFIERS_STATIC | VALA_CCODE_MODIFIERS_EXTERN)) != 0) {
-		/* no separate declaration for static variables*/
 		return;
 	}
 	vala_ccode_writer_write_indent (writer, NULL);
@@ -357,8 +368,11 @@ static void vala_ccode_declaration_real_write_declaration (ValaCCodeNode* base,
 	{
 		GeeIterator* _decl_it;
 		_decl_it = gee_iterable_iterator ((GeeIterable*) self->priv->declarators);
-		while (gee_iterator_next (_decl_it)) {
+		while (TRUE) {
 			ValaCCodeDeclarator* decl;
+			if (!gee_iterator_next (_decl_it)) {
+				break;
+			}
 			decl = (ValaCCodeDeclarator*) gee_iterator_get (_decl_it);
 			if (!first) {
 				vala_ccode_writer_write_string (writer, ", ");
@@ -376,24 +390,28 @@ static void vala_ccode_declaration_real_write_declaration (ValaCCodeNode* base,
 
 
 const char* vala_ccode_declaration_get_type_name (ValaCCodeDeclaration* self) {
+	const char* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_type_name;
+	result = self->priv->_type_name;
+	return result;
 }
 
 
 void vala_ccode_declaration_set_type_name (ValaCCodeDeclaration* self, const char* value) {
-	char* _tmp2;
-	const char* _tmp1;
+	char* _tmp1_;
+	const char* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_type_name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : g_strdup (_tmp1)), self->priv->_type_name = (g_free (self->priv->_type_name), NULL), _tmp2);
+	_tmp1_ = NULL;
+	_tmp0_ = NULL;
+	self->priv->_type_name = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_)), self->priv->_type_name = (g_free (self->priv->_type_name), NULL), _tmp1_);
 }
 
 
 ValaCCodeModifiers vala_ccode_declaration_get_modifiers (ValaCCodeDeclaration* self) {
+	ValaCCodeModifiers result;
 	g_return_val_if_fail (self != NULL, 0);
-	return self->priv->_modifiers;
+	result = self->priv->_modifiers;
+	return result;
 }
 
 
