@@ -146,6 +146,7 @@ struct _ValaCCodeDoStatementPrivate {
 };
 
 
+static gpointer vala_ccode_do_statement_parent_class = NULL;
 
 gpointer vala_ccode_node_ref (gpointer instance);
 void vala_ccode_node_unref (gpointer instance);
@@ -170,7 +171,6 @@ void vala_ccode_do_statement_set_body (ValaCCodeDoStatement* self, ValaCCodeStat
 void vala_ccode_do_statement_set_condition (ValaCCodeDoStatement* self, ValaCCodeExpression* value);
 ValaCCodeDoStatement* vala_ccode_do_statement_new (ValaCCodeStatement* stmt, ValaCCodeExpression* cond);
 ValaCCodeDoStatement* vala_ccode_do_statement_construct (GType object_type, ValaCCodeStatement* stmt, ValaCCodeExpression* cond);
-ValaCCodeDoStatement* vala_ccode_do_statement_new (ValaCCodeStatement* stmt, ValaCCodeExpression* cond);
 GType vala_ccode_line_directive_get_type (void);
 void vala_ccode_writer_write_indent (ValaCCodeWriter* self, ValaCCodeLineDirective* line);
 ValaCCodeLineDirective* vala_ccode_node_get_line (ValaCCodeNode* self);
@@ -181,7 +181,6 @@ void vala_ccode_block_set_suppress_newline (ValaCCodeBlock* self, gboolean value
 void vala_ccode_node_write (ValaCCodeNode* self, ValaCCodeWriter* writer);
 ValaCCodeExpression* vala_ccode_do_statement_get_condition (ValaCCodeDoStatement* self);
 static void vala_ccode_do_statement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
-static gpointer vala_ccode_do_statement_parent_class = NULL;
 static void vala_ccode_do_statement_finalize (ValaCCodeNode* obj);
 
 
@@ -225,34 +224,38 @@ static void vala_ccode_do_statement_real_write (ValaCCodeNode* base, ValaCCodeWr
 
 
 ValaCCodeStatement* vala_ccode_do_statement_get_body (ValaCCodeDoStatement* self) {
+	ValaCCodeStatement* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_body;
+	result = self->priv->_body;
+	return result;
 }
 
 
 void vala_ccode_do_statement_set_body (ValaCCodeDoStatement* self, ValaCCodeStatement* value) {
-	ValaCCodeStatement* _tmp2_;
 	ValaCCodeStatement* _tmp1_;
+	ValaCCodeStatement* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2_ = NULL;
 	_tmp1_ = NULL;
-	self->priv->_body = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_ccode_node_ref (_tmp1_)), (self->priv->_body == NULL) ? NULL : (self->priv->_body = (vala_ccode_node_unref (self->priv->_body), NULL)), _tmp2_);
+	_tmp0_ = NULL;
+	self->priv->_body = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_ccode_node_ref (_tmp0_)), (self->priv->_body == NULL) ? NULL : (self->priv->_body = (vala_ccode_node_unref (self->priv->_body), NULL)), _tmp1_);
 }
 
 
 ValaCCodeExpression* vala_ccode_do_statement_get_condition (ValaCCodeDoStatement* self) {
+	ValaCCodeExpression* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_condition;
+	result = self->priv->_condition;
+	return result;
 }
 
 
 void vala_ccode_do_statement_set_condition (ValaCCodeDoStatement* self, ValaCCodeExpression* value) {
-	ValaCCodeExpression* _tmp2_;
 	ValaCCodeExpression* _tmp1_;
+	ValaCCodeExpression* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2_ = NULL;
 	_tmp1_ = NULL;
-	self->priv->_condition = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_ccode_node_ref (_tmp1_)), (self->priv->_condition == NULL) ? NULL : (self->priv->_condition = (vala_ccode_node_unref (self->priv->_condition), NULL)), _tmp2_);
+	_tmp0_ = NULL;
+	self->priv->_condition = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_ccode_node_ref (_tmp0_)), (self->priv->_condition == NULL) ? NULL : (self->priv->_condition = (vala_ccode_node_unref (self->priv->_condition), NULL)), _tmp1_);
 }
 
 
