@@ -139,6 +139,7 @@ struct _ValaCCodeForStatementPrivate {
 };
 
 
+static gpointer vala_ccode_for_statement_parent_class = NULL;
 
 gpointer vala_ccode_node_ref (gpointer instance);
 void vala_ccode_node_unref (gpointer instance);
@@ -163,7 +164,6 @@ void vala_ccode_for_statement_set_condition (ValaCCodeForStatement* self, ValaCC
 void vala_ccode_for_statement_set_body (ValaCCodeForStatement* self, ValaCCodeStatement* value);
 ValaCCodeForStatement* vala_ccode_for_statement_new (ValaCCodeExpression* condition, ValaCCodeStatement* body);
 ValaCCodeForStatement* vala_ccode_for_statement_construct (GType object_type, ValaCCodeExpression* condition, ValaCCodeStatement* body);
-ValaCCodeForStatement* vala_ccode_for_statement_new (ValaCCodeExpression* condition, ValaCCodeStatement* body);
 void vala_ccode_for_statement_add_initializer (ValaCCodeForStatement* self, ValaCCodeExpression* expr);
 void vala_ccode_for_statement_add_iterator (ValaCCodeForStatement* self, ValaCCodeExpression* expr);
 GType vala_ccode_line_directive_get_type (void);
@@ -174,7 +174,6 @@ void vala_ccode_node_write (ValaCCodeNode* self, ValaCCodeWriter* writer);
 ValaCCodeExpression* vala_ccode_for_statement_get_condition (ValaCCodeForStatement* self);
 ValaCCodeStatement* vala_ccode_for_statement_get_body (ValaCCodeForStatement* self);
 static void vala_ccode_for_statement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
-static gpointer vala_ccode_for_statement_parent_class = NULL;
 static void vala_ccode_for_statement_finalize (ValaCCodeNode* obj);
 
 
@@ -229,8 +228,11 @@ static void vala_ccode_for_statement_real_write (ValaCCodeNode* base, ValaCCodeW
 	{
 		GeeIterator* _init_expr_it;
 		_init_expr_it = gee_iterable_iterator ((GeeIterable*) self->priv->initializer);
-		while (gee_iterator_next (_init_expr_it)) {
+		while (TRUE) {
 			ValaCCodeExpression* init_expr;
+			if (!gee_iterator_next (_init_expr_it)) {
+				break;
+			}
 			init_expr = (ValaCCodeExpression*) gee_iterator_get (_init_expr_it);
 			if (!first) {
 				vala_ccode_writer_write_string (writer, ", ");
@@ -253,8 +255,11 @@ static void vala_ccode_for_statement_real_write (ValaCCodeNode* base, ValaCCodeW
 	{
 		GeeIterator* _it_expr_it;
 		_it_expr_it = gee_iterable_iterator ((GeeIterable*) self->priv->iterator);
-		while (gee_iterator_next (_it_expr_it)) {
+		while (TRUE) {
 			ValaCCodeExpression* it_expr;
+			if (!gee_iterator_next (_it_expr_it)) {
+				break;
+			}
 			it_expr = (ValaCCodeExpression*) gee_iterator_get (_it_expr_it);
 			if (!first) {
 				vala_ccode_writer_write_string (writer, ", ");
@@ -274,34 +279,38 @@ static void vala_ccode_for_statement_real_write (ValaCCodeNode* base, ValaCCodeW
 
 
 ValaCCodeExpression* vala_ccode_for_statement_get_condition (ValaCCodeForStatement* self) {
+	ValaCCodeExpression* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_condition;
+	result = self->priv->_condition;
+	return result;
 }
 
 
 void vala_ccode_for_statement_set_condition (ValaCCodeForStatement* self, ValaCCodeExpression* value) {
-	ValaCCodeExpression* _tmp2_;
 	ValaCCodeExpression* _tmp1_;
+	ValaCCodeExpression* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2_ = NULL;
 	_tmp1_ = NULL;
-	self->priv->_condition = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_ccode_node_ref (_tmp1_)), (self->priv->_condition == NULL) ? NULL : (self->priv->_condition = (vala_ccode_node_unref (self->priv->_condition), NULL)), _tmp2_);
+	_tmp0_ = NULL;
+	self->priv->_condition = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_ccode_node_ref (_tmp0_)), (self->priv->_condition == NULL) ? NULL : (self->priv->_condition = (vala_ccode_node_unref (self->priv->_condition), NULL)), _tmp1_);
 }
 
 
 ValaCCodeStatement* vala_ccode_for_statement_get_body (ValaCCodeForStatement* self) {
+	ValaCCodeStatement* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_body;
+	result = self->priv->_body;
+	return result;
 }
 
 
 void vala_ccode_for_statement_set_body (ValaCCodeForStatement* self, ValaCCodeStatement* value) {
-	ValaCCodeStatement* _tmp2_;
 	ValaCCodeStatement* _tmp1_;
+	ValaCCodeStatement* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2_ = NULL;
 	_tmp1_ = NULL;
-	self->priv->_body = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_ccode_node_ref (_tmp1_)), (self->priv->_body == NULL) ? NULL : (self->priv->_body = (vala_ccode_node_unref (self->priv->_body), NULL)), _tmp2_);
+	_tmp0_ = NULL;
+	self->priv->_body = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_ccode_node_ref (_tmp0_)), (self->priv->_body == NULL) ? NULL : (self->priv->_body = (vala_ccode_node_unref (self->priv->_body), NULL)), _tmp1_);
 }
 
 
