@@ -118,6 +118,7 @@ struct _ValaCCodeMemberAccessPrivate {
 };
 
 
+static gpointer vala_ccode_member_access_parent_class = NULL;
 
 gpointer vala_ccode_node_ref (gpointer instance);
 void vala_ccode_node_unref (gpointer instance);
@@ -142,17 +143,14 @@ void vala_ccode_member_access_set_member_name (ValaCCodeMemberAccess* self, cons
 void vala_ccode_member_access_set_is_pointer (ValaCCodeMemberAccess* self, gboolean value);
 ValaCCodeMemberAccess* vala_ccode_member_access_new (ValaCCodeExpression* container, const char* member, gboolean pointer);
 ValaCCodeMemberAccess* vala_ccode_member_access_construct (GType object_type, ValaCCodeExpression* container, const char* member, gboolean pointer);
-ValaCCodeMemberAccess* vala_ccode_member_access_new (ValaCCodeExpression* container, const char* member, gboolean pointer);
 ValaCCodeMemberAccess* vala_ccode_member_access_new_pointer (ValaCCodeExpression* container, const char* member);
 ValaCCodeMemberAccess* vala_ccode_member_access_construct_pointer (GType object_type, ValaCCodeExpression* container, const char* member);
-ValaCCodeMemberAccess* vala_ccode_member_access_new_pointer (ValaCCodeExpression* container, const char* member);
 ValaCCodeExpression* vala_ccode_member_access_get_inner (ValaCCodeMemberAccess* self);
 void vala_ccode_expression_write_inner (ValaCCodeExpression* self, ValaCCodeWriter* writer);
 gboolean vala_ccode_member_access_get_is_pointer (ValaCCodeMemberAccess* self);
 void vala_ccode_writer_write_string (ValaCCodeWriter* self, const char* s);
 const char* vala_ccode_member_access_get_member_name (ValaCCodeMemberAccess* self);
 static void vala_ccode_member_access_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
-static gpointer vala_ccode_member_access_parent_class = NULL;
 static void vala_ccode_member_access_finalize (ValaCCodeNode* obj);
 
 
@@ -206,40 +204,46 @@ static void vala_ccode_member_access_real_write (ValaCCodeNode* base, ValaCCodeW
 
 
 ValaCCodeExpression* vala_ccode_member_access_get_inner (ValaCCodeMemberAccess* self) {
+	ValaCCodeExpression* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_inner;
+	result = self->priv->_inner;
+	return result;
 }
 
 
 void vala_ccode_member_access_set_inner (ValaCCodeMemberAccess* self, ValaCCodeExpression* value) {
-	ValaCCodeExpression* _tmp2;
-	ValaCCodeExpression* _tmp1;
+	ValaCCodeExpression* _tmp1_;
+	ValaCCodeExpression* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_inner = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_ccode_node_ref (_tmp1)), (self->priv->_inner == NULL) ? NULL : (self->priv->_inner = (vala_ccode_node_unref (self->priv->_inner), NULL)), _tmp2);
+	_tmp1_ = NULL;
+	_tmp0_ = NULL;
+	self->priv->_inner = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_ccode_node_ref (_tmp0_)), (self->priv->_inner == NULL) ? NULL : (self->priv->_inner = (vala_ccode_node_unref (self->priv->_inner), NULL)), _tmp1_);
 }
 
 
 const char* vala_ccode_member_access_get_member_name (ValaCCodeMemberAccess* self) {
+	const char* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_member_name;
+	result = self->priv->_member_name;
+	return result;
 }
 
 
 void vala_ccode_member_access_set_member_name (ValaCCodeMemberAccess* self, const char* value) {
-	char* _tmp2;
-	const char* _tmp1;
+	char* _tmp1_;
+	const char* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_member_name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : g_strdup (_tmp1)), self->priv->_member_name = (g_free (self->priv->_member_name), NULL), _tmp2);
+	_tmp1_ = NULL;
+	_tmp0_ = NULL;
+	self->priv->_member_name = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_)), self->priv->_member_name = (g_free (self->priv->_member_name), NULL), _tmp1_);
 }
 
 
 gboolean vala_ccode_member_access_get_is_pointer (ValaCCodeMemberAccess* self) {
+	gboolean result;
 	g_return_val_if_fail (self != NULL, FALSE);
-	return self->priv->_is_pointer;
+	result = self->priv->_is_pointer;
+	return result;
 }
 
 
