@@ -158,6 +158,7 @@ struct _ValaCCodeSwitchStatementPrivate {
 };
 
 
+static gpointer vala_ccode_switch_statement_parent_class = NULL;
 
 gpointer vala_ccode_node_ref (gpointer instance);
 void vala_ccode_node_unref (gpointer instance);
@@ -182,7 +183,6 @@ enum  {
 void vala_ccode_switch_statement_set_expression (ValaCCodeSwitchStatement* self, ValaCCodeExpression* value);
 ValaCCodeSwitchStatement* vala_ccode_switch_statement_new (ValaCCodeExpression* expression);
 ValaCCodeSwitchStatement* vala_ccode_switch_statement_construct (GType object_type, ValaCCodeExpression* expression);
-ValaCCodeSwitchStatement* vala_ccode_switch_statement_new (ValaCCodeExpression* expression);
 GType vala_ccode_line_directive_get_type (void);
 void vala_ccode_writer_write_indent (ValaCCodeWriter* self, ValaCCodeLineDirective* line);
 ValaCCodeLineDirective* vala_ccode_node_get_line (ValaCCodeNode* self);
@@ -190,7 +190,6 @@ void vala_ccode_writer_write_string (ValaCCodeWriter* self, const char* s);
 ValaCCodeExpression* vala_ccode_switch_statement_get_expression (ValaCCodeSwitchStatement* self);
 void vala_ccode_node_write (ValaCCodeNode* self, ValaCCodeWriter* writer);
 static void vala_ccode_switch_statement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
-static gpointer vala_ccode_switch_statement_parent_class = NULL;
 static void vala_ccode_switch_statement_finalize (ValaCCodeNode* obj);
 
 
@@ -222,18 +221,20 @@ static void vala_ccode_switch_statement_real_write (ValaCCodeNode* base, ValaCCo
 
 
 ValaCCodeExpression* vala_ccode_switch_statement_get_expression (ValaCCodeSwitchStatement* self) {
+	ValaCCodeExpression* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_expression;
+	result = self->priv->_expression;
+	return result;
 }
 
 
 void vala_ccode_switch_statement_set_expression (ValaCCodeSwitchStatement* self, ValaCCodeExpression* value) {
-	ValaCCodeExpression* _tmp2_;
 	ValaCCodeExpression* _tmp1_;
+	ValaCCodeExpression* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2_ = NULL;
 	_tmp1_ = NULL;
-	self->priv->_expression = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_ccode_node_ref (_tmp1_)), (self->priv->_expression == NULL) ? NULL : (self->priv->_expression = (vala_ccode_node_unref (self->priv->_expression), NULL)), _tmp2_);
+	_tmp0_ = NULL;
+	self->priv->_expression = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_ccode_node_ref (_tmp0_)), (self->priv->_expression == NULL) ? NULL : (self->priv->_expression = (vala_ccode_node_unref (self->priv->_expression), NULL)), _tmp1_);
 }
 
 
