@@ -92,6 +92,7 @@ struct _ValaParamSpecCCodeWriter {
 };
 
 
+static gpointer vala_ccode_writer_parent_class = NULL;
 
 gpointer vala_ccode_writer_ref (gpointer instance);
 void vala_ccode_writer_unref (gpointer instance);
@@ -106,7 +107,6 @@ enum  {
 void vala_ccode_writer_set_filename (ValaCCodeWriter* self, const char* value);
 ValaCCodeWriter* vala_ccode_writer_new (const char* filename);
 ValaCCodeWriter* vala_ccode_writer_construct (GType object_type, const char* filename);
-ValaCCodeWriter* vala_ccode_writer_new (const char* filename);
 const char* vala_ccode_writer_get_filename (ValaCCodeWriter* self);
 gboolean vala_ccode_writer_open (ValaCCodeWriter* self);
 void vala_ccode_writer_close (ValaCCodeWriter* self);
@@ -127,7 +127,6 @@ void vala_ccode_writer_write_begin_block (ValaCCodeWriter* self);
 void vala_ccode_writer_write_end_block (ValaCCodeWriter* self);
 void vala_ccode_writer_write_comment (ValaCCodeWriter* self, const char* text);
 void vala_ccode_writer_set_line_directives (ValaCCodeWriter* self, gboolean value);
-static gpointer vala_ccode_writer_parent_class = NULL;
 static void vala_ccode_writer_finalize (ValaCCodeWriter* obj);
 static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
@@ -156,6 +155,7 @@ ValaCCodeWriter* vala_ccode_writer_new (const char* filename) {
  *         false otherwise
  */
 gboolean vala_ccode_writer_open (ValaCCodeWriter* self) {
+	gboolean result;
 	g_return_val_if_fail (self != NULL, FALSE);
 	self->priv->file_exists = g_file_test (self->priv->_filename, G_FILE_TEST_EXISTS);
 	if (self->priv->file_exists) {
@@ -170,7 +170,8 @@ gboolean vala_ccode_writer_open (ValaCCodeWriter* self) {
 		_tmp2_ = NULL;
 		self->priv->stream = (_tmp2_ = fopen (self->priv->_filename, "w"), (self->priv->stream == NULL) ? NULL : (self->priv->stream = (fclose (self->priv->stream), NULL)), _tmp2_);
 	}
-	return self->priv->stream != NULL;
+	result = self->priv->stream != NULL;
+	return result;
 }
 
 
@@ -277,8 +278,19 @@ void vala_ccode_writer_write_indent (ValaCCodeWriter* self, ValaCCodeLineDirecti
 	{
 		gint i;
 		i = 0;
-		for (; i < self->priv->indent; i++) {
-			fputc ('\t', self->priv->stream);
+		{
+			gboolean _tmp2_;
+			_tmp2_ = TRUE;
+			while (TRUE) {
+				if (!_tmp2_) {
+					i++;
+				}
+				_tmp2_ = FALSE;
+				if (!(i < self->priv->indent)) {
+					break;
+				}
+				fputc ('\t', self->priv->stream);
+			}
 		}
 	}
 	self->priv->_bol = FALSE;
@@ -387,24 +399,28 @@ void vala_ccode_writer_write_comment (ValaCCodeWriter* self, const char* text) {
 
 
 const char* vala_ccode_writer_get_filename (ValaCCodeWriter* self) {
+	const char* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_filename;
+	result = self->priv->_filename;
+	return result;
 }
 
 
 void vala_ccode_writer_set_filename (ValaCCodeWriter* self, const char* value) {
-	char* _tmp2_;
-	const char* _tmp1_;
+	char* _tmp1_;
+	const char* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2_ = NULL;
 	_tmp1_ = NULL;
-	self->priv->_filename = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : g_strdup (_tmp1_)), self->priv->_filename = (g_free (self->priv->_filename), NULL), _tmp2_);
+	_tmp0_ = NULL;
+	self->priv->_filename = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_)), self->priv->_filename = (g_free (self->priv->_filename), NULL), _tmp1_);
 }
 
 
 gboolean vala_ccode_writer_get_line_directives (ValaCCodeWriter* self) {
+	gboolean result;
 	g_return_val_if_fail (self != NULL, FALSE);
-	return self->priv->_line_directives;
+	result = self->priv->_line_directives;
+	return result;
 }
 
 
@@ -415,8 +431,10 @@ void vala_ccode_writer_set_line_directives (ValaCCodeWriter* self, gboolean valu
 
 
 gboolean vala_ccode_writer_get_bol (ValaCCodeWriter* self) {
+	gboolean result;
 	g_return_val_if_fail (self != NULL, FALSE);
-	return self->priv->_bol;
+	result = self->priv->_bol;
+	return result;
 }
 
 
