@@ -102,6 +102,7 @@ struct _ValaInterfaceRegisterFunctionPrivate {
 };
 
 
+static gpointer vala_interface_register_function_parent_class = NULL;
 
 gpointer vala_typeregister_function_ref (gpointer instance);
 void vala_typeregister_function_unref (gpointer instance);
@@ -118,7 +119,6 @@ void vala_interface_register_function_set_interface_reference (ValaInterfaceRegi
 void vala_typeregister_function_set_context (ValaTypeRegisterFunction* self, ValaCodeContext* value);
 ValaInterfaceRegisterFunction* vala_interface_register_function_new (ValaInterface* iface, ValaCodeContext* context);
 ValaInterfaceRegisterFunction* vala_interface_register_function_construct (GType object_type, ValaInterface* iface, ValaCodeContext* context);
-ValaInterfaceRegisterFunction* vala_interface_register_function_new (ValaInterface* iface, ValaCodeContext* context);
 ValaInterface* vala_interface_register_function_get_interface_reference (ValaInterfaceRegisterFunction* self);
 static ValaTypeSymbol* vala_interface_register_function_real_get_type_declaration (ValaTypeRegisterFunction* base);
 static char* vala_interface_register_function_real_get_type_struct_name (ValaTypeRegisterFunction* base);
@@ -131,7 +131,6 @@ static char* vala_interface_register_function_real_get_instance_init_func_name (
 static char* vala_interface_register_function_real_get_parent_type_name (ValaTypeRegisterFunction* base);
 static ValaSymbolAccessibility vala_interface_register_function_real_get_accessibility (ValaTypeRegisterFunction* base);
 static ValaCCodeFragment* vala_interface_register_function_real_get_type_interface_init_statements (ValaTypeRegisterFunction* base);
-static gpointer vala_interface_register_function_parent_class = NULL;
 static void vala_interface_register_function_finalize (ValaTypeRegisterFunction* obj);
 
 
@@ -154,82 +153,103 @@ ValaInterfaceRegisterFunction* vala_interface_register_function_new (ValaInterfa
 
 static ValaTypeSymbol* vala_interface_register_function_real_get_type_declaration (ValaTypeRegisterFunction* base) {
 	ValaInterfaceRegisterFunction * self;
+	ValaTypeSymbol* result;
 	ValaTypeSymbol* _tmp0_;
 	self = (ValaInterfaceRegisterFunction*) base;
 	_tmp0_ = NULL;
-	return (_tmp0_ = (ValaTypeSymbol*) self->priv->_interface_reference, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_));
+	result = (_tmp0_ = (ValaTypeSymbol*) self->priv->_interface_reference, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_));
+	return result;
 }
 
 
 static char* vala_interface_register_function_real_get_type_struct_name (ValaTypeRegisterFunction* base) {
 	ValaInterfaceRegisterFunction * self;
+	char* result;
 	self = (ValaInterfaceRegisterFunction*) base;
-	return vala_interface_get_type_cname (self->priv->_interface_reference);
+	result = vala_interface_get_type_cname (self->priv->_interface_reference);
+	return result;
 }
 
 
 static char* vala_interface_register_function_real_get_base_init_func_name (ValaTypeRegisterFunction* base) {
 	ValaInterfaceRegisterFunction * self;
+	char* result;
 	char* _tmp0_;
 	char* _tmp1_;
 	self = (ValaInterfaceRegisterFunction*) base;
 	_tmp0_ = NULL;
 	_tmp1_ = NULL;
-	return (_tmp1_ = g_strdup_printf ("%s_base_init", _tmp0_ = vala_symbol_get_lower_case_cname ((ValaSymbol*) self->priv->_interface_reference, NULL)), _tmp0_ = (g_free (_tmp0_), NULL), _tmp1_);
+	result = (_tmp1_ = g_strdup_printf ("%s_base_init", _tmp0_ = vala_symbol_get_lower_case_cname ((ValaSymbol*) self->priv->_interface_reference, NULL)), _tmp0_ = (g_free (_tmp0_), NULL), _tmp1_);
+	return result;
 }
 
 
 static char* vala_interface_register_function_real_get_class_finalize_func_name (ValaTypeRegisterFunction* base) {
 	ValaInterfaceRegisterFunction * self;
+	char* result;
 	self = (ValaInterfaceRegisterFunction*) base;
-	return g_strdup ("NULL");
+	result = g_strdup ("NULL");
+	return result;
 }
 
 
 static char* vala_interface_register_function_real_get_base_finalize_func_name (ValaTypeRegisterFunction* base) {
 	ValaInterfaceRegisterFunction * self;
+	char* result;
 	self = (ValaInterfaceRegisterFunction*) base;
-	return g_strdup ("NULL");
+	result = g_strdup ("NULL");
+	return result;
 }
 
 
 static char* vala_interface_register_function_real_get_class_init_func_name (ValaTypeRegisterFunction* base) {
 	ValaInterfaceRegisterFunction * self;
+	char* result;
 	self = (ValaInterfaceRegisterFunction*) base;
-	return g_strdup ("NULL");
+	result = g_strdup ("NULL");
+	return result;
 }
 
 
 static char* vala_interface_register_function_real_get_instance_struct_size (ValaTypeRegisterFunction* base) {
 	ValaInterfaceRegisterFunction * self;
+	char* result;
 	self = (ValaInterfaceRegisterFunction*) base;
-	return g_strdup ("0");
+	result = g_strdup ("0");
+	return result;
 }
 
 
 static char* vala_interface_register_function_real_get_instance_init_func_name (ValaTypeRegisterFunction* base) {
 	ValaInterfaceRegisterFunction * self;
+	char* result;
 	self = (ValaInterfaceRegisterFunction*) base;
-	return g_strdup ("NULL");
+	result = g_strdup ("NULL");
+	return result;
 }
 
 
 static char* vala_interface_register_function_real_get_parent_type_name (ValaTypeRegisterFunction* base) {
 	ValaInterfaceRegisterFunction * self;
+	char* result;
 	self = (ValaInterfaceRegisterFunction*) base;
-	return g_strdup ("G_TYPE_INTERFACE");
+	result = g_strdup ("G_TYPE_INTERFACE");
+	return result;
 }
 
 
 static ValaSymbolAccessibility vala_interface_register_function_real_get_accessibility (ValaTypeRegisterFunction* base) {
 	ValaInterfaceRegisterFunction * self;
+	ValaSymbolAccessibility result;
 	self = (ValaInterfaceRegisterFunction*) base;
-	return vala_symbol_get_access ((ValaSymbol*) self->priv->_interface_reference);
+	result = vala_symbol_get_access ((ValaSymbol*) self->priv->_interface_reference);
+	return result;
 }
 
 
 static ValaCCodeFragment* vala_interface_register_function_real_get_type_interface_init_statements (ValaTypeRegisterFunction* base) {
 	ValaInterfaceRegisterFunction * self;
+	ValaCCodeFragment* result;
 	ValaCCodeFragment* frag;
 	self = (ValaInterfaceRegisterFunction*) base;
 	frag = vala_ccode_fragment_new ();
@@ -243,7 +263,7 @@ static ValaCCodeFragment* vala_interface_register_function_real_get_type_interfa
 		_tmp1_ = NULL;
 		_prereq_ref_it = (_tmp1_ = gee_iterable_iterator ((GeeIterable*) (_tmp0_ = vala_interface_get_prerequisites (self->priv->_interface_reference))), (_tmp0_ == NULL) ? NULL : (_tmp0_ = (gee_collection_object_unref (_tmp0_), NULL)), _tmp1_);
 		/* register all prerequisites */
-		while (gee_iterator_next (_prereq_ref_it)) {
+		while (TRUE) {
 			ValaDataType* prereq_ref;
 			ValaTypeSymbol* _tmp2_;
 			ValaTypeSymbol* prereq;
@@ -257,6 +277,11 @@ static ValaCCodeFragment* vala_interface_register_function_real_get_type_interfa
 			char* _tmp8_;
 			ValaCCodeExpressionStatement* _tmp10_;
 			/* register all prerequisites */
+			if (!gee_iterator_next (_prereq_ref_it)) {
+				/* register all prerequisites */
+				break;
+			}
+			/* register all prerequisites */
 			prereq_ref = (ValaDataType*) gee_iterator_get (_prereq_ref_it);
 			_tmp2_ = NULL;
 			prereq = (_tmp2_ = vala_data_type_get_data_type (prereq_ref), (_tmp2_ == NULL) ? NULL : vala_code_node_ref (_tmp2_));
@@ -284,13 +309,16 @@ static ValaCCodeFragment* vala_interface_register_function_real_get_type_interfa
 		}
 		(_prereq_ref_it == NULL) ? NULL : (_prereq_ref_it = (gee_collection_object_unref (_prereq_ref_it), NULL));
 	}
-	return frag;
+	result = frag;
+	return result;
 }
 
 
 ValaInterface* vala_interface_register_function_get_interface_reference (ValaInterfaceRegisterFunction* self) {
+	ValaInterface* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_interface_reference;
+	result = self->priv->_interface_reference;
+	return result;
 }
 
 
