@@ -322,6 +322,19 @@ struct _GeeHashMapValueIteratorPrivate {
 };
 
 
+static gpointer gee_hash_map_key_set_parent_class = NULL;
+static GeeIterableIface* gee_hash_map_key_set_gee_iterable_parent_iface = NULL;
+static GeeCollectionIface* gee_hash_map_key_set_gee_collection_parent_iface = NULL;
+static GeeSetIface* gee_hash_map_key_set_gee_set_parent_iface = NULL;
+static gpointer gee_hash_map_key_iterator_parent_class = NULL;
+static GeeIteratorIface* gee_hash_map_key_iterator_gee_iterator_parent_iface = NULL;
+static gpointer gee_hash_map_value_collection_parent_class = NULL;
+static GeeIterableIface* gee_hash_map_value_collection_gee_iterable_parent_iface = NULL;
+static GeeCollectionIface* gee_hash_map_value_collection_gee_collection_parent_iface = NULL;
+static gpointer gee_hash_map_value_iterator_parent_class = NULL;
+static GeeIteratorIface* gee_hash_map_value_iterator_gee_iterator_parent_iface = NULL;
+static gpointer gee_hash_map_parent_class = NULL;
+static GeeMapIface* gee_hash_map_gee_map_parent_iface = NULL;
 
 gpointer gee_collection_object_ref (gpointer instance);
 void gee_collection_object_unref (gpointer instance);
@@ -346,7 +359,6 @@ void gee_hash_map_set_key_equal_func (GeeHashMap* self, GEqualFunc value);
 void gee_hash_map_set_value_equal_func (GeeHashMap* self, GEqualFunc value);
 GeeHashMap* gee_hash_map_new (GType k_type, GBoxedCopyFunc k_dup_func, GDestroyNotify k_destroy_func, GType v_type, GBoxedCopyFunc v_dup_func, GDestroyNotify v_destroy_func, GHashFunc key_hash_func, GEqualFunc key_equal_func, GEqualFunc value_equal_func);
 GeeHashMap* gee_hash_map_construct (GType object_type, GType k_type, GBoxedCopyFunc k_dup_func, GDestroyNotify k_destroy_func, GType v_type, GBoxedCopyFunc v_dup_func, GDestroyNotify v_destroy_func, GHashFunc key_hash_func, GEqualFunc key_equal_func, GEqualFunc value_equal_func);
-GeeHashMap* gee_hash_map_new (GType k_type, GBoxedCopyFunc k_dup_func, GDestroyNotify k_destroy_func, GType v_type, GBoxedCopyFunc v_dup_func, GDestroyNotify v_destroy_func, GHashFunc key_hash_func, GEqualFunc key_equal_func, GEqualFunc value_equal_func);
 static GeeHashMapKeySet* gee_hash_map_key_set_new (GType k_type, GBoxedCopyFunc k_dup_func, GDestroyNotify k_destroy_func, GType v_type, GBoxedCopyFunc v_dup_func, GDestroyNotify v_destroy_func, GeeHashMap* map);
 static GeeHashMapKeySet* gee_hash_map_key_set_construct (GType object_type, GType k_type, GBoxedCopyFunc k_dup_func, GDestroyNotify k_destroy_func, GType v_type, GBoxedCopyFunc v_dup_func, GDestroyNotify v_destroy_func, GeeHashMap* map);
 static GType gee_hash_map_key_set_get_type (void);
@@ -372,7 +384,6 @@ enum  {
 	GEE_HASH_MAP_KEY_SET_DUMMY_PROPERTY
 };
 static void gee_hash_map_key_set_set_map (GeeHashMapKeySet* self, GeeHashMap* value);
-static GeeHashMapKeySet* gee_hash_map_key_set_new (GType k_type, GBoxedCopyFunc k_dup_func, GDestroyNotify k_destroy_func, GType v_type, GBoxedCopyFunc v_dup_func, GDestroyNotify v_destroy_func, GeeHashMap* map);
 static GType gee_hash_map_key_set_real_get_element_type (GeeIterable* base);
 static GeeHashMapKeyIterator* gee_hash_map_key_iterator_new (GType k_type, GBoxedCopyFunc k_dup_func, GDestroyNotify k_destroy_func, GType v_type, GBoxedCopyFunc v_dup_func, GDestroyNotify v_destroy_func, GeeHashMap* map);
 static GeeHashMapKeyIterator* gee_hash_map_key_iterator_construct (GType object_type, GType k_type, GBoxedCopyFunc k_dup_func, GDestroyNotify k_destroy_func, GType v_type, GBoxedCopyFunc v_dup_func, GDestroyNotify v_destroy_func, GeeHashMap* map);
@@ -384,28 +395,20 @@ static gboolean gee_hash_map_key_set_real_remove (GeeCollection* base, gconstpoi
 gboolean gee_map_contains (GeeMap* self, gconstpointer key);
 static gboolean gee_hash_map_key_set_real_contains (GeeCollection* base, gconstpointer key);
 gint gee_map_get_size (GeeMap* self);
-static gpointer gee_hash_map_key_set_parent_class = NULL;
-static GeeIterableIface* gee_hash_map_key_set_gee_iterable_parent_iface = NULL;
-static GeeCollectionIface* gee_hash_map_key_set_gee_collection_parent_iface = NULL;
-static GeeSetIface* gee_hash_map_key_set_gee_set_parent_iface = NULL;
 static void gee_hash_map_key_set_finalize (GeeCollectionObject* obj);
 #define GEE_HASH_MAP_KEY_ITERATOR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GEE_HASH_MAP_TYPE_KEY_ITERATOR, GeeHashMapKeyIteratorPrivate))
 enum  {
 	GEE_HASH_MAP_KEY_ITERATOR_DUMMY_PROPERTY
 };
 static void gee_hash_map_key_iterator_set_map (GeeHashMapKeyIterator* self, GeeHashMap* value);
-static GeeHashMapKeyIterator* gee_hash_map_key_iterator_new (GType k_type, GBoxedCopyFunc k_dup_func, GDestroyNotify k_destroy_func, GType v_type, GBoxedCopyFunc v_dup_func, GDestroyNotify v_destroy_func, GeeHashMap* map);
 static gboolean gee_hash_map_key_iterator_real_next (GeeIterator* base);
 static gpointer gee_hash_map_key_iterator_real_get (GeeIterator* base);
-static gpointer gee_hash_map_key_iterator_parent_class = NULL;
-static GeeIteratorIface* gee_hash_map_key_iterator_gee_iterator_parent_iface = NULL;
 static void gee_hash_map_key_iterator_finalize (GeeCollectionObject* obj);
 #define GEE_HASH_MAP_VALUE_COLLECTION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GEE_HASH_MAP_TYPE_VALUE_COLLECTION, GeeHashMapValueCollectionPrivate))
 enum  {
 	GEE_HASH_MAP_VALUE_COLLECTION_DUMMY_PROPERTY
 };
 static void gee_hash_map_value_collection_set_map (GeeHashMapValueCollection* self, GeeHashMap* value);
-static GeeHashMapValueCollection* gee_hash_map_value_collection_new (GType k_type, GBoxedCopyFunc k_dup_func, GDestroyNotify k_destroy_func, GType v_type, GBoxedCopyFunc v_dup_func, GDestroyNotify v_destroy_func, GeeHashMap* map);
 static GType gee_hash_map_value_collection_real_get_element_type (GeeIterable* base);
 static GeeHashMapValueIterator* gee_hash_map_value_iterator_new (GType k_type, GBoxedCopyFunc k_dup_func, GDestroyNotify k_destroy_func, GType v_type, GBoxedCopyFunc v_dup_func, GDestroyNotify v_destroy_func, GeeHashMap* map);
 static GeeHashMapValueIterator* gee_hash_map_value_iterator_construct (GType object_type, GType k_type, GBoxedCopyFunc k_dup_func, GDestroyNotify k_destroy_func, GType v_type, GBoxedCopyFunc v_dup_func, GDestroyNotify v_destroy_func, GeeHashMap* map);
@@ -418,23 +421,15 @@ GeeIterator* gee_iterable_iterator (GeeIterable* self);
 gboolean gee_iterator_next (GeeIterator* self);
 gpointer gee_iterator_get (GeeIterator* self);
 static gboolean gee_hash_map_value_collection_real_contains (GeeCollection* base, gconstpointer value);
-static gpointer gee_hash_map_value_collection_parent_class = NULL;
-static GeeIterableIface* gee_hash_map_value_collection_gee_iterable_parent_iface = NULL;
-static GeeCollectionIface* gee_hash_map_value_collection_gee_collection_parent_iface = NULL;
 static void gee_hash_map_value_collection_finalize (GeeCollectionObject* obj);
 #define GEE_HASH_MAP_VALUE_ITERATOR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GEE_HASH_MAP_TYPE_VALUE_ITERATOR, GeeHashMapValueIteratorPrivate))
 enum  {
 	GEE_HASH_MAP_VALUE_ITERATOR_DUMMY_PROPERTY
 };
 static void gee_hash_map_value_iterator_set_map (GeeHashMapValueIterator* self, GeeHashMap* value);
-static GeeHashMapValueIterator* gee_hash_map_value_iterator_new (GType k_type, GBoxedCopyFunc k_dup_func, GDestroyNotify k_destroy_func, GType v_type, GBoxedCopyFunc v_dup_func, GDestroyNotify v_destroy_func, GeeHashMap* map);
 static gboolean gee_hash_map_value_iterator_real_next (GeeIterator* base);
 static gpointer gee_hash_map_value_iterator_real_get (GeeIterator* base);
-static gpointer gee_hash_map_value_iterator_parent_class = NULL;
-static GeeIteratorIface* gee_hash_map_value_iterator_gee_iterator_parent_iface = NULL;
 static void gee_hash_map_value_iterator_finalize (GeeCollectionObject* obj);
-static gpointer gee_hash_map_parent_class = NULL;
-static GeeMapIface* gee_hash_map_gee_map_parent_iface = NULL;
 static void gee_hash_map_finalize (GeeCollectionObject* obj);
 static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
@@ -468,19 +463,24 @@ GeeHashMap* gee_hash_map_new (GType k_type, GBoxedCopyFunc k_dup_func, GDestroyN
 
 static GeeSet* gee_hash_map_real_get_keys (GeeMap* base) {
 	GeeHashMap * self;
+	GeeSet* result;
 	self = (GeeHashMap*) base;
-	return (GeeSet*) gee_hash_map_key_set_new (self->priv->k_type, (GBoxedCopyFunc) self->priv->k_dup_func, self->priv->k_destroy_func, self->priv->v_type, (GBoxedCopyFunc) self->priv->v_dup_func, self->priv->v_destroy_func, self);
+	result = (GeeSet*) gee_hash_map_key_set_new (self->priv->k_type, (GBoxedCopyFunc) self->priv->k_dup_func, self->priv->k_destroy_func, self->priv->v_type, (GBoxedCopyFunc) self->priv->v_dup_func, self->priv->v_destroy_func, self);
+	return result;
 }
 
 
 static GeeCollection* gee_hash_map_real_get_values (GeeMap* base) {
 	GeeHashMap * self;
+	GeeCollection* result;
 	self = (GeeHashMap*) base;
-	return (GeeCollection*) gee_hash_map_value_collection_new (self->priv->k_type, (GBoxedCopyFunc) self->priv->k_dup_func, self->priv->k_destroy_func, self->priv->v_type, (GBoxedCopyFunc) self->priv->v_dup_func, self->priv->v_destroy_func, self);
+	result = (GeeCollection*) gee_hash_map_value_collection_new (self->priv->k_type, (GBoxedCopyFunc) self->priv->k_dup_func, self->priv->k_destroy_func, self->priv->v_type, (GBoxedCopyFunc) self->priv->v_dup_func, self->priv->v_destroy_func, self);
+	return result;
 }
 
 
 static GeeHashMapNode** gee_hash_map_lookup_node (GeeHashMap* self, gconstpointer key) {
+	GeeHashMapNode** result;
 	guint hash_value;
 	GeeHashMapNode** node;
 	g_return_val_if_fail (self != NULL, NULL);
@@ -506,30 +506,36 @@ static GeeHashMapNode** gee_hash_map_lookup_node (GeeHashMap* self, gconstpointe
 		}
 		node = &(*node)->next;
 	}
-	return node;
+	result = node;
+	return result;
 }
 
 
 static gboolean gee_hash_map_real_contains (GeeMap* base, gconstpointer key) {
 	GeeHashMap * self;
+	gboolean result;
 	GeeHashMapNode** node;
 	self = (GeeHashMap*) base;
 	node = gee_hash_map_lookup_node (self, key);
-	return (*node) != NULL;
+	result = (*node) != NULL;
+	return result;
 }
 
 
 static gpointer gee_hash_map_real_get (GeeMap* base, gconstpointer key) {
 	GeeHashMap * self;
+	gpointer result;
 	GeeHashMapNode* node;
 	self = (GeeHashMap*) base;
 	node = *gee_hash_map_lookup_node (self, key);
 	if (node != NULL) {
 		gconstpointer _tmp0_;
 		_tmp0_ = NULL;
-		return (_tmp0_ = node->value, ((_tmp0_ == NULL) || (self->priv->v_dup_func == NULL)) ? ((gpointer) _tmp0_) : self->priv->v_dup_func ((gpointer) _tmp0_));
+		result = (_tmp0_ = node->value, ((_tmp0_ == NULL) || (self->priv->v_dup_func == NULL)) ? ((gpointer) _tmp0_) : self->priv->v_dup_func ((gpointer) _tmp0_));
+		return result;
 	} else {
-		return NULL;
+		result = NULL;
+		return result;
 	}
 }
 
@@ -562,23 +568,34 @@ static void gee_hash_map_real_set (GeeMap* base, gconstpointer key, gconstpointe
 
 static gboolean gee_hash_map_real_remove (GeeMap* base, gconstpointer key) {
 	GeeHashMap * self;
+	gboolean result;
 	GeeHashMapNode** node;
 	self = (GeeHashMap*) base;
 	node = gee_hash_map_lookup_node (self, key);
 	if ((*node) != NULL) {
-		gpointer _tmp0_;
+		GeeHashMapNode* _tmp0_;
+		GeeHashMapNode* next;
 		gpointer _tmp1_;
+		gpointer _tmp2_;
+		GeeHashMapNode* _tmp3_;
 		_tmp0_ = NULL;
-		(*node)->key = (_tmp0_ = NULL, (((*node)->key == NULL) || (self->priv->k_destroy_func == NULL)) ? NULL : ((*node)->key = (self->priv->k_destroy_func ((*node)->key), NULL)), _tmp0_);
+		next = (_tmp0_ = (*node)->next, (*node)->next = NULL, _tmp0_);
 		_tmp1_ = NULL;
-		(*node)->value = (_tmp1_ = NULL, (((*node)->value == NULL) || (self->priv->v_destroy_func == NULL)) ? NULL : ((*node)->value = (self->priv->v_destroy_func ((*node)->value), NULL)), _tmp1_);
-		*node = (*node)->next;
+		(*node)->key = (_tmp1_ = NULL, (((*node)->key == NULL) || (self->priv->k_destroy_func == NULL)) ? NULL : ((*node)->key = (self->priv->k_destroy_func ((*node)->key), NULL)), _tmp1_);
+		_tmp2_ = NULL;
+		(*node)->value = (_tmp2_ = NULL, (((*node)->value == NULL) || (self->priv->v_destroy_func == NULL)) ? NULL : ((*node)->value = (self->priv->v_destroy_func ((*node)->value), NULL)), _tmp2_);
+		gee_hash_map_node_free (*node);
+		_tmp3_ = NULL;
+		*node = (_tmp3_ = next, next = NULL, _tmp3_);
 		self->priv->_nnodes--;
 		gee_hash_map_resize (self);
 		self->priv->_stamp++;
-		return TRUE;
+		result = TRUE;
+		(next == NULL) ? NULL : (next = (gee_hash_map_node_free (next), NULL));
+		return result;
 	}
-	return FALSE;
+	result = FALSE;
+	return result;
 }
 
 
@@ -588,30 +605,44 @@ static void gee_hash_map_real_clear (GeeMap* base) {
 	{
 		gint i;
 		i = 0;
-		for (; i < self->priv->_array_size; i++) {
-			GeeHashMapNode* _tmp0_;
-			GeeHashMapNode* node;
-			_tmp0_ = NULL;
-			node = (_tmp0_ = self->priv->_nodes[i], self->priv->_nodes[i] = NULL, _tmp0_);
-			while (node != NULL) {
+		{
+			gboolean _tmp0_;
+			_tmp0_ = TRUE;
+			while (TRUE) {
 				GeeHashMapNode* _tmp1_;
-				GeeHashMapNode* next;
-				gpointer _tmp2_;
-				gpointer _tmp3_;
-				GeeHashMapNode* _tmp5_;
-				GeeHashMapNode* _tmp4_;
+				GeeHashMapNode* node;
+				if (!_tmp0_) {
+					i++;
+				}
+				_tmp0_ = FALSE;
+				if (!(i < self->priv->_array_size)) {
+					break;
+				}
 				_tmp1_ = NULL;
-				next = (_tmp1_ = node->next, node->next = NULL, _tmp1_);
-				_tmp2_ = NULL;
-				node->key = (_tmp2_ = NULL, ((node->key == NULL) || (self->priv->k_destroy_func == NULL)) ? NULL : (node->key = (self->priv->k_destroy_func (node->key), NULL)), _tmp2_);
-				_tmp3_ = NULL;
-				node->value = (_tmp3_ = NULL, ((node->value == NULL) || (self->priv->v_destroy_func == NULL)) ? NULL : (node->value = (self->priv->v_destroy_func (node->value), NULL)), _tmp3_);
-				_tmp5_ = NULL;
-				_tmp4_ = NULL;
-				node = (_tmp5_ = (_tmp4_ = next, next = NULL, _tmp4_), (node == NULL) ? NULL : (node = (gee_hash_map_node_free (node), NULL)), _tmp5_);
-				(next == NULL) ? NULL : (next = (gee_hash_map_node_free (next), NULL));
+				node = (_tmp1_ = self->priv->_nodes[i], self->priv->_nodes[i] = NULL, _tmp1_);
+				while (TRUE) {
+					GeeHashMapNode* _tmp2_;
+					GeeHashMapNode* next;
+					gpointer _tmp3_;
+					gpointer _tmp4_;
+					GeeHashMapNode* _tmp6_;
+					GeeHashMapNode* _tmp5_;
+					if (!(node != NULL)) {
+						break;
+					}
+					_tmp2_ = NULL;
+					next = (_tmp2_ = node->next, node->next = NULL, _tmp2_);
+					_tmp3_ = NULL;
+					node->key = (_tmp3_ = NULL, ((node->key == NULL) || (self->priv->k_destroy_func == NULL)) ? NULL : (node->key = (self->priv->k_destroy_func (node->key), NULL)), _tmp3_);
+					_tmp4_ = NULL;
+					node->value = (_tmp4_ = NULL, ((node->value == NULL) || (self->priv->v_destroy_func == NULL)) ? NULL : (node->value = (self->priv->v_destroy_func (node->value), NULL)), _tmp4_);
+					_tmp6_ = NULL;
+					_tmp5_ = NULL;
+					node = (_tmp6_ = (_tmp5_ = next, next = NULL, _tmp5_), (node == NULL) ? NULL : (node = (gee_hash_map_node_free (node), NULL)), _tmp6_);
+					(next == NULL) ? NULL : (next = (gee_hash_map_node_free (next), NULL));
+				}
+				(node == NULL) ? NULL : (node = (gee_hash_map_node_free (node), NULL));
 			}
-			(node == NULL) ? NULL : (node = (gee_hash_map_node_free (node), NULL));
 		}
 	}
 	self->priv->_nnodes = 0;
@@ -648,8 +679,8 @@ static void gee_hash_map_resize (GeeHashMap* self) {
 		gint new_nodes_size;
 		gint new_nodes_length1;
 		GeeHashMapNode** new_nodes;
-		GeeHashMapNode** _tmp15_;
-		GeeHashMapNode** _tmp14_;
+		GeeHashMapNode** _tmp17_;
+		GeeHashMapNode** _tmp16_;
 		new_array_size = (gint) g_spaced_primes_closest ((guint) self->priv->_nnodes);
 		new_array_size = CLAMP (new_array_size, GEE_HASH_MAP_MIN_SIZE, GEE_HASH_MAP_MAX_SIZE);
 		_tmp3_ = NULL;
@@ -657,45 +688,68 @@ static void gee_hash_map_resize (GeeHashMap* self) {
 		{
 			gint i;
 			i = 0;
-			for (; i < self->priv->_array_size; i++) {
-				GeeHashMapNode* node;
-				GeeHashMapNode* next;
-				GeeHashMapNode* _tmp7_;
-				GeeHashMapNode* _tmp6_;
-				GeeHashMapNode* _tmp5_;
-				GeeHashMapNode* _tmp4_;
-				node = NULL;
-				next = NULL;
-				_tmp7_ = NULL;
-				_tmp6_ = NULL;
-				_tmp5_ = NULL;
-				_tmp4_ = NULL;
-				for (node = (_tmp5_ = (_tmp4_ = self->priv->_nodes[i], self->priv->_nodes[i] = NULL, _tmp4_), (node == NULL) ? NULL : (node = (gee_hash_map_node_free (node), NULL)), _tmp5_); node != NULL; node = (_tmp7_ = (_tmp6_ = next, next = NULL, _tmp6_), (node == NULL) ? NULL : (node = (gee_hash_map_node_free (node), NULL)), _tmp7_)) {
-					GeeHashMapNode* _tmp9_;
-					GeeHashMapNode* _tmp8_;
-					guint hash_val;
-					GeeHashMapNode* _tmp11_;
-					GeeHashMapNode* _tmp10_;
-					GeeHashMapNode* _tmp13_;
-					GeeHashMapNode* _tmp12_;
-					_tmp9_ = NULL;
-					_tmp8_ = NULL;
-					next = (_tmp9_ = (_tmp8_ = node->next, node->next = NULL, _tmp8_), (next == NULL) ? NULL : (next = (gee_hash_map_node_free (next), NULL)), _tmp9_);
-					hash_val = node->key_hash % new_array_size;
-					_tmp11_ = NULL;
-					_tmp10_ = NULL;
-					node->next = (_tmp11_ = (_tmp10_ = new_nodes[hash_val], new_nodes[hash_val] = NULL, _tmp10_), (node->next == NULL) ? NULL : (node->next = (gee_hash_map_node_free (node->next), NULL)), _tmp11_);
-					_tmp13_ = NULL;
-					_tmp12_ = NULL;
-					new_nodes[hash_val] = (_tmp13_ = (_tmp12_ = node, node = NULL, _tmp12_), (new_nodes[hash_val] == NULL) ? NULL : (new_nodes[hash_val] = (gee_hash_map_node_free (new_nodes[hash_val]), NULL)), _tmp13_);
+			{
+				gboolean _tmp4_;
+				_tmp4_ = TRUE;
+				while (TRUE) {
+					GeeHashMapNode* node;
+					GeeHashMapNode* next;
+					if (!_tmp4_) {
+						i++;
+					}
+					_tmp4_ = FALSE;
+					if (!(i < self->priv->_array_size)) {
+						break;
+					}
+					node = NULL;
+					next = NULL;
+					{
+						GeeHashMapNode* _tmp6_;
+						GeeHashMapNode* _tmp5_;
+						gboolean _tmp7_;
+						_tmp6_ = NULL;
+						_tmp5_ = NULL;
+						node = (_tmp6_ = (_tmp5_ = self->priv->_nodes[i], self->priv->_nodes[i] = NULL, _tmp5_), (node == NULL) ? NULL : (node = (gee_hash_map_node_free (node), NULL)), _tmp6_);
+						_tmp7_ = TRUE;
+						while (TRUE) {
+							GeeHashMapNode* _tmp11_;
+							GeeHashMapNode* _tmp10_;
+							guint hash_val;
+							GeeHashMapNode* _tmp13_;
+							GeeHashMapNode* _tmp12_;
+							GeeHashMapNode* _tmp15_;
+							GeeHashMapNode* _tmp14_;
+							if (!_tmp7_) {
+								GeeHashMapNode* _tmp9_;
+								GeeHashMapNode* _tmp8_;
+								_tmp9_ = NULL;
+								_tmp8_ = NULL;
+								node = (_tmp9_ = (_tmp8_ = next, next = NULL, _tmp8_), (node == NULL) ? NULL : (node = (gee_hash_map_node_free (node), NULL)), _tmp9_);
+							}
+							_tmp7_ = FALSE;
+							if (!(node != NULL)) {
+								break;
+							}
+							_tmp11_ = NULL;
+							_tmp10_ = NULL;
+							next = (_tmp11_ = (_tmp10_ = node->next, node->next = NULL, _tmp10_), (next == NULL) ? NULL : (next = (gee_hash_map_node_free (next), NULL)), _tmp11_);
+							hash_val = node->key_hash % new_array_size;
+							_tmp13_ = NULL;
+							_tmp12_ = NULL;
+							node->next = (_tmp13_ = (_tmp12_ = new_nodes[hash_val], new_nodes[hash_val] = NULL, _tmp12_), (node->next == NULL) ? NULL : (node->next = (gee_hash_map_node_free (node->next), NULL)), _tmp13_);
+							_tmp15_ = NULL;
+							_tmp14_ = NULL;
+							new_nodes[hash_val] = (_tmp15_ = (_tmp14_ = node, node = NULL, _tmp14_), (new_nodes[hash_val] == NULL) ? NULL : (new_nodes[hash_val] = (gee_hash_map_node_free (new_nodes[hash_val]), NULL)), _tmp15_);
+						}
+					}
+					(node == NULL) ? NULL : (node = (gee_hash_map_node_free (node), NULL));
+					(next == NULL) ? NULL : (next = (gee_hash_map_node_free (next), NULL));
 				}
-				(node == NULL) ? NULL : (node = (gee_hash_map_node_free (node), NULL));
-				(next == NULL) ? NULL : (next = (gee_hash_map_node_free (next), NULL));
 			}
 		}
-		_tmp15_ = NULL;
-		_tmp14_ = NULL;
-		self->priv->_nodes = (_tmp15_ = (_tmp14_ = new_nodes, new_nodes = NULL, _tmp14_), self->priv->_nodes = (_vala_array_free (self->priv->_nodes, self->priv->_nodes_length1, (GDestroyNotify) gee_hash_map_node_free), NULL), self->priv->_nodes_length1 = new_nodes_length1, self->priv->_nodes_size = self->priv->_nodes_length1, _tmp15_);
+		_tmp17_ = NULL;
+		_tmp16_ = NULL;
+		self->priv->_nodes = (_tmp17_ = (_tmp16_ = new_nodes, new_nodes = NULL, _tmp16_), self->priv->_nodes = (_vala_array_free (self->priv->_nodes, self->priv->_nodes_length1, (GDestroyNotify) gee_hash_map_node_free), NULL), self->priv->_nodes_length1 = new_nodes_length1, self->priv->_nodes_size = self->priv->_nodes_length1, _tmp17_);
 		self->priv->_array_size = new_array_size;
 		new_nodes = (_vala_array_free (new_nodes, new_nodes_length1, (GDestroyNotify) gee_hash_map_node_free), NULL);
 	}
@@ -703,9 +757,11 @@ static void gee_hash_map_resize (GeeHashMap* self) {
 
 
 static gint gee_hash_map_real_get_size (GeeMap* base) {
+	gint result;
 	GeeHashMap* self;
 	self = (GeeHashMap*) base;
-	return self->priv->_nnodes;
+	result = self->priv->_nnodes;
+	return result;
 }
 
 
@@ -774,20 +830,25 @@ static GeeHashMapKeySet* gee_hash_map_key_set_new (GType k_type, GBoxedCopyFunc
 
 static GType gee_hash_map_key_set_real_get_element_type (GeeIterable* base) {
 	GeeHashMapKeySet * self;
+	GType result;
 	self = (GeeHashMapKeySet*) base;
-	return self->priv->k_type;
+	result = self->priv->k_type;
+	return result;
 }
 
 
 static GeeIterator* gee_hash_map_key_set_real_iterator (GeeIterable* base) {
 	GeeHashMapKeySet * self;
+	GeeIterator* result;
 	self = (GeeHashMapKeySet*) base;
-	return (GeeIterator*) gee_hash_map_key_iterator_new (self->priv->k_type, (GBoxedCopyFunc) self->priv->k_dup_func, self->priv->k_destroy_func, self->priv->v_type, (GBoxedCopyFunc) self->priv->v_dup_func, self->priv->v_destroy_func, self->priv->_map);
+	result = (GeeIterator*) gee_hash_map_key_iterator_new (self->priv->k_type, (GBoxedCopyFunc) self->priv->k_dup_func, self->priv->k_destroy_func, self->priv->v_type, (GBoxedCopyFunc) self->priv->v_dup_func, self->priv->v_destroy_func, self->priv->_map);
+	return result;
 }
 
 
 static gboolean gee_hash_map_key_set_real_add (GeeCollection* base, gconstpointer key) {
 	GeeHashMapKeySet * self;
+	gboolean result;
 	self = (GeeHashMapKeySet*) base;
 	g_assert_not_reached ();
 }
@@ -802,6 +863,7 @@ static void gee_hash_map_key_set_real_clear (GeeCollection* base) {
 
 static gboolean gee_hash_map_key_set_real_remove (GeeCollection* base, gconstpointer key) {
 	GeeHashMapKeySet * self;
+	gboolean result;
 	self = (GeeHashMapKeySet*) base;
 	g_assert_not_reached ();
 }
@@ -809,8 +871,10 @@ static gboolean gee_hash_map_key_set_real_remove (GeeCollection* base, gconstpoi
 
 static gboolean gee_hash_map_key_set_real_contains (GeeCollection* base, gconstpointer key) {
 	GeeHashMapKeySet * self;
+	gboolean result;
 	self = (GeeHashMapKeySet*) base;
-	return gee_map_contains ((GeeMap*) self->priv->_map, key);
+	result = gee_map_contains ((GeeMap*) self->priv->_map, key);
+	return result;
 }
 
 
@@ -825,9 +889,11 @@ static void gee_hash_map_key_set_set_map (GeeHashMapKeySet* self, GeeHashMap* va
 
 
 static gint gee_hash_map_key_set_real_get_size (GeeCollection* base) {
+	gint result;
 	GeeHashMapKeySet* self;
 	self = (GeeHashMapKeySet*) base;
-	return gee_map_get_size ((GeeMap*) self->priv->_map);
+	result = gee_map_get_size ((GeeMap*) self->priv->_map);
+	return result;
 }
 
 
@@ -911,6 +977,7 @@ static GeeHashMapKeyIterator* gee_hash_map_key_iterator_new (GType k_type, GBoxe
 
 static gboolean gee_hash_map_key_iterator_real_next (GeeIterator* base) {
 	GeeHashMapKeyIterator * self;
+	gboolean result;
 	self = (GeeHashMapKeyIterator*) base;
 	if (self->priv->_node != NULL) {
 		self->priv->_node = self->priv->_node->next;
@@ -929,18 +996,21 @@ static gboolean gee_hash_map_key_iterator_real_next (GeeIterator* base) {
 		self->priv->_index++;
 		self->priv->_node = self->priv->_map->priv->_nodes[self->priv->_index];
 	}
-	return self->priv->_node != NULL;
+	result = self->priv->_node != NULL;
+	return result;
 }
 
 
 static gpointer gee_hash_map_key_iterator_real_get (GeeIterator* base) {
 	GeeHashMapKeyIterator * self;
+	gpointer result;
 	gconstpointer _tmp0_;
 	self = (GeeHashMapKeyIterator*) base;
 	g_assert (self->priv->_stamp == self->priv->_map->priv->_stamp);
 	g_assert (self->priv->_node != NULL);
 	_tmp0_ = NULL;
-	return (_tmp0_ = self->priv->_node->key, ((_tmp0_ == NULL) || (self->priv->k_dup_func == NULL)) ? ((gpointer) _tmp0_) : self->priv->k_dup_func ((gpointer) _tmp0_));
+	result = (_tmp0_ = self->priv->_node->key, ((_tmp0_ == NULL) || (self->priv->k_dup_func == NULL)) ? ((gpointer) _tmp0_) : self->priv->k_dup_func ((gpointer) _tmp0_));
+	return result;
 }
 
 
@@ -1017,20 +1087,25 @@ static GeeHashMapValueCollection* gee_hash_map_value_collection_new (GType k_typ
 
 static GType gee_hash_map_value_collection_real_get_element_type (GeeIterable* base) {
 	GeeHashMapValueCollection * self;
+	GType result;
 	self = (GeeHashMapValueCollection*) base;
-	return self->priv->v_type;
+	result = self->priv->v_type;
+	return result;
 }
 
 
 static GeeIterator* gee_hash_map_value_collection_real_iterator (GeeIterable* base) {
 	GeeHashMapValueCollection * self;
+	GeeIterator* result;
 	self = (GeeHashMapValueCollection*) base;
-	return (GeeIterator*) gee_hash_map_value_iterator_new (self->priv->k_type, (GBoxedCopyFunc) self->priv->k_dup_func, self->priv->k_destroy_func, self->priv->v_type, (GBoxedCopyFunc) self->priv->v_dup_func, self->priv->v_destroy_func, self->priv->_map);
+	result = (GeeIterator*) gee_hash_map_value_iterator_new (self->priv->k_type, (GBoxedCopyFunc) self->priv->k_dup_func, self->priv->k_destroy_func, self->priv->v_type, (GBoxedCopyFunc) self->priv->v_dup_func, self->priv->v_destroy_func, self->priv->_map);
+	return result;
 }
 
 
 static gboolean gee_hash_map_value_collection_real_add (GeeCollection* base, gconstpointer value) {
 	GeeHashMapValueCollection * self;
+	gboolean result;
 	self = (GeeHashMapValueCollection*) base;
 	g_assert_not_reached ();
 }
@@ -1045,6 +1120,7 @@ static void gee_hash_map_value_collection_real_clear (GeeCollection* base) {
 
 static gboolean gee_hash_map_value_collection_real_remove (GeeCollection* base, gconstpointer value) {
 	GeeHashMapValueCollection * self;
+	gboolean result;
 	self = (GeeHashMapValueCollection*) base;
 	g_assert_not_reached ();
 }
@@ -1052,20 +1128,26 @@ static gboolean gee_hash_map_value_collection_real_remove (GeeCollection* base,
 
 static gboolean gee_hash_map_value_collection_real_contains (GeeCollection* base, gconstpointer value) {
 	GeeHashMapValueCollection * self;
+	gboolean result;
 	GeeIterator* it;
-	gboolean _tmp3_;
 	self = (GeeHashMapValueCollection*) base;
 	it = gee_iterable_iterator ((GeeIterable*) self);
-	while (gee_iterator_next (it)) {
+	while (TRUE) {
 		gpointer _tmp0_;
 		gboolean _tmp1_;
+		if (!gee_iterator_next (it)) {
+			break;
+		}
 		_tmp0_ = NULL;
 		if ((_tmp1_ = self->priv->_map->priv->_value_equal_func (_tmp0_ = gee_iterator_get (it), value), ((_tmp0_ == NULL) || (self->priv->v_destroy_func == NULL)) ? NULL : (_tmp0_ = (self->priv->v_destroy_func (_tmp0_), NULL)), _tmp1_)) {
-			gboolean _tmp2_;
-			return (_tmp2_ = TRUE, (it == NULL) ? NULL : (it = (gee_collection_object_unref (it), NULL)), _tmp2_);
+			result = TRUE;
+			(it == NULL) ? NULL : (it = (gee_collection_object_unref (it), NULL));
+			return result;
 		}
 	}
-	return (_tmp3_ = FALSE, (it == NULL) ? NULL : (it = (gee_collection_object_unref (it), NULL)), _tmp3_);
+	result = FALSE;
+	(it == NULL) ? NULL : (it = (gee_collection_object_unref (it), NULL));
+	return result;
 }
 
 
@@ -1080,9 +1162,11 @@ static void gee_hash_map_value_collection_set_map (GeeHashMapValueCollection* se
 
 
 static gint gee_hash_map_value_collection_real_get_size (GeeCollection* base) {
+	gint result;
 	GeeHashMapValueCollection* self;
 	self = (GeeHashMapValueCollection*) base;
-	return gee_map_get_size ((GeeMap*) self->priv->_map);
+	result = gee_map_get_size ((GeeMap*) self->priv->_map);
+	return result;
 }
 
 
@@ -1159,6 +1243,7 @@ static GeeHashMapValueIterator* gee_hash_map_value_iterator_new (GType k_type, G
 
 static gboolean gee_hash_map_value_iterator_real_next (GeeIterator* base) {
 	GeeHashMapValueIterator * self;
+	gboolean result;
 	self = (GeeHashMapValueIterator*) base;
 	if (self->priv->_node != NULL) {
 		self->priv->_node = self->priv->_node->next;
@@ -1177,18 +1262,21 @@ static gboolean gee_hash_map_value_iterator_real_next (GeeIterator* base) {
 		self->priv->_index++;
 		self->priv->_node = self->priv->_map->priv->_nodes[self->priv->_index];
 	}
-	return self->priv->_node != NULL;
+	result = self->priv->_node != NULL;
+	return result;
 }
 
 
 static gpointer gee_hash_map_value_iterator_real_get (GeeIterator* base) {
 	GeeHashMapValueIterator * self;
+	gpointer result;
 	gconstpointer _tmp0_;
 	self = (GeeHashMapValueIterator*) base;
 	g_assert (self->priv->_stamp == self->priv->_map->priv->_stamp);
 	g_assert (self->priv->_node != NULL);
 	_tmp0_ = NULL;
-	return (_tmp0_ = self->priv->_node->value, ((_tmp0_ == NULL) || (self->priv->v_dup_func == NULL)) ? ((gpointer) _tmp0_) : self->priv->v_dup_func ((gpointer) _tmp0_));
+	result = (_tmp0_ = self->priv->_node->value, ((_tmp0_ == NULL) || (self->priv->v_dup_func == NULL)) ? ((gpointer) _tmp0_) : self->priv->v_dup_func ((gpointer) _tmp0_));
+	return result;
 }
 
 
