@@ -121,18 +121,13 @@ struct _GeeCollectionObjectClass {
 };
 
 /**
- * A map is a generic collection of key/value pairs.
+ * Implemented by classes that support a simple iteration over instances of the
+ * collection.
  */
-struct _GeeMapIface {
+struct _GeeIteratorIface {
 	GTypeInterface parent_iface;
-	GeeSet* (*get_keys) (GeeMap* self);
-	GeeCollection* (*get_values) (GeeMap* self);
-	gboolean (*contains) (GeeMap* self, gconstpointer key);
-	gpointer (*get) (GeeMap* self, gconstpointer key);
-	void (*set) (GeeMap* self, gconstpointer key, gconstpointer value);
-	gboolean (*remove) (GeeMap* self, gconstpointer key);
-	void (*clear) (GeeMap* self);
-	gint (*get_size) (GeeMap* self);
+	gboolean (*next) (GeeIterator* self);
+	gpointer (*get) (GeeIterator* self);
 };
 
 /**
@@ -145,16 +140,6 @@ struct _GeeIterableIface {
 	GeeIterator* (*iterator) (GeeIterable* self);
 };
 
-/**
- * Implemented by classes that support a simple iteration over instances of the
- * collection.
- */
-struct _GeeIteratorIface {
-	GTypeInterface parent_iface;
-	gboolean (*next) (GeeIterator* self);
-	gpointer (*get) (GeeIterator* self);
-};
-
 /**
  * Serves as the base interface for implementing collection classes. Defines
  * size, iteration, and modification methods.
@@ -175,6 +160,21 @@ struct _GeeSetIface {
 	GTypeInterface parent_iface;
 };
 
+/**
+ * A map is a generic collection of key/value pairs.
+ */
+struct _GeeMapIface {
+	GTypeInterface parent_iface;
+	GeeSet* (*get_keys) (GeeMap* self);
+	GeeCollection* (*get_values) (GeeMap* self);
+	gboolean (*contains) (GeeMap* self, gconstpointer key);
+	gpointer (*get) (GeeMap* self, gconstpointer key);
+	void (*set) (GeeMap* self, gconstpointer key, gconstpointer value);
+	gboolean (*remove) (GeeMap* self, gconstpointer key);
+	void (*clear) (GeeMap* self);
+	gint (*get_size) (GeeMap* self);
+};
+
 /**
  * Represents a read-only collection of key/value pairs.
  */
@@ -198,6 +198,8 @@ struct _GeeReadOnlyMapPrivate {
 };
 
 
+static gpointer gee_read_only_map_parent_class = NULL;
+static GeeMapIface* gee_read_only_map_gee_map_parent_iface = NULL;
 
 gpointer gee_collection_object_ref (gpointer instance);
 void gee_collection_object_unref (gpointer instance);
@@ -218,7 +220,6 @@ enum  {
 void gee_read_only_map_set_map (GeeReadOnlyMap* self, GeeMap* value);
 GeeReadOnlyMap* gee_read_only_map_new (GType k_type, GBoxedCopyFunc k_dup_func, GDestroyNotify k_destroy_func, GType v_type, GBoxedCopyFunc v_dup_func, GDestroyNotify v_destroy_func, GeeMap* map);
 GeeReadOnlyMap* gee_read_only_map_construct (GType object_type, GType k_type, GBoxedCopyFunc k_dup_func, GDestroyNotify k_destroy_func, GType v_type, GBoxedCopyFunc v_dup_func, GDestroyNotify v_destroy_func, GeeMap* map);
-GeeReadOnlyMap* gee_read_only_map_new (GType k_type, GBoxedCopyFunc k_dup_func, GDestroyNotify k_destroy_func, GType v_type, GBoxedCopyFunc v_dup_func, GDestroyNotify v_destroy_func, GeeMap* map);
 GeeReadOnlySet* gee_read_only_set_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GeeSet* set);
 GeeReadOnlySet* gee_read_only_set_construct (GType object_type, GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GeeSet* set);
 GType gee_read_only_set_get_type (void);
@@ -237,8 +238,6 @@ static void gee_read_only_map_real_set (GeeMap* base, gconstpointer key, gconstp
 static gboolean gee_read_only_map_real_remove (GeeMap* base, gconstpointer key);
 static void gee_read_only_map_real_clear (GeeMap* base);
 gint gee_map_get_size (GeeMap* self);
-static gpointer gee_read_only_map_parent_class = NULL;
-static GeeMapIface* gee_read_only_map_gee_map_parent_iface = NULL;
 static void gee_read_only_map_finalize (GeeCollectionObject* obj);
 
 
@@ -264,41 +263,53 @@ GeeReadOnlyMap* gee_read_only_map_new (GType k_type, GBoxedCopyFunc k_dup_func,
 
 static GeeSet* gee_read_only_map_real_get_keys (GeeMap* base) {
 	GeeReadOnlyMap * self;
+	GeeSet* result;
 	self = (GeeReadOnlyMap*) base;
 	if (self->priv->_map == NULL) {
-		return (GeeSet*) gee_read_only_set_new (self->priv->k_type, (GBoxedCopyFunc) self->priv->k_dup_func, self->priv->k_destroy_func, NULL);
+		result = (GeeSet*) gee_read_only_set_new (self->priv->k_type, (GBoxedCopyFunc) self->priv->k_dup_func, self->priv->k_destroy_func, NULL);
+		return result;
 	}
-	return gee_map_get_keys (self->priv->_map);
+	result = gee_map_get_keys (self->priv->_map);
+	return result;
 }
 
 
 static GeeCollection* gee_read_only_map_real_get_values (GeeMap* base) {
 	GeeReadOnlyMap * self;
+	GeeCollection* result;
 	self = (GeeReadOnlyMap*) base;
 	if (self->priv->_map == NULL) {
-		return (GeeCollection*) gee_read_only_collection_new (self->priv->v_type, (GBoxedCopyFunc) self->priv->v_dup_func, self->priv->v_destroy_func, NULL);
+		result = (GeeCollection*) gee_read_only_collection_new (self->priv->v_type, (GBoxedCopyFunc) self->priv->v_dup_func, self->priv->v_destroy_func, NULL);
+		return result;
 	}
-	return gee_map_get_values (self->priv->_map);
+	result = gee_map_get_values (self->priv->_map);
+	return result;
 }
 
 
 static gboolean gee_read_only_map_real_contains (GeeMap* base, gconstpointer key) {
 	GeeReadOnlyMap * self;
+	gboolean result;
 	self = (GeeReadOnlyMap*) base;
 	if (self->priv->_map == NULL) {
-		return FALSE;
+		result = FALSE;
+		return result;
 	}
-	return gee_map_contains (self->priv->_map, key);
+	result = gee_map_contains (self->priv->_map, key);
+	return result;
 }
 
 
 static gpointer gee_read_only_map_real_get (GeeMap* base, gconstpointer key) {
 	GeeReadOnlyMap * self;
+	gpointer result;
 	self = (GeeReadOnlyMap*) base;
 	if (self->priv->_map == NULL) {
-		return NULL;
+		result = NULL;
+		return result;
 	}
-	return gee_map_get (self->priv->_map, key);
+	result = gee_map_get (self->priv->_map, key);
+	return result;
 }
 
 
@@ -311,6 +322,7 @@ static void gee_read_only_map_real_set (GeeMap* base, gconstpointer key, gconstp
 
 static gboolean gee_read_only_map_real_remove (GeeMap* base, gconstpointer key) {
 	GeeReadOnlyMap * self;
+	gboolean result;
 	self = (GeeReadOnlyMap*) base;
 	g_assert_not_reached ();
 }
@@ -324,19 +336,21 @@ static void gee_read_only_map_real_clear (GeeMap* base) {
 
 
 static gint gee_read_only_map_real_get_size (GeeMap* base) {
+	gint result;
 	GeeReadOnlyMap* self;
 	self = (GeeReadOnlyMap*) base;
-	return gee_map_get_size (self->priv->_map);
+	result = gee_map_get_size (self->priv->_map);
+	return result;
 }
 
 
 void gee_read_only_map_set_map (GeeReadOnlyMap* self, GeeMap* value) {
-	GeeMap* _tmp1;
-	GeeMap* _tmp0;
+	GeeMap* _tmp1_;
+	GeeMap* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1 = NULL;
-	_tmp0 = NULL;
-	self->priv->_map = (_tmp1 = (_tmp0 = value, (_tmp0 == NULL) ? NULL : gee_collection_object_ref (_tmp0)), (self->priv->_map == NULL) ? NULL : (self->priv->_map = (gee_collection_object_unref (self->priv->_map), NULL)), _tmp1);
+	_tmp1_ = NULL;
+	_tmp0_ = NULL;
+	self->priv->_map = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : gee_collection_object_ref (_tmp0_)), (self->priv->_map == NULL) ? NULL : (self->priv->_map = (gee_collection_object_unref (self->priv->_map), NULL)), _tmp1_);
 }
 
 
