@@ -107,20 +107,20 @@ struct _GeeCollectionObjectClass {
  * Implemented by classes that support a simple iteration over instances of the
  * collection.
  */
-struct _GeeIterableIface {
+struct _GeeIteratorIface {
 	GTypeInterface parent_iface;
-	GType (*get_element_type) (GeeIterable* self);
-	GeeIterator* (*iterator) (GeeIterable* self);
+	gboolean (*next) (GeeIterator* self);
+	gpointer (*get) (GeeIterator* self);
 };
 
 /**
  * Implemented by classes that support a simple iteration over instances of the
  * collection.
  */
-struct _GeeIteratorIface {
+struct _GeeIterableIface {
 	GTypeInterface parent_iface;
-	gboolean (*next) (GeeIterator* self);
-	gpointer (*get) (GeeIterator* self);
+	GType (*get_element_type) (GeeIterable* self);
+	GeeIterator* (*iterator) (GeeIterable* self);
 };
 
 /**
@@ -178,6 +178,12 @@ struct _GeeReadOnlySetIteratorPrivate {
 };
 
 
+static gpointer gee_read_only_set_iterator_parent_class = NULL;
+static GeeIteratorIface* gee_read_only_set_iterator_gee_iterator_parent_iface = NULL;
+static gpointer gee_read_only_set_parent_class = NULL;
+static GeeIterableIface* gee_read_only_set_gee_iterable_parent_iface = NULL;
+static GeeCollectionIface* gee_read_only_set_gee_collection_parent_iface = NULL;
+static GeeSetIface* gee_read_only_set_gee_set_parent_iface = NULL;
 
 gpointer gee_collection_object_ref (gpointer instance);
 void gee_collection_object_unref (gpointer instance);
@@ -197,7 +203,6 @@ enum  {
 void gee_read_only_set_set_set (GeeReadOnlySet* self, GeeSet* value);
 GeeReadOnlySet* gee_read_only_set_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GeeSet* set);
 GeeReadOnlySet* gee_read_only_set_construct (GType object_type, GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GeeSet* set);
-GeeReadOnlySet* gee_read_only_set_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GeeSet* set);
 static GType gee_read_only_set_real_get_element_type (GeeIterable* base);
 static GeeReadOnlySetIterator* gee_read_only_set_iterator_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func);
 static GeeReadOnlySetIterator* gee_read_only_set_iterator_construct (GType object_type, GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func);
@@ -216,13 +221,6 @@ enum  {
 };
 static gboolean gee_read_only_set_iterator_real_next (GeeIterator* base);
 static gpointer gee_read_only_set_iterator_real_get (GeeIterator* base);
-static GeeReadOnlySetIterator* gee_read_only_set_iterator_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func);
-static gpointer gee_read_only_set_iterator_parent_class = NULL;
-static GeeIteratorIface* gee_read_only_set_iterator_gee_iterator_parent_iface = NULL;
-static gpointer gee_read_only_set_parent_class = NULL;
-static GeeIterableIface* gee_read_only_set_gee_iterable_parent_iface = NULL;
-static GeeCollectionIface* gee_read_only_set_gee_collection_parent_iface = NULL;
-static GeeSetIface* gee_read_only_set_gee_set_parent_iface = NULL;
 static void gee_read_only_set_finalize (GeeCollectionObject* obj);
 
 
@@ -245,33 +243,42 @@ GeeReadOnlySet* gee_read_only_set_new (GType g_type, GBoxedCopyFunc g_dup_func,
 
 static GType gee_read_only_set_real_get_element_type (GeeIterable* base) {
 	GeeReadOnlySet * self;
+	GType result;
 	self = (GeeReadOnlySet*) base;
-	return self->priv->g_type;
+	result = self->priv->g_type;
+	return result;
 }
 
 
 static GeeIterator* gee_read_only_set_real_iterator (GeeIterable* base) {
 	GeeReadOnlySet * self;
+	GeeIterator* result;
 	self = (GeeReadOnlySet*) base;
 	if (self->priv->_set == NULL) {
-		return (GeeIterator*) gee_read_only_set_iterator_new (self->priv->g_type, (GBoxedCopyFunc) self->priv->g_dup_func, self->priv->g_destroy_func);
+		result = (GeeIterator*) gee_read_only_set_iterator_new (self->priv->g_type, (GBoxedCopyFunc) self->priv->g_dup_func, self->priv->g_destroy_func);
+		return result;
 	}
-	return gee_iterable_iterator ((GeeIterable*) self->priv->_set);
+	result = gee_iterable_iterator ((GeeIterable*) self->priv->_set);
+	return result;
 }
 
 
 static gboolean gee_read_only_set_real_contains (GeeCollection* base, gconstpointer item) {
 	GeeReadOnlySet * self;
+	gboolean result;
 	self = (GeeReadOnlySet*) base;
 	if (self->priv->_set == NULL) {
-		return FALSE;
+		result = FALSE;
+		return result;
 	}
-	return gee_collection_contains ((GeeCollection*) self->priv->_set, item);
+	result = gee_collection_contains ((GeeCollection*) self->priv->_set, item);
+	return result;
 }
 
 
 static gboolean gee_read_only_set_real_add (GeeCollection* base, gconstpointer item) {
 	GeeReadOnlySet * self;
+	gboolean result;
 	self = (GeeReadOnlySet*) base;
 	g_assert_not_reached ();
 }
@@ -279,6 +286,7 @@ static gboolean gee_read_only_set_real_add (GeeCollection* base, gconstpointer i
 
 static gboolean gee_read_only_set_real_remove (GeeCollection* base, gconstpointer item) {
 	GeeReadOnlySet * self;
+	gboolean result;
 	self = (GeeReadOnlySet*) base;
 	g_assert_not_reached ();
 }
@@ -292,33 +300,39 @@ static void gee_read_only_set_real_clear (GeeCollection* base) {
 
 
 static gint gee_read_only_set_real_get_size (GeeCollection* base) {
+	gint result;
 	GeeReadOnlySet* self;
 	self = (GeeReadOnlySet*) base;
-	return gee_collection_get_size ((GeeCollection*) self->priv->_set);
+	result = gee_collection_get_size ((GeeCollection*) self->priv->_set);
+	return result;
 }
 
 
 void gee_read_only_set_set_set (GeeReadOnlySet* self, GeeSet* value) {
-	GeeSet* _tmp1;
-	GeeSet* _tmp0;
+	GeeSet* _tmp1_;
+	GeeSet* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1 = NULL;
-	_tmp0 = NULL;
-	self->priv->_set = (_tmp1 = (_tmp0 = value, (_tmp0 == NULL) ? NULL : gee_collection_object_ref (_tmp0)), (self->priv->_set == NULL) ? NULL : (self->priv->_set = (gee_collection_object_unref (self->priv->_set), NULL)), _tmp1);
+	_tmp1_ = NULL;
+	_tmp0_ = NULL;
+	self->priv->_set = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : gee_collection_object_ref (_tmp0_)), (self->priv->_set == NULL) ? NULL : (self->priv->_set = (gee_collection_object_unref (self->priv->_set), NULL)), _tmp1_);
 }
 
 
 static gboolean gee_read_only_set_iterator_real_next (GeeIterator* base) {
 	GeeReadOnlySetIterator * self;
+	gboolean result;
 	self = (GeeReadOnlySetIterator*) base;
-	return FALSE;
+	result = FALSE;
+	return result;
 }
 
 
 static gpointer gee_read_only_set_iterator_real_get (GeeIterator* base) {
 	GeeReadOnlySetIterator * self;
+	gpointer result;
 	self = (GeeReadOnlySetIterator*) base;
-	return NULL;
+	result = NULL;
+	return result;
 }
 
 
