@@ -202,6 +202,8 @@ struct _ValaSymbolClass {
 	char* (*get_lower_case_cname) (ValaSymbol* self, const char* infix);
 	char* (*get_lower_case_cprefix) (ValaSymbol* self);
 	GeeList* (*get_cheader_filenames) (ValaSymbol* self);
+	gboolean (*is_instance_member) (ValaSymbol* self);
+	gboolean (*is_class_member) (ValaSymbol* self);
 };
 
 /**
@@ -243,6 +245,7 @@ struct _ValaArrayMoveMethodClass {
 };
 
 
+static gpointer vala_array_move_method_parent_class = NULL;
 
 gpointer vala_code_node_ref (gpointer instance);
 void vala_code_node_unref (gpointer instance);
@@ -282,8 +285,6 @@ ValaMethod* vala_method_construct (GType object_type, const char* name, ValaData
 void vala_symbol_set_external (ValaSymbol* self, gboolean value);
 ValaArrayMoveMethod* vala_array_move_method_new (ValaSourceReference* source_reference);
 ValaArrayMoveMethod* vala_array_move_method_construct (GType object_type, ValaSourceReference* source_reference);
-ValaArrayMoveMethod* vala_array_move_method_new (ValaSourceReference* source_reference);
-static gpointer vala_array_move_method_parent_class = NULL;
 
 
 
