@@ -88,6 +88,7 @@ struct _ValaParamSpecBasicBlock {
 };
 
 
+static gpointer vala_basic_block_parent_class = NULL;
 
 gpointer vala_basic_block_ref (gpointer instance);
 void vala_basic_block_unref (gpointer instance);
@@ -113,13 +114,10 @@ enum  {
 };
 ValaBasicBlock* vala_basic_block_new (void);
 ValaBasicBlock* vala_basic_block_construct (GType object_type);
-ValaBasicBlock* vala_basic_block_new (void);
 ValaBasicBlock* vala_basic_block_new_entry (void);
 ValaBasicBlock* vala_basic_block_construct_entry (GType object_type);
-ValaBasicBlock* vala_basic_block_new_entry (void);
 ValaBasicBlock* vala_basic_block_new_exit (void);
 ValaBasicBlock* vala_basic_block_construct_exit (GType object_type);
-ValaBasicBlock* vala_basic_block_new_exit (void);
 void vala_basic_block_add_node (ValaBasicBlock* self, ValaCodeNode* node);
 GeeList* vala_basic_block_get_nodes (ValaBasicBlock* self);
 void vala_basic_block_connect (ValaBasicBlock* self, ValaBasicBlock* target);
@@ -133,7 +131,6 @@ GeeSet* vala_basic_block_get_dominator_frontier (ValaBasicBlock* self);
 void vala_basic_block_add_phi_function (ValaBasicBlock* self, ValaPhiFunction* phi);
 GeeSet* vala_basic_block_get_phi_functions (ValaBasicBlock* self);
 ValaBasicBlock* vala_basic_block_get_parent (ValaBasicBlock* self);
-static gpointer vala_basic_block_parent_class = NULL;
 static void vala_basic_block_finalize (ValaBasicBlock* obj);
 
 
@@ -182,10 +179,12 @@ void vala_basic_block_add_node (ValaBasicBlock* self, ValaCodeNode* node) {
 
 
 GeeList* vala_basic_block_get_nodes (ValaBasicBlock* self) {
+	GeeList* result;
 	GeeList* _tmp0_;
 	g_return_val_if_fail (self != NULL, NULL);
 	_tmp0_ = NULL;
-	return (_tmp0_ = self->priv->nodes, (_tmp0_ == NULL) ? NULL : gee_collection_object_ref (_tmp0_));
+	result = (_tmp0_ = self->priv->nodes, (_tmp0_ == NULL) ? NULL : gee_collection_object_ref (_tmp0_));
+	return result;
 }
 
 
@@ -202,14 +201,18 @@ void vala_basic_block_connect (ValaBasicBlock* self, ValaBasicBlock* target) {
 
 
 GeeList* vala_basic_block_get_predecessors (ValaBasicBlock* self) {
+	GeeList* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return (GeeList*) gee_read_only_list_new (VALA_TYPE_BASIC_BLOCK, NULL, NULL, self->priv->predecessors);
+	result = (GeeList*) gee_read_only_list_new (VALA_TYPE_BASIC_BLOCK, NULL, NULL, self->priv->predecessors);
+	return result;
 }
 
 
 GeeList* vala_basic_block_get_successors (ValaBasicBlock* self) {
+	GeeList* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return (GeeList*) gee_read_only_list_new (VALA_TYPE_BASIC_BLOCK, NULL, NULL, self->priv->successors);
+	result = (GeeList*) gee_read_only_list_new (VALA_TYPE_BASIC_BLOCK, NULL, NULL, self->priv->successors);
+	return result;
 }
 
 
@@ -222,10 +225,12 @@ void vala_basic_block_add_child (ValaBasicBlock* self, ValaBasicBlock* block) {
 
 
 GeeList* vala_basic_block_get_children (ValaBasicBlock* self) {
+	GeeList* result;
 	GeeList* _tmp0_;
 	g_return_val_if_fail (self != NULL, NULL);
 	_tmp0_ = NULL;
-	return (_tmp0_ = self->priv->children, (_tmp0_ == NULL) ? NULL : gee_collection_object_ref (_tmp0_));
+	result = (_tmp0_ = self->priv->children, (_tmp0_ == NULL) ? NULL : gee_collection_object_ref (_tmp0_));
+	return result;
 }
 
 
@@ -237,10 +242,12 @@ void vala_basic_block_add_dominator_frontier (ValaBasicBlock* self, ValaBasicBlo
 
 
 GeeSet* vala_basic_block_get_dominator_frontier (ValaBasicBlock* self) {
+	GeeSet* result;
 	GeeSet* _tmp0_;
 	g_return_val_if_fail (self != NULL, NULL);
 	_tmp0_ = NULL;
-	return (_tmp0_ = self->priv->df, (_tmp0_ == NULL) ? NULL : gee_collection_object_ref (_tmp0_));
+	result = (_tmp0_ = self->priv->df, (_tmp0_ == NULL) ? NULL : gee_collection_object_ref (_tmp0_));
+	return result;
 }
 
 
@@ -252,26 +259,30 @@ void vala_basic_block_add_phi_function (ValaBasicBlock* self, ValaPhiFunction* p
 
 
 GeeSet* vala_basic_block_get_phi_functions (ValaBasicBlock* self) {
+	GeeSet* result;
 	GeeSet* _tmp0_;
 	g_return_val_if_fail (self != NULL, NULL);
 	_tmp0_ = NULL;
-	return (_tmp0_ = self->priv->phi_functions, (_tmp0_ == NULL) ? NULL : gee_collection_object_ref (_tmp0_));
+	result = (_tmp0_ = self->priv->phi_functions, (_tmp0_ == NULL) ? NULL : gee_collection_object_ref (_tmp0_));
+	return result;
 }
 
 
 ValaBasicBlock* vala_basic_block_get_parent (ValaBasicBlock* self) {
+	ValaBasicBlock* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_parent;
+	result = self->priv->_parent;
+	return result;
 }
 
 
 static void vala_basic_block_set_parent (ValaBasicBlock* self, ValaBasicBlock* value) {
-	ValaBasicBlock* _tmp2_;
 	ValaBasicBlock* _tmp1_;
+	ValaBasicBlock* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2_ = NULL;
 	_tmp1_ = NULL;
-	self->priv->_parent = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_basic_block_ref (_tmp1_)), (self->priv->_parent == NULL) ? NULL : (self->priv->_parent = (vala_basic_block_unref (self->priv->_parent), NULL)), _tmp2_);
+	_tmp0_ = NULL;
+	self->priv->_parent = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_basic_block_ref (_tmp0_)), (self->priv->_parent == NULL) ? NULL : (self->priv->_parent = (vala_basic_block_unref (self->priv->_parent), NULL)), _tmp1_);
 }
 
 
