@@ -265,6 +265,7 @@ struct _ValaBooleanTypeClass {
 };
 
 
+static gpointer vala_boolean_type_parent_class = NULL;
 
 gpointer vala_code_node_ref (gpointer instance);
 void vala_code_node_unref (gpointer instance);
@@ -302,7 +303,6 @@ ValaValueType* vala_value_type_construct (GType object_type, ValaTypeSymbol* typ
 GType vala_struct_get_type (void);
 ValaBooleanType* vala_boolean_type_new (ValaStruct* type_symbol);
 ValaBooleanType* vala_boolean_type_construct (GType object_type, ValaStruct* type_symbol);
-ValaBooleanType* vala_boolean_type_new (ValaStruct* type_symbol);
 ValaTypeSymbol* vala_value_type_get_type_symbol (ValaValueType* self);
 gpointer vala_source_reference_ref (gpointer instance);
 void vala_source_reference_unref (gpointer instance);
@@ -317,7 +317,6 @@ void vala_data_type_set_value_owned (ValaDataType* self, gboolean value);
 gboolean vala_data_type_get_nullable (ValaDataType* self);
 void vala_data_type_set_nullable (ValaDataType* self, gboolean value);
 static ValaDataType* vala_boolean_type_real_copy (ValaDataType* base);
-static gpointer vala_boolean_type_parent_class = NULL;
 
 
 
@@ -336,13 +335,15 @@ ValaBooleanType* vala_boolean_type_new (ValaStruct* type_symbol) {
 
 static ValaDataType* vala_boolean_type_real_copy (ValaDataType* base) {
 	ValaBooleanType * self;
+	ValaDataType* result;
 	ValaBooleanType* _result_;
 	self = (ValaBooleanType*) base;
 	_result_ = vala_boolean_type_new (VALA_STRUCT (vala_value_type_get_type_symbol ((ValaValueType*) self)));
 	vala_code_node_set_source_reference ((ValaCodeNode*) _result_, vala_code_node_get_source_reference ((ValaCodeNode*) self));
 	vala_data_type_set_value_owned ((ValaDataType*) _result_, vala_data_type_get_value_owned ((ValaDataType*) self));
 	vala_data_type_set_nullable ((ValaDataType*) _result_, vala_data_type_get_nullable ((ValaDataType*) self));
-	return (ValaDataType*) _result_;
+	result = (ValaDataType*) _result_;
+	return result;
 }
 
 
