@@ -200,6 +200,9 @@ struct _ValaParamSpecCodeContext {
 };
 
 
+static GStaticPrivate vala_code_context_context_stack_key;
+static GStaticPrivate vala_code_context_context_stack_key = {0};
+static gpointer vala_code_context_parent_class = NULL;
 
 gpointer vala_code_context_ref (gpointer instance);
 void vala_code_context_unref (gpointer instance);
@@ -246,8 +249,6 @@ gpointer vala_value_get_source_reference (const GValue* value);
 GType vala_source_reference_get_type (void);
 ValaNamespace* vala_namespace_new (const char* name, ValaSourceReference* source_reference);
 ValaNamespace* vala_namespace_construct (GType object_type, const char* name, ValaSourceReference* source_reference);
-static GStaticPrivate vala_code_context_context_stack_key;
-static GStaticPrivate vala_code_context_context_stack_key = {0};
 ValaCodeGenerator* vala_code_generator_new (void);
 ValaCodeGenerator* vala_code_generator_construct (GType object_type);
 gint vala_code_context_get_target_glib_major (ValaCodeContext* self);
@@ -255,7 +256,6 @@ gint vala_code_context_get_target_glib_minor (ValaCodeContext* self);
 gboolean vala_code_context_require_glib_version (ValaCodeContext* self, gint major, gint minor);
 ValaCodeContext* vala_code_context_new (void);
 ValaCodeContext* vala_code_context_construct (GType object_type);
-ValaCodeContext* vala_code_context_new (void);
 ValaCodeContext* vala_code_context_get (void);
 void vala_code_context_push (ValaCodeContext* context);
 void vala_code_context_pop (void);
@@ -320,7 +320,6 @@ ValaReport* vala_code_context_get_report (ValaCodeContext* self);
 void vala_code_context_set_report (ValaCodeContext* self, ValaReport* value);
 ValaCodeGenerator* vala_code_context_get_codegen (ValaCodeContext* self);
 void vala_code_context_set_codegen (ValaCodeContext* self, ValaCodeGenerator* value);
-static gpointer vala_code_context_parent_class = NULL;
 static void vala_code_context_finalize (ValaCodeContext* obj);
 static gint _vala_array_length (gpointer array);
 
@@ -331,6 +330,7 @@ static gint _vala_array_length (gpointer array);
  * equal to the specified version.
  */
 gboolean vala_code_context_require_glib_version (ValaCodeContext* self, gint major, gint minor) {
+	gboolean result;
 	gboolean _tmp0_;
 	g_return_val_if_fail (self != NULL, FALSE);
 	_tmp0_ = FALSE;
@@ -346,7 +346,8 @@ gboolean vala_code_context_require_glib_version (ValaCodeContext* self, gint maj
 		}
 		_tmp0_ = _tmp1_;
 	}
-	return _tmp0_;
+	result = _tmp0_;
+	return result;
 }
 
 
@@ -366,9 +367,11 @@ ValaCodeContext* vala_code_context_new (void) {
  * Return the topmost context from the context stack.
  */
 ValaCodeContext* vala_code_context_get (void) {
+	ValaCodeContext* result;
 	GeeList* context_stack;
 	context_stack = g_static_private_get (&vala_code_context_context_stack_key);
-	return (ValaCodeContext*) gee_list_get (context_stack, gee_collection_get_size ((GeeCollection*) context_stack) - 1);
+	result = (ValaCodeContext*) gee_list_get (context_stack, gee_collection_get_size ((GeeCollection*) context_stack) - 1);
+	return result;
 }
 
 
@@ -403,8 +406,10 @@ void vala_code_context_pop (void) {
  * @return list of source files
  */
 GeeList* vala_code_context_get_source_files (ValaCodeContext* self) {
+	GeeList* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return (GeeList*) gee_read_only_list_new (VALA_TYPE_SOURCE_FILE, (GBoxedCopyFunc) vala_source_file_ref, vala_source_file_unref, self->priv->source_files);
+	result = (GeeList*) gee_read_only_list_new (VALA_TYPE_SOURCE_FILE, (GBoxedCopyFunc) vala_source_file_ref, vala_source_file_unref, self->priv->source_files);
+	return result;
 }
 
 
@@ -414,8 +419,10 @@ GeeList* vala_code_context_get_source_files (ValaCodeContext* self) {
  * @return list of C source files
  */
 GeeList* vala_code_context_get_c_source_files (ValaCodeContext* self) {
+	GeeList* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return (GeeList*) gee_read_only_list_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, self->priv->c_source_files);
+	result = (GeeList*) gee_read_only_list_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, self->priv->c_source_files);
+	return result;
 }
 
 
@@ -449,8 +456,10 @@ void vala_code_context_add_c_source_file (ValaCodeContext* self, const char* fil
  * @return list of used packages
  */
 GeeList* vala_code_context_get_packages (ValaCodeContext* self) {
+	GeeList* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return (GeeList*) gee_read_only_list_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, self->priv->packages);
+	result = (GeeList*) gee_read_only_list_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, self->priv->packages);
+	return result;
 }
 
 
@@ -461,9 +470,11 @@ GeeList* vala_code_context_get_packages (ValaCodeContext* self) {
  * @return    true if the specified package is being used
  */
 gboolean vala_code_context_has_package (ValaCodeContext* self, const char* pkg) {
+	gboolean result;
 	g_return_val_if_fail (self != NULL, FALSE);
 	g_return_val_if_fail (pkg != NULL, FALSE);
-	return gee_collection_contains ((GeeCollection*) self->priv->packages, pkg);
+	result = gee_collection_contains ((GeeCollection*) self->priv->packages, pkg);
+	return result;
 }
 
 
@@ -491,8 +502,11 @@ void vala_code_context_accept (ValaCodeContext* self, ValaCodeVisitor* visitor)
 	{
 		GeeIterator* _file_it;
 		_file_it = gee_iterable_iterator ((GeeIterable*) self->priv->source_files);
-		while (gee_iterator_next (_file_it)) {
+		while (TRUE) {
 			ValaSourceFile* file;
+			if (!gee_iterator_next (_file_it)) {
+				break;
+			}
 			file = (ValaSourceFile*) gee_iterator_get (_file_it);
 			vala_source_file_accept (file, visitor);
 			(file == NULL) ? NULL : (file = (vala_source_file_unref (file), NULL));
@@ -510,17 +524,19 @@ void vala_code_context_add_define (ValaCodeContext* self, const char* define) {
 
 
 gboolean vala_code_context_is_defined (ValaCodeContext* self, const char* define) {
+	gboolean result;
 	g_return_val_if_fail (self != NULL, FALSE);
 	g_return_val_if_fail (define != NULL, FALSE);
-	return gee_collection_contains ((GeeCollection*) self->priv->defines, define);
+	result = gee_collection_contains ((GeeCollection*) self->priv->defines, define);
+	return result;
 }
 
 
 char* vala_code_context_get_package_path (ValaCodeContext* self, const char* pkg, char** vapi_directories, int vapi_directories_length1) {
+	char* result;
 	char* basename;
 	char* filename;
-	char* _tmp3_;
-	char* _tmp9_;
+	char* _tmp2_;
 	g_return_val_if_fail (self != NULL, NULL);
 	g_return_val_if_fail (pkg != NULL, NULL);
 	basename = g_strdup_printf ("%s.vapi", pkg);
@@ -533,65 +549,71 @@ char* vala_code_context_get_package_path (ValaCodeContext* self, const char* pkg
 			vapidir_collection = vapi_directories;
 			vapidir_collection_length1 = vapi_directories_length1;
 			for (vapidir_it = 0; vapidir_it < vapi_directories_length1; vapidir_it = vapidir_it + 1) {
-				const char* _tmp2_;
+				const char* _tmp1_;
 				char* vapidir;
-				_tmp2_ = NULL;
-				vapidir = (_tmp2_ = vapidir_collection[vapidir_it], (_tmp2_ == NULL) ? NULL : g_strdup (_tmp2_));
+				_tmp1_ = NULL;
+				vapidir = (_tmp1_ = vapidir_collection[vapidir_it], (_tmp1_ == NULL) ? NULL : g_strdup (_tmp1_));
 				{
 					char* _tmp0_;
 					_tmp0_ = NULL;
 					filename = (_tmp0_ = g_build_filename (vapidir, basename, NULL), filename = (g_free (filename), NULL), _tmp0_);
 					if (g_file_test (filename, G_FILE_TEST_EXISTS)) {
-						char* _tmp1_;
-						_tmp1_ = NULL;
-						return (_tmp1_ = filename, vapidir = (g_free (vapidir), NULL), basename = (g_free (basename), NULL), _tmp1_);
+						result = filename;
+						vapidir = (g_free (vapidir), NULL);
+						basename = (g_free (basename), NULL);
+						return result;
 					}
 					vapidir = (g_free (vapidir), NULL);
 				}
 			}
 		}
 	}
-	_tmp3_ = NULL;
-	filename = (_tmp3_ = g_build_filename (PACKAGE_DATADIR, "vapi", basename, NULL), filename = (g_free (filename), NULL), _tmp3_);
+	_tmp2_ = NULL;
+	filename = (_tmp2_ = g_build_filename (PACKAGE_DATADIR, "vapi", basename, NULL), filename = (g_free (filename), NULL), _tmp2_);
 	if (g_file_test (filename, G_FILE_TEST_EXISTS)) {
-		char* _tmp4_;
-		_tmp4_ = NULL;
-		return (_tmp4_ = filename, basename = (g_free (basename), NULL), _tmp4_);
+		result = filename;
+		basename = (g_free (basename), NULL);
+		return result;
 	}
 	{
-		char** _tmp5_;
+		char** _tmp3_;
 		char** vapidir_collection;
 		int vapidir_collection_length1;
 		int vapidir_it;
-		_tmp5_ = NULL;
-		vapidir_collection = _tmp5_ = g_get_system_data_dirs ();
-		vapidir_collection_length1 = _vala_array_length (_tmp5_);
-		for (vapidir_it = 0; vapidir_it < _vala_array_length (_tmp5_); vapidir_it = vapidir_it + 1) {
-			const char* _tmp8_;
+		_tmp3_ = NULL;
+		vapidir_collection = _tmp3_ = g_get_system_data_dirs ();
+		vapidir_collection_length1 = _vala_array_length (_tmp3_);
+		for (vapidir_it = 0; vapidir_it < _vala_array_length (_tmp3_); vapidir_it = vapidir_it + 1) {
+			const char* _tmp5_;
 			char* vapidir;
-			_tmp8_ = NULL;
-			vapidir = (_tmp8_ = vapidir_collection[vapidir_it], (_tmp8_ == NULL) ? NULL : g_strdup (_tmp8_));
+			_tmp5_ = NULL;
+			vapidir = (_tmp5_ = vapidir_collection[vapidir_it], (_tmp5_ == NULL) ? NULL : g_strdup (_tmp5_));
 			{
-				char* _tmp6_;
-				_tmp6_ = NULL;
-				filename = (_tmp6_ = g_build_filename (vapidir, "vala/vapi", basename, NULL), filename = (g_free (filename), NULL), _tmp6_);
+				char* _tmp4_;
+				_tmp4_ = NULL;
+				filename = (_tmp4_ = g_build_filename (vapidir, "vala/vapi", basename, NULL), filename = (g_free (filename), NULL), _tmp4_);
 				if (g_file_test (filename, G_FILE_TEST_EXISTS)) {
-					char* _tmp7_;
-					_tmp7_ = NULL;
-					return (_tmp7_ = filename, vapidir = (g_free (vapidir), NULL), basename = (g_free (basename), NULL), _tmp7_);
+					result = filename;
+					vapidir = (g_free (vapidir), NULL);
+					basename = (g_free (basename), NULL);
+					return result;
 				}
 				vapidir = (g_free (vapidir), NULL);
 			}
 		}
 	}
-	_tmp9_ = NULL;
-	return (_tmp9_ = NULL, basename = (g_free (basename), NULL), filename = (g_free (filename), NULL), _tmp9_);
+	result = NULL;
+	basename = (g_free (basename), NULL);
+	filename = (g_free (filename), NULL);
+	return result;
 }
 
 
 gboolean vala_code_context_get_assert (ValaCodeContext* self) {
+	gboolean result;
 	g_return_val_if_fail (self != NULL, FALSE);
-	return self->priv->_assert;
+	result = self->priv->_assert;
+	return result;
 }
 
 
@@ -602,8 +624,10 @@ void vala_code_context_set_assert (ValaCodeContext* self, gboolean value) {
 
 
 gboolean vala_code_context_get_checking (ValaCodeContext* self) {
+	gboolean result;
 	g_return_val_if_fail (self != NULL, FALSE);
-	return self->priv->_checking;
+	result = self->priv->_checking;
+	return result;
 }
 
 
@@ -614,8 +638,10 @@ void vala_code_context_set_checking (ValaCodeContext* self, gboolean value) {
 
 
 gboolean vala_code_context_get_deprecated (ValaCodeContext* self) {
+	gboolean result;
 	g_return_val_if_fail (self != NULL, FALSE);
-	return self->priv->_deprecated;
+	result = self->priv->_deprecated;
+	return result;
 }
 
 
@@ -626,8 +652,10 @@ void vala_code_context_set_deprecated (ValaCodeContext* self, gboolean value) {
 
 
 gboolean vala_code_context_get_experimental (ValaCodeContext* self) {
+	gboolean result;
 	g_return_val_if_fail (self != NULL, FALSE);
-	return self->priv->_experimental;
+	result = self->priv->_experimental;
+	return result;
 }
 
 
@@ -638,8 +666,10 @@ void vala_code_context_set_experimental (ValaCodeContext* self, gboolean value)
 
 
 gboolean vala_code_context_get_non_null_experimental (ValaCodeContext* self) {
+	gboolean result;
 	g_return_val_if_fail (self != NULL, FALSE);
-	return self->priv->_non_null_experimental;
+	result = self->priv->_non_null_experimental;
+	return result;
 }
 
 
@@ -650,8 +680,10 @@ void vala_code_context_set_non_null_experimental (ValaCodeContext* self, gboolea
 
 
 gboolean vala_code_context_get_dbus_transformation (ValaCodeContext* self) {
+	gboolean result;
 	g_return_val_if_fail (self != NULL, FALSE);
-	return self->priv->_dbus_transformation;
+	result = self->priv->_dbus_transformation;
+	return result;
 }
 
 
@@ -662,8 +694,10 @@ void vala_code_context_set_dbus_transformation (ValaCodeContext* self, gboolean
 
 
 gboolean vala_code_context_get_ccode_only (ValaCodeContext* self) {
+	gboolean result;
 	g_return_val_if_fail (self != NULL, FALSE);
-	return self->priv->_ccode_only;
+	result = self->priv->_ccode_only;
+	return result;
 }
 
 
@@ -674,40 +708,46 @@ void vala_code_context_set_ccode_only (ValaCodeContext* self, gboolean value) {
 
 
 const char* vala_code_context_get_header_filename (ValaCodeContext* self) {
+	const char* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_header_filename;
+	result = self->priv->_header_filename;
+	return result;
 }
 
 
 void vala_code_context_set_header_filename (ValaCodeContext* self, const char* value) {
-	char* _tmp2_;
-	const char* _tmp1_;
+	char* _tmp1_;
+	const char* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2_ = NULL;
 	_tmp1_ = NULL;
-	self->priv->_header_filename = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : g_strdup (_tmp1_)), self->priv->_header_filename = (g_free (self->priv->_header_filename), NULL), _tmp2_);
+	_tmp0_ = NULL;
+	self->priv->_header_filename = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_)), self->priv->_header_filename = (g_free (self->priv->_header_filename), NULL), _tmp1_);
 }
 
 
 const char* vala_code_context_get_internal_header_filename (ValaCodeContext* self) {
+	const char* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_internal_header_filename;
+	result = self->priv->_internal_header_filename;
+	return result;
 }
 
 
 void vala_code_context_set_internal_header_filename (ValaCodeContext* self, const char* value) {
-	char* _tmp2_;
-	const char* _tmp1_;
+	char* _tmp1_;
+	const char* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2_ = NULL;
 	_tmp1_ = NULL;
-	self->priv->_internal_header_filename = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : g_strdup (_tmp1_)), self->priv->_internal_header_filename = (g_free (self->priv->_internal_header_filename), NULL), _tmp2_);
+	_tmp0_ = NULL;
+	self->priv->_internal_header_filename = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_)), self->priv->_internal_header_filename = (g_free (self->priv->_internal_header_filename), NULL), _tmp1_);
 }
 
 
 gboolean vala_code_context_get_compile_only (ValaCodeContext* self) {
+	gboolean result;
 	g_return_val_if_fail (self != NULL, FALSE);
-	return self->priv->_compile_only;
+	result = self->priv->_compile_only;
+	return result;
 }
 
 
@@ -718,56 +758,64 @@ void vala_code_context_set_compile_only (ValaCodeContext* self, gboolean value)
 
 
 const char* vala_code_context_get_output (ValaCodeContext* self) {
+	const char* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_output;
+	result = self->priv->_output;
+	return result;
 }
 
 
 void vala_code_context_set_output (ValaCodeContext* self, const char* value) {
-	char* _tmp2_;
-	const char* _tmp1_;
+	char* _tmp1_;
+	const char* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2_ = NULL;
 	_tmp1_ = NULL;
-	self->priv->_output = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : g_strdup (_tmp1_)), self->priv->_output = (g_free (self->priv->_output), NULL), _tmp2_);
+	_tmp0_ = NULL;
+	self->priv->_output = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_)), self->priv->_output = (g_free (self->priv->_output), NULL), _tmp1_);
 }
 
 
 const char* vala_code_context_get_basedir (ValaCodeContext* self) {
+	const char* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_basedir;
+	result = self->priv->_basedir;
+	return result;
 }
 
 
 void vala_code_context_set_basedir (ValaCodeContext* self, const char* value) {
-	char* _tmp2_;
-	const char* _tmp1_;
+	char* _tmp1_;
+	const char* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2_ = NULL;
 	_tmp1_ = NULL;
-	self->priv->_basedir = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : g_strdup (_tmp1_)), self->priv->_basedir = (g_free (self->priv->_basedir), NULL), _tmp2_);
+	_tmp0_ = NULL;
+	self->priv->_basedir = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_)), self->priv->_basedir = (g_free (self->priv->_basedir), NULL), _tmp1_);
 }
 
 
 const char* vala_code_context_get_directory (ValaCodeContext* self) {
+	const char* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_directory;
+	result = self->priv->_directory;
+	return result;
 }
 
 
 void vala_code_context_set_directory (ValaCodeContext* self, const char* value) {
-	char* _tmp2_;
-	const char* _tmp1_;
+	char* _tmp1_;
+	const char* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2_ = NULL;
 	_tmp1_ = NULL;
-	self->priv->_directory = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : g_strdup (_tmp1_)), self->priv->_directory = (g_free (self->priv->_directory), NULL), _tmp2_);
+	_tmp0_ = NULL;
+	self->priv->_directory = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_)), self->priv->_directory = (g_free (self->priv->_directory), NULL), _tmp1_);
 }
 
 
 gboolean vala_code_context_get_debug (ValaCodeContext* self) {
+	gboolean result;
 	g_return_val_if_fail (self != NULL, FALSE);
-	return self->priv->_debug;
+	result = self->priv->_debug;
+	return result;
 }
 
 
@@ -778,8 +826,10 @@ void vala_code_context_set_debug (ValaCodeContext* self, gboolean value) {
 
 
 gint vala_code_context_get_optlevel (ValaCodeContext* self) {
+	gint result;
 	g_return_val_if_fail (self != NULL, 0);
-	return self->priv->_optlevel;
+	result = self->priv->_optlevel;
+	return result;
 }
 
 
@@ -790,8 +840,10 @@ void vala_code_context_set_optlevel (ValaCodeContext* self, gint value) {
 
 
 gboolean vala_code_context_get_thread (ValaCodeContext* self) {
+	gboolean result;
 	g_return_val_if_fail (self != NULL, FALSE);
-	return self->priv->_thread;
+	result = self->priv->_thread;
+	return result;
 }
 
 
@@ -802,24 +854,28 @@ void vala_code_context_set_thread (ValaCodeContext* self, gboolean value) {
 
 
 ValaMethod* vala_code_context_get_module_init_method (ValaCodeContext* self) {
+	ValaMethod* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_module_init_method;
+	result = self->priv->_module_init_method;
+	return result;
 }
 
 
 void vala_code_context_set_module_init_method (ValaCodeContext* self, ValaMethod* value) {
-	ValaMethod* _tmp2_;
 	ValaMethod* _tmp1_;
+	ValaMethod* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2_ = NULL;
 	_tmp1_ = NULL;
-	self->priv->_module_init_method = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_)), (self->priv->_module_init_method == NULL) ? NULL : (self->priv->_module_init_method = (vala_code_node_unref (self->priv->_module_init_method), NULL)), _tmp2_);
+	_tmp0_ = NULL;
+	self->priv->_module_init_method = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_)), (self->priv->_module_init_method == NULL) ? NULL : (self->priv->_module_init_method = (vala_code_node_unref (self->priv->_module_init_method), NULL)), _tmp1_);
 }
 
 
 gboolean vala_code_context_get_save_temps (ValaCodeContext* self) {
+	gboolean result;
 	g_return_val_if_fail (self != NULL, FALSE);
-	return self->priv->_save_temps;
+	result = self->priv->_save_temps;
+	return result;
 }
 
 
@@ -830,8 +886,10 @@ void vala_code_context_set_save_temps (ValaCodeContext* self, gboolean value) {
 
 
 ValaProfile vala_code_context_get_profile (ValaCodeContext* self) {
+	ValaProfile result;
 	g_return_val_if_fail (self != NULL, 0);
-	return self->priv->_profile;
+	result = self->priv->_profile;
+	return result;
 }
 
 
@@ -842,8 +900,10 @@ void vala_code_context_set_profile (ValaCodeContext* self, ValaProfile value) {
 
 
 gint vala_code_context_get_target_glib_major (ValaCodeContext* self) {
+	gint result;
 	g_return_val_if_fail (self != NULL, 0);
-	return self->priv->_target_glib_major;
+	result = self->priv->_target_glib_major;
+	return result;
 }
 
 
@@ -854,8 +914,10 @@ void vala_code_context_set_target_glib_major (ValaCodeContext* self, gint value)
 
 
 gint vala_code_context_get_target_glib_minor (ValaCodeContext* self) {
+	gint result;
 	g_return_val_if_fail (self != NULL, 0);
-	return self->priv->_target_glib_minor;
+	result = self->priv->_target_glib_minor;
+	return result;
 }
 
 
@@ -866,8 +928,10 @@ void vala_code_context_set_target_glib_minor (ValaCodeContext* self, gint value)
 
 
 gboolean vala_code_context_get_verbose_mode (ValaCodeContext* self) {
+	gboolean result;
 	g_return_val_if_fail (self != NULL, FALSE);
-	return self->priv->_verbose_mode;
+	result = self->priv->_verbose_mode;
+	return result;
 }
 
 
@@ -878,46 +942,54 @@ void vala_code_context_set_verbose_mode (ValaCodeContext* self, gboolean value)
 
 
 gboolean vala_code_context_get_save_csources (ValaCodeContext* self) {
+	gboolean result;
 	g_return_val_if_fail (self != NULL, FALSE);
-	return self->priv->_save_temps;
+	result = self->priv->_save_temps;
+	return result;
 }
 
 
 ValaReport* vala_code_context_get_report (ValaCodeContext* self) {
+	ValaReport* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_report;
+	result = self->priv->_report;
+	return result;
 }
 
 
 void vala_code_context_set_report (ValaCodeContext* self, ValaReport* value) {
-	ValaReport* _tmp2_;
 	ValaReport* _tmp1_;
+	ValaReport* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2_ = NULL;
 	_tmp1_ = NULL;
-	self->priv->_report = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : g_object_ref (_tmp1_)), (self->priv->_report == NULL) ? NULL : (self->priv->_report = (g_object_unref (self->priv->_report), NULL)), _tmp2_);
+	_tmp0_ = NULL;
+	self->priv->_report = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : g_object_ref (_tmp0_)), (self->priv->_report == NULL) ? NULL : (self->priv->_report = (g_object_unref (self->priv->_report), NULL)), _tmp1_);
 }
 
 
 ValaNamespace* vala_code_context_get_root (ValaCodeContext* self) {
+	ValaNamespace* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_root;
+	result = self->priv->_root;
+	return result;
 }
 
 
 ValaCodeGenerator* vala_code_context_get_codegen (ValaCodeContext* self) {
+	ValaCodeGenerator* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_codegen;
+	result = self->priv->_codegen;
+	return result;
 }
 
 
 void vala_code_context_set_codegen (ValaCodeContext* self, ValaCodeGenerator* value) {
-	ValaCodeGenerator* _tmp2_;
 	ValaCodeGenerator* _tmp1_;
+	ValaCodeGenerator* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2_ = NULL;
 	_tmp1_ = NULL;
-	self->priv->_codegen = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_code_visitor_ref (_tmp1_)), (self->priv->_codegen == NULL) ? NULL : (self->priv->_codegen = (vala_code_visitor_unref (self->priv->_codegen), NULL)), _tmp2_);
+	_tmp0_ = NULL;
+	self->priv->_codegen = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_code_visitor_ref (_tmp0_)), (self->priv->_codegen == NULL) ? NULL : (self->priv->_codegen = (vala_code_visitor_unref (self->priv->_codegen), NULL)), _tmp1_);
 }
 
 
