@@ -187,6 +187,8 @@ struct _ValaDeclarationStatementPrivate {
 };
 
 
+static gpointer vala_declaration_statement_parent_class = NULL;
+static ValaStatementIface* vala_declaration_statement_vala_statement_parent_iface = NULL;
 
 gpointer vala_code_node_ref (gpointer instance);
 void vala_code_node_unref (gpointer instance);
@@ -222,7 +224,6 @@ GType vala_source_reference_get_type (void);
 void vala_code_node_set_source_reference (ValaCodeNode* self, ValaSourceReference* value);
 ValaDeclarationStatement* vala_declaration_statement_new (ValaSymbol* declaration, ValaSourceReference* source_reference);
 ValaDeclarationStatement* vala_declaration_statement_construct (GType object_type, ValaSymbol* declaration, ValaSourceReference* source_reference);
-ValaDeclarationStatement* vala_declaration_statement_new (ValaSymbol* declaration, ValaSourceReference* source_reference);
 void vala_code_visitor_visit_declaration_statement (ValaCodeVisitor* self, ValaDeclarationStatement* stmt);
 static void vala_declaration_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 ValaSymbol* vala_declaration_statement_get_declaration (ValaDeclarationStatement* self);
@@ -243,8 +244,6 @@ static void vala_declaration_statement_real_get_defined_variables (ValaCodeNode*
 void vala_code_node_get_used_variables (ValaCodeNode* self, GeeCollection* collection);
 static void vala_declaration_statement_real_get_used_variables (ValaCodeNode* base, GeeCollection* collection);
 void vala_code_node_set_parent_node (ValaCodeNode* self, ValaCodeNode* value);
-static gpointer vala_declaration_statement_parent_class = NULL;
-static ValaStatementIface* vala_declaration_statement_vala_statement_parent_iface = NULL;
 static void vala_declaration_statement_finalize (ValaCodeNode* obj);
 
 
@@ -289,38 +288,42 @@ static void vala_declaration_statement_real_accept_children (ValaCodeNode* base,
 
 static gboolean vala_declaration_statement_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer) {
 	ValaDeclarationStatement * self;
-	ValaLocalVariable* _tmp2_;
-	ValaSymbol* _tmp1_;
+	gboolean result;
+	ValaLocalVariable* _tmp1_;
+	ValaSymbol* _tmp0_;
 	ValaLocalVariable* local;
-	gboolean _tmp3_;
-	gboolean _tmp6_;
+	gboolean _tmp2_;
 	self = (ValaDeclarationStatement*) base;
 	g_return_val_if_fail (analyzer != NULL, FALSE);
 	if (vala_code_node_get_checked ((ValaCodeNode*) self)) {
-		return !vala_code_node_get_error ((ValaCodeNode*) self);
+		result = !vala_code_node_get_error ((ValaCodeNode*) self);
+		return result;
 	}
 	vala_code_node_set_checked ((ValaCodeNode*) self, TRUE);
 	vala_code_node_check ((ValaCodeNode*) vala_declaration_statement_get_declaration (self), analyzer);
-	_tmp2_ = NULL;
 	_tmp1_ = NULL;
-	local = (_tmp2_ = (_tmp1_ = vala_declaration_statement_get_declaration (self), VALA_IS_LOCAL_VARIABLE (_tmp1_) ? ((ValaLocalVariable*) _tmp1_) : NULL), (_tmp2_ == NULL) ? NULL : vala_code_node_ref (_tmp2_));
-	_tmp3_ = FALSE;
+	_tmp0_ = NULL;
+	local = (_tmp1_ = (_tmp0_ = vala_declaration_statement_get_declaration (self), VALA_IS_LOCAL_VARIABLE (_tmp0_) ? ((ValaLocalVariable*) _tmp0_) : NULL), (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_));
+	_tmp2_ = FALSE;
 	if (local != NULL) {
-		_tmp3_ = vala_local_variable_get_initializer (local) != NULL;
+		_tmp2_ = vala_local_variable_get_initializer (local) != NULL;
 	} else {
-		_tmp3_ = FALSE;
+		_tmp2_ = FALSE;
 	}
-	if (_tmp3_) {
+	if (_tmp2_) {
 		{
-			GeeList* _tmp4_;
-			GeeIterator* _tmp5_;
+			GeeList* _tmp3_;
+			GeeIterator* _tmp4_;
 			GeeIterator* _error_type_it;
+			_tmp3_ = NULL;
 			_tmp4_ = NULL;
-			_tmp5_ = NULL;
-			_error_type_it = (_tmp5_ = gee_iterable_iterator ((GeeIterable*) (_tmp4_ = vala_code_node_get_error_types ((ValaCodeNode*) vala_local_variable_get_initializer (local)))), (_tmp4_ == NULL) ? NULL : (_tmp4_ = (gee_collection_object_unref (_tmp4_), NULL)), _tmp5_);
-			while (gee_iterator_next (_error_type_it)) {
+			_error_type_it = (_tmp4_ = gee_iterable_iterator ((GeeIterable*) (_tmp3_ = vala_code_node_get_error_types ((ValaCodeNode*) vala_local_variable_get_initializer (local)))), (_tmp3_ == NULL) ? NULL : (_tmp3_ = (gee_collection_object_unref (_tmp3_), NULL)), _tmp4_);
+			while (TRUE) {
 				ValaDataType* error_type;
 				ValaDataType* initializer_error_type;
+				if (!gee_iterator_next (_error_type_it)) {
+					break;
+				}
 				error_type = (ValaDataType*) gee_iterator_get (_error_type_it);
 				/* ensure we can trace back which expression may throw errors of this type*/
 				initializer_error_type = vala_data_type_copy (error_type);
@@ -332,7 +335,9 @@ static gboolean vala_declaration_statement_real_check (ValaCodeNode* base, ValaS
 			(_error_type_it == NULL) ? NULL : (_error_type_it = (gee_collection_object_unref (_error_type_it), NULL));
 		}
 	}
-	return (_tmp6_ = !vala_code_node_get_error ((ValaCodeNode*) self), (local == NULL) ? NULL : (local = (vala_code_node_unref (local), NULL)), _tmp6_);
+	result = !vala_code_node_get_error ((ValaCodeNode*) self);
+	(local == NULL) ? NULL : (local = (vala_code_node_unref (local), NULL));
+	return result;
 }
 
 
@@ -386,18 +391,20 @@ static void vala_declaration_statement_real_get_used_variables (ValaCodeNode* ba
 
 
 ValaSymbol* vala_declaration_statement_get_declaration (ValaDeclarationStatement* self) {
+	ValaSymbol* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_declaration;
+	result = self->priv->_declaration;
+	return result;
 }
 
 
 void vala_declaration_statement_set_declaration (ValaDeclarationStatement* self, ValaSymbol* value) {
-	ValaSymbol* _tmp2_;
 	ValaSymbol* _tmp1_;
+	ValaSymbol* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2_ = NULL;
 	_tmp1_ = NULL;
-	self->priv->_declaration = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_)), (self->priv->_declaration == NULL) ? NULL : (self->priv->_declaration = (vala_code_node_unref (self->priv->_declaration), NULL)), _tmp2_);
+	_tmp0_ = NULL;
+	self->priv->_declaration = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_)), (self->priv->_declaration == NULL) ? NULL : (self->priv->_declaration = (vala_code_node_unref (self->priv->_declaration), NULL)), _tmp1_);
 	if (self->priv->_declaration != NULL) {
 		vala_code_node_set_parent_node ((ValaCodeNode*) self->priv->_declaration, (ValaCodeNode*) self);
 	}
