@@ -202,6 +202,8 @@ struct _ValaSymbolClass {
 	char* (*get_lower_case_cname) (ValaSymbol* self, const char* infix);
 	char* (*get_lower_case_cprefix) (ValaSymbol* self);
 	GeeList* (*get_cheader_filenames) (ValaSymbol* self);
+	gboolean (*is_instance_member) (ValaSymbol* self);
+	gboolean (*is_class_member) (ValaSymbol* self);
 };
 
 /**
@@ -249,6 +251,9 @@ struct _ValaDynamicMethodPrivate {
 };
 
 
+static gint vala_dynamic_method_dynamic_method_id;
+static gint vala_dynamic_method_dynamic_method_id = 0;
+static gpointer vala_dynamic_method_parent_class = NULL;
 
 gpointer vala_code_node_ref (gpointer instance);
 void vala_code_node_unref (gpointer instance);
@@ -276,8 +281,6 @@ GType vala_method_call_get_type (void);
 enum  {
 	VALA_DYNAMIC_METHOD_DUMMY_PROPERTY
 };
-static gint vala_dynamic_method_dynamic_method_id;
-static gint vala_dynamic_method_dynamic_method_id = 0;
 gpointer vala_source_reference_ref (gpointer instance);
 void vala_source_reference_unref (gpointer instance);
 GParamSpec* vala_param_spec_source_reference (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
@@ -289,7 +292,6 @@ ValaMethod* vala_method_construct (GType object_type, const char* name, ValaData
 void vala_dynamic_method_set_dynamic_type (ValaDynamicMethod* self, ValaDataType* value);
 ValaDynamicMethod* vala_dynamic_method_new (ValaDataType* dynamic_type, const char* name, ValaDataType* return_type, ValaSourceReference* source_reference);
 ValaDynamicMethod* vala_dynamic_method_construct (GType object_type, ValaDataType* dynamic_type, const char* name, ValaDataType* return_type, ValaSourceReference* source_reference);
-ValaDynamicMethod* vala_dynamic_method_new (ValaDataType* dynamic_type, const char* name, ValaDataType* return_type, ValaSourceReference* source_reference);
 static GeeList* vala_dynamic_method_real_get_cheader_filenames (ValaSymbol* base);
 const char* vala_symbol_get_name (ValaSymbol* self);
 static char* vala_dynamic_method_real_get_default_cname (ValaMethod* base);
@@ -297,7 +299,6 @@ static gboolean vala_dynamic_method_real_check (ValaCodeNode* base, ValaSemantic
 ValaDataType* vala_dynamic_method_get_dynamic_type (ValaDynamicMethod* self);
 ValaMethodCall* vala_dynamic_method_get_invocation (ValaDynamicMethod* self);
 void vala_dynamic_method_set_invocation (ValaDynamicMethod* self, ValaMethodCall* value);
-static gpointer vala_dynamic_method_parent_class = NULL;
 static void vala_dynamic_method_finalize (ValaCodeNode* obj);
 
 
@@ -320,13 +321,16 @@ ValaDynamicMethod* vala_dynamic_method_new (ValaDataType* dynamic_type, const ch
 
 static GeeList* vala_dynamic_method_real_get_cheader_filenames (ValaSymbol* base) {
 	ValaDynamicMethod * self;
+	GeeList* result;
 	self = (ValaDynamicMethod*) base;
-	return (GeeList*) gee_array_list_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, g_direct_equal);
+	result = (GeeList*) gee_array_list_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, g_direct_equal);
+	return result;
 }
 
 
 static char* vala_dynamic_method_real_get_default_cname (ValaMethod* base) {
 	ValaDynamicMethod * self;
+	char* result;
 	const char* _tmp1_;
 	self = (ValaDynamicMethod*) base;
 	/* return cname of wrapper method*/
@@ -336,47 +340,54 @@ static char* vala_dynamic_method_real_get_default_cname (ValaMethod* base) {
 		self->priv->cname = (_tmp0_ = g_strdup_printf ("_dynamic_%s%d", vala_symbol_get_name ((ValaSymbol*) self), vala_dynamic_method_dynamic_method_id++), self->priv->cname = (g_free (self->priv->cname), NULL), _tmp0_);
 	}
 	_tmp1_ = NULL;
-	return (_tmp1_ = self->priv->cname, (_tmp1_ == NULL) ? NULL : g_strdup (_tmp1_));
+	result = (_tmp1_ = self->priv->cname, (_tmp1_ == NULL) ? NULL : g_strdup (_tmp1_));
+	return result;
 }
 
 
 static gboolean vala_dynamic_method_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer) {
 	ValaDynamicMethod * self;
+	gboolean result;
 	self = (ValaDynamicMethod*) base;
 	g_return_val_if_fail (analyzer != NULL, FALSE);
-	return TRUE;
+	result = TRUE;
+	return result;
 }
 
 
 ValaDataType* vala_dynamic_method_get_dynamic_type (ValaDynamicMethod* self) {
+	ValaDataType* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_dynamic_type;
+	result = self->priv->_dynamic_type;
+	return result;
 }
 
 
 void vala_dynamic_method_set_dynamic_type (ValaDynamicMethod* self, ValaDataType* value) {
-	ValaDataType* _tmp2_;
 	ValaDataType* _tmp1_;
+	ValaDataType* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2_ = NULL;
 	_tmp1_ = NULL;
-	self->priv->_dynamic_type = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_)), (self->priv->_dynamic_type == NULL) ? NULL : (self->priv->_dynamic_type = (vala_code_node_unref (self->priv->_dynamic_type), NULL)), _tmp2_);
+	_tmp0_ = NULL;
+	self->priv->_dynamic_type = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_)), (self->priv->_dynamic_type == NULL) ? NULL : (self->priv->_dynamic_type = (vala_code_node_unref (self->priv->_dynamic_type), NULL)), _tmp1_);
 }
 
 
 ValaMethodCall* vala_dynamic_method_get_invocation (ValaDynamicMethod* self) {
+	ValaMethodCall* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_invocation;
+	result = self->priv->_invocation;
+	return result;
 }
 
 
 void vala_dynamic_method_set_invocation (ValaDynamicMethod* self, ValaMethodCall* value) {
-	ValaMethodCall* _tmp2_;
 	ValaMethodCall* _tmp1_;
+	ValaMethodCall* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2_ = NULL;
 	_tmp1_ = NULL;
-	self->priv->_invocation = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_)), (self->priv->_invocation == NULL) ? NULL : (self->priv->_invocation = (vala_code_node_unref (self->priv->_invocation), NULL)), _tmp2_);
+	_tmp0_ = NULL;
+	self->priv->_invocation = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_)), (self->priv->_invocation == NULL) ? NULL : (self->priv->_invocation = (vala_code_node_unref (self->priv->_invocation), NULL)), _tmp1_);
 }
 
 
