@@ -261,6 +261,8 @@ struct _ValaSymbolClass {
 	char* (*get_lower_case_cname) (ValaSymbol* self, const char* infix);
 	char* (*get_lower_case_cprefix) (ValaSymbol* self);
 	GeeList* (*get_cheader_filenames) (ValaSymbol* self);
+	gboolean (*is_instance_member) (ValaSymbol* self);
+	gboolean (*is_class_member) (ValaSymbol* self);
 };
 
 /**
@@ -317,6 +319,8 @@ struct _ValaFieldPrivate {
 };
 
 
+static gpointer vala_field_parent_class = NULL;
+static ValaLockableIface* vala_field_vala_lockable_parent_iface = NULL;
 
 gpointer vala_code_node_ref (gpointer instance);
 void vala_code_node_unref (gpointer instance);
@@ -356,7 +360,6 @@ void vala_field_set_field_type (ValaField* self, ValaDataType* value);
 void vala_field_set_initializer (ValaField* self, ValaExpression* value);
 ValaField* vala_field_new (const char* name, ValaDataType* field_type, ValaExpression* initializer, ValaSourceReference* source_reference);
 ValaField* vala_field_construct (GType object_type, const char* name, ValaDataType* field_type, ValaExpression* initializer, ValaSourceReference* source_reference);
-ValaField* vala_field_new (const char* name, ValaDataType* field_type, ValaExpression* initializer, ValaSourceReference* source_reference);
 void vala_code_visitor_visit_member (ValaCodeVisitor* self, ValaMember* m);
 void vala_code_visitor_visit_field (ValaCodeVisitor* self, ValaField* f);
 static void vala_field_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
@@ -421,6 +424,9 @@ void vala_report_error (ValaSourceReference* source, const char* message);
 char* vala_code_node_to_string (ValaCodeNode* self);
 char* vala_symbol_get_full_name (ValaSymbol* self);
 void vala_expression_set_target_type (ValaExpression* self, ValaDataType* value);
+ValaDataType* vala_expression_get_value_type (ValaExpression* self);
+gboolean vala_data_type_compatible (ValaDataType* self, ValaDataType* target_type);
+gboolean vala_symbol_get_external (ValaSymbol* self);
 GType vala_typesymbol_get_type (void);
 GType vala_object_type_symbol_get_type (void);
 GType vala_interface_get_type (void);
@@ -441,8 +447,6 @@ gboolean vala_field_get_no_delegate_target (ValaField* self);
 gboolean vala_field_get_array_null_terminated (ValaField* self);
 gboolean vala_field_get_has_array_length_cname (ValaField* self);
 gboolean vala_field_get_has_array_length_cexpr (ValaField* self);
-static gpointer vala_field_parent_class = NULL;
-static ValaLockableIface* vala_field_vala_lockable_parent_iface = NULL;
 static void vala_field_finalize (ValaCodeNode* obj);
 static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
@@ -502,6 +506,7 @@ static void vala_field_real_accept_children (ValaCodeNode* base, ValaCodeVisitor
  * @return the name to be used in C code
  */
 char* vala_field_get_cname (ValaField* self) {
+	char* result;
 	const char* _tmp1_;
 	g_return_val_if_fail (self != NULL, NULL);
 	if (self->priv->cname == NULL) {
@@ -510,7 +515,8 @@ char* vala_field_get_cname (ValaField* self) {
 		self->priv->cname = (_tmp0_ = vala_field_get_default_cname (self), self->priv->cname = (g_free (self->priv->cname), NULL), _tmp0_);
 	}
 	_tmp1_ = NULL;
-	return (_tmp1_ = self->priv->cname, (_tmp1_ == NULL) ? NULL : g_strdup (_tmp1_));
+	result = (_tmp1_ = self->priv->cname, (_tmp1_ == NULL) ? NULL : g_strdup (_tmp1_));
+	return result;
 }
 
 
@@ -536,17 +542,20 @@ void vala_field_set_cname (ValaField* self, const char* cname) {
  * @return the name to be used in C code by default
  */
 char* vala_field_get_default_cname (ValaField* self) {
+	char* result;
 	g_return_val_if_fail (self != NULL, NULL);
 	if (self->priv->_binding == MEMBER_BINDING_STATIC) {
 		char* _tmp0_;
 		char* _tmp1_;
 		_tmp0_ = NULL;
 		_tmp1_ = NULL;
-		return (_tmp1_ = g_strconcat (_tmp0_ = vala_symbol_get_lower_case_cprefix (vala_symbol_get_parent_symbol ((ValaSymbol*) self)), vala_symbol_get_name ((ValaSymbol*) self), NULL), _tmp0_ = (g_free (_tmp0_), NULL), _tmp1_);
+		result = (_tmp1_ = g_strconcat (_tmp0_ = vala_symbol_get_lower_case_cprefix (vala_symbol_get_parent_symbol ((ValaSymbol*) self)), vala_symbol_get_name ((ValaSymbol*) self), NULL), _tmp0_ = (g_free (_tmp0_), NULL), _tmp1_);
+		return result;
 	} else {
-		const char* _tmp3_;
-		_tmp3_ = NULL;
-		return (_tmp3_ = vala_symbol_get_name ((ValaSymbol*) self), (_tmp3_ == NULL) ? NULL : g_strdup (_tmp3_));
+		const char* _tmp2_;
+		_tmp2_ = NULL;
+		result = (_tmp2_ = vala_symbol_get_name ((ValaSymbol*) self), (_tmp2_ == NULL) ? NULL : g_strdup (_tmp2_));
+		return result;
 	}
 }
 
@@ -557,10 +566,12 @@ char* vala_field_get_default_cname (ValaField* self) {
  * @return the name of the array length field to be used in C code
  */
 char* vala_field_get_array_length_cname (ValaField* self) {
+	char* result;
 	const char* _tmp0_;
 	g_return_val_if_fail (self != NULL, NULL);
 	_tmp0_ = NULL;
-	return (_tmp0_ = self->priv->array_length_cname, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_));
+	result = (_tmp0_ = self->priv->array_length_cname, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_));
+	return result;
 }
 
 
@@ -586,10 +597,12 @@ void vala_field_set_array_length_cname (ValaField* self, const char* array_lengt
  * @return the array length expression to be used in C code
  */
 char* vala_field_get_array_length_cexpr (ValaField* self) {
+	char* result;
 	const char* _tmp0_;
 	g_return_val_if_fail (self != NULL, NULL);
 	_tmp0_ = NULL;
-	return (_tmp0_ = self->priv->array_length_cexpr, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_));
+	result = (_tmp0_ = self->priv->array_length_cexpr, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_));
+	return result;
 }
 
 
@@ -694,8 +707,10 @@ void vala_field_process_attributes (ValaField* self) {
 
 static gboolean vala_field_real_get_lock_used (ValaLockable* base) {
 	ValaField * self;
+	gboolean result;
 	self = (ValaField*) base;
-	return self->priv->lock_used;
+	result = self->priv->lock_used;
+	return result;
 }
 
 
@@ -729,17 +744,18 @@ static void vala_field_real_replace_type (ValaCodeNode* base, ValaDataType* old_
 
 
 char* vala_field_get_ctype (ValaField* self) {
+	char* result;
 	ValaAttribute* attr;
-	char* _tmp1_;
 	g_return_val_if_fail (self != NULL, NULL);
 	attr = vala_code_node_get_attribute ((ValaCodeNode*) self, "CCode");
 	if (attr == NULL) {
-		char* _tmp0_;
-		_tmp0_ = NULL;
-		return (_tmp0_ = NULL, (attr == NULL) ? NULL : (attr = (vala_code_node_unref (attr), NULL)), _tmp0_);
+		result = NULL;
+		(attr == NULL) ? NULL : (attr = (vala_code_node_unref (attr), NULL));
+		return result;
 	}
-	_tmp1_ = NULL;
-	return (_tmp1_ = vala_attribute_get_string (attr, "type"), (attr == NULL) ? NULL : (attr = (vala_code_node_unref (attr), NULL)), _tmp1_);
+	result = vala_attribute_get_string (attr, "type");
+	(attr == NULL) ? NULL : (attr = (vala_code_node_unref (attr), NULL));
+	return result;
 }
 
 
@@ -769,25 +785,26 @@ void vala_field_set_ctype (ValaField* self, const char* ctype) {
 
 static gboolean vala_field_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer) {
 	ValaField * self;
-	ValaSourceFile* _tmp1_;
+	gboolean result;
+	ValaSourceFile* _tmp0_;
 	ValaSourceFile* old_source_file;
-	ValaSymbol* _tmp2_;
+	ValaSymbol* _tmp1_;
 	ValaSymbol* old_symbol;
-	gboolean _tmp7_;
+	gboolean _tmp8_;
 	gboolean field_in_header;
 	gboolean _tmp11_;
 	gboolean _tmp12_;
-	gboolean _tmp18_;
 	self = (ValaField*) base;
 	g_return_val_if_fail (analyzer != NULL, FALSE);
 	if (vala_code_node_get_checked ((ValaCodeNode*) self)) {
-		return !vala_code_node_get_error ((ValaCodeNode*) self);
+		result = !vala_code_node_get_error ((ValaCodeNode*) self);
+		return result;
 	}
 	vala_code_node_set_checked ((ValaCodeNode*) self, TRUE);
+	_tmp0_ = NULL;
+	old_source_file = (_tmp0_ = vala_semantic_analyzer_get_current_source_file (analyzer), (_tmp0_ == NULL) ? NULL : vala_source_file_ref (_tmp0_));
 	_tmp1_ = NULL;
-	old_source_file = (_tmp1_ = vala_semantic_analyzer_get_current_source_file (analyzer), (_tmp1_ == NULL) ? NULL : vala_source_file_ref (_tmp1_));
-	_tmp2_ = NULL;
-	old_symbol = (_tmp2_ = vala_semantic_analyzer_get_current_symbol (analyzer), (_tmp2_ == NULL) ? NULL : vala_code_node_ref (_tmp2_));
+	old_symbol = (_tmp1_ = vala_semantic_analyzer_get_current_symbol (analyzer), (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_));
 	if (vala_code_node_get_source_reference ((ValaCodeNode*) self) != NULL) {
 		vala_semantic_analyzer_set_current_source_file (analyzer, vala_source_reference_get_file (vala_code_node_get_source_reference ((ValaCodeNode*) self)));
 	}
@@ -795,36 +812,61 @@ static gboolean vala_field_real_check (ValaCodeNode* base, ValaSemanticAnalyzer*
 	vala_code_node_check ((ValaCodeNode*) vala_field_get_field_type (self), analyzer);
 	/* check whether field type is at least as accessible as the field*/
 	if (!vala_semantic_analyzer_is_type_accessible (analyzer, (ValaSymbol*) self, vala_field_get_field_type (self))) {
-		char* _tmp5_;
 		char* _tmp4_;
 		char* _tmp3_;
-		gboolean _tmp6_;
+		char* _tmp2_;
 		vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
-		_tmp5_ = NULL;
 		_tmp4_ = NULL;
 		_tmp3_ = NULL;
-		vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp5_ = g_strdup_printf ("field type `%s` is less accessible than field `%s`", _tmp3_ = vala_code_node_to_string ((ValaCodeNode*) vala_field_get_field_type (self)), _tmp4_ = vala_symbol_get_full_name ((ValaSymbol*) self)));
-		_tmp5_ = (g_free (_tmp5_), NULL);
+		_tmp2_ = NULL;
+		vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp4_ = g_strdup_printf ("field type `%s` is less accessible than field `%s`", _tmp2_ = vala_code_node_to_string ((ValaCodeNode*) vala_field_get_field_type (self)), _tmp3_ = vala_symbol_get_full_name ((ValaSymbol*) self)));
 		_tmp4_ = (g_free (_tmp4_), NULL);
 		_tmp3_ = (g_free (_tmp3_), NULL);
-		return (_tmp6_ = FALSE, (old_source_file == NULL) ? NULL : (old_source_file = (vala_source_file_unref (old_source_file), NULL)), (old_symbol == NULL) ? NULL : (old_symbol = (vala_code_node_unref (old_symbol), NULL)), _tmp6_);
+		_tmp2_ = (g_free (_tmp2_), NULL);
+		result = FALSE;
+		(old_source_file == NULL) ? NULL : (old_source_file = (vala_source_file_unref (old_source_file), NULL));
+		(old_symbol == NULL) ? NULL : (old_symbol = (vala_code_node_unref (old_symbol), NULL));
+		return result;
 	}
 	vala_field_process_attributes (self);
 	if (vala_field_get_initializer (self) != NULL) {
 		vala_expression_set_target_type (vala_field_get_initializer (self), vala_field_get_field_type (self));
 		vala_code_node_check ((ValaCodeNode*) vala_field_get_initializer (self), analyzer);
+		if (!vala_data_type_compatible (vala_expression_get_value_type (vala_field_get_initializer (self)), vala_field_get_field_type (self))) {
+			char* _tmp7_;
+			char* _tmp6_;
+			char* _tmp5_;
+			vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
+			_tmp7_ = NULL;
+			_tmp6_ = NULL;
+			_tmp5_ = NULL;
+			vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp7_ = g_strdup_printf ("Cannot convert from `%s' to `%s'", _tmp5_ = vala_code_node_to_string ((ValaCodeNode*) vala_expression_get_value_type (vala_field_get_initializer (self))), _tmp6_ = vala_code_node_to_string ((ValaCodeNode*) vala_field_get_field_type (self))));
+			_tmp7_ = (g_free (_tmp7_), NULL);
+			_tmp6_ = (g_free (_tmp6_), NULL);
+			_tmp5_ = (g_free (_tmp5_), NULL);
+			result = FALSE;
+			(old_source_file == NULL) ? NULL : (old_source_file = (vala_source_file_unref (old_source_file), NULL));
+			(old_symbol == NULL) ? NULL : (old_symbol = (vala_code_node_unref (old_symbol), NULL));
+			return result;
+		}
+		if (vala_symbol_get_external ((ValaSymbol*) self)) {
+			vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
+			vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), "External fields cannot use initializers");
+		}
 	}
-	_tmp7_ = FALSE;
+	_tmp8_ = FALSE;
 	if (self->priv->_binding == MEMBER_BINDING_INSTANCE) {
-		_tmp7_ = VALA_IS_INTERFACE (vala_symbol_get_parent_symbol ((ValaSymbol*) self));
+		_tmp8_ = VALA_IS_INTERFACE (vala_symbol_get_parent_symbol ((ValaSymbol*) self));
 	} else {
-		_tmp7_ = FALSE;
+		_tmp8_ = FALSE;
 	}
-	if (_tmp7_) {
-		gboolean _tmp8_;
+	if (_tmp8_) {
 		vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
 		vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), "Interfaces may not have instance fields");
-		return (_tmp8_ = FALSE, (old_source_file == NULL) ? NULL : (old_source_file = (vala_source_file_unref (old_source_file), NULL)), (old_symbol == NULL) ? NULL : (old_symbol = (vala_code_node_unref (old_symbol), NULL)), _tmp8_);
+		result = FALSE;
+		(old_source_file == NULL) ? NULL : (old_source_file = (vala_source_file_unref (old_source_file), NULL));
+		(old_symbol == NULL) ? NULL : (old_symbol = (vala_code_node_unref (old_symbol), NULL));
+		return result;
 	}
 	field_in_header = !vala_symbol_is_internal_symbol ((ValaSymbol*) self);
 	if (VALA_IS_CLASS (vala_symbol_get_parent_symbol ((ValaSymbol*) self))) {
@@ -877,40 +919,47 @@ static gboolean vala_field_real_check (ValaCodeNode* base, ValaSemanticAnalyzer*
 	}
 	vala_semantic_analyzer_set_current_source_file (analyzer, old_source_file);
 	vala_semantic_analyzer_set_current_symbol (analyzer, old_symbol);
-	return (_tmp18_ = !vala_code_node_get_error ((ValaCodeNode*) self), (old_source_file == NULL) ? NULL : (old_source_file = (vala_source_file_unref (old_source_file), NULL)), (old_symbol == NULL) ? NULL : (old_symbol = (vala_code_node_unref (old_symbol), NULL)), _tmp18_);
+	result = !vala_code_node_get_error ((ValaCodeNode*) self);
+	(old_source_file == NULL) ? NULL : (old_source_file = (vala_source_file_unref (old_source_file), NULL));
+	(old_symbol == NULL) ? NULL : (old_symbol = (vala_code_node_unref (old_symbol), NULL));
+	return result;
 }
 
 
 ValaDataType* vala_field_get_field_type (ValaField* self) {
+	ValaDataType* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_data_type;
+	result = self->priv->_data_type;
+	return result;
 }
 
 
 void vala_field_set_field_type (ValaField* self, ValaDataType* value) {
-	ValaDataType* _tmp2_;
 	ValaDataType* _tmp1_;
+	ValaDataType* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2_ = NULL;
 	_tmp1_ = NULL;
-	self->priv->_data_type = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_)), (self->priv->_data_type == NULL) ? NULL : (self->priv->_data_type = (vala_code_node_unref (self->priv->_data_type), NULL)), _tmp2_);
+	_tmp0_ = NULL;
+	self->priv->_data_type = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_)), (self->priv->_data_type == NULL) ? NULL : (self->priv->_data_type = (vala_code_node_unref (self->priv->_data_type), NULL)), _tmp1_);
 	vala_code_node_set_parent_node ((ValaCodeNode*) self->priv->_data_type, (ValaCodeNode*) self);
 }
 
 
 ValaExpression* vala_field_get_initializer (ValaField* self) {
+	ValaExpression* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_initializer;
+	result = self->priv->_initializer;
+	return result;
 }
 
 
 void vala_field_set_initializer (ValaField* self, ValaExpression* value) {
-	ValaExpression* _tmp2_;
 	ValaExpression* _tmp1_;
+	ValaExpression* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2_ = NULL;
 	_tmp1_ = NULL;
-	self->priv->_initializer = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_)), (self->priv->_initializer == NULL) ? NULL : (self->priv->_initializer = (vala_code_node_unref (self->priv->_initializer), NULL)), _tmp2_);
+	_tmp0_ = NULL;
+	self->priv->_initializer = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_)), (self->priv->_initializer == NULL) ? NULL : (self->priv->_initializer = (vala_code_node_unref (self->priv->_initializer), NULL)), _tmp1_);
 	if (self->priv->_initializer != NULL) {
 		vala_code_node_set_parent_node ((ValaCodeNode*) self->priv->_initializer, (ValaCodeNode*) self);
 	}
@@ -918,8 +967,10 @@ void vala_field_set_initializer (ValaField* self, ValaExpression* value) {
 
 
 MemberBinding vala_field_get_binding (ValaField* self) {
+	MemberBinding result;
 	g_return_val_if_fail (self != NULL, 0);
-	return self->priv->_binding;
+	result = self->priv->_binding;
+	return result;
 }
 
 
@@ -930,8 +981,10 @@ void vala_field_set_binding (ValaField* self, MemberBinding value) {
 
 
 gboolean vala_field_get_is_volatile (ValaField* self) {
+	gboolean result;
 	g_return_val_if_fail (self != NULL, FALSE);
-	return self->priv->_is_volatile;
+	result = self->priv->_is_volatile;
+	return result;
 }
 
 
@@ -942,8 +995,10 @@ void vala_field_set_is_volatile (ValaField* self, gboolean value) {
 
 
 gboolean vala_field_get_no_array_length (ValaField* self) {
+	gboolean result;
 	g_return_val_if_fail (self != NULL, FALSE);
-	return self->priv->_no_array_length;
+	result = self->priv->_no_array_length;
+	return result;
 }
 
 
@@ -954,8 +1009,10 @@ void vala_field_set_no_array_length (ValaField* self, gboolean value) {
 
 
 gboolean vala_field_get_no_delegate_target (ValaField* self) {
+	gboolean result;
 	g_return_val_if_fail (self != NULL, FALSE);
-	return self->priv->_no_delegate_target;
+	result = self->priv->_no_delegate_target;
+	return result;
 }
 
 
@@ -966,8 +1023,10 @@ void vala_field_set_no_delegate_target (ValaField* self, gboolean value) {
 
 
 gboolean vala_field_get_array_null_terminated (ValaField* self) {
+	gboolean result;
 	g_return_val_if_fail (self != NULL, FALSE);
-	return self->priv->_array_null_terminated;
+	result = self->priv->_array_null_terminated;
+	return result;
 }
 
 
@@ -978,14 +1037,18 @@ void vala_field_set_array_null_terminated (ValaField* self, gboolean value) {
 
 
 gboolean vala_field_get_has_array_length_cname (ValaField* self) {
+	gboolean result;
 	g_return_val_if_fail (self != NULL, FALSE);
-	return self->priv->array_length_cname != NULL;
+	result = self->priv->array_length_cname != NULL;
+	return result;
 }
 
 
 gboolean vala_field_get_has_array_length_cexpr (ValaField* self) {
+	gboolean result;
 	g_return_val_if_fail (self != NULL, FALSE);
-	return self->priv->array_length_cexpr != NULL;
+	result = self->priv->array_length_cexpr != NULL;
+	return result;
 }
 
 
