@@ -468,6 +468,16 @@ typedef struct _ValaSwitchSectionClass ValaSwitchSectionClass;
 typedef struct _ValaSwitchLabel ValaSwitchLabel;
 typedef struct _ValaSwitchLabelClass ValaSwitchLabelClass;
 
+#define VALA_TYPE_LOOP (vala_loop_get_type ())
+#define VALA_LOOP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_LOOP, ValaLoop))
+#define VALA_LOOP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_LOOP, ValaLoopClass))
+#define VALA_IS_LOOP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_LOOP))
+#define VALA_IS_LOOP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_LOOP))
+#define VALA_LOOP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_LOOP, ValaLoopClass))
+
+typedef struct _ValaLoop ValaLoop;
+typedef struct _ValaLoopClass ValaLoopClass;
+
 #define VALA_TYPE_WHILE_STATEMENT (vala_while_statement_get_type ())
 #define VALA_WHILE_STATEMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_WHILE_STATEMENT, ValaWhileStatement))
 #define VALA_WHILE_STATEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_WHILE_STATEMENT, ValaWhileStatementClass))
@@ -859,6 +869,26 @@ typedef struct _ValaAssignment ValaAssignment;
 typedef struct _ValaAssignmentClass ValaAssignmentClass;
 typedef struct _ValaSemanticAnalyzerPrivate ValaSemanticAnalyzerPrivate;
 
+#define VALA_TYPE_VALUE_TYPE (vala_value_type_get_type ())
+#define VALA_VALUE_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_VALUE_TYPE, ValaValueType))
+#define VALA_VALUE_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_VALUE_TYPE, ValaValueTypeClass))
+#define VALA_IS_VALUE_TYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_VALUE_TYPE))
+#define VALA_IS_VALUE_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_VALUE_TYPE))
+#define VALA_VALUE_TYPE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_VALUE_TYPE, ValaValueTypeClass))
+
+typedef struct _ValaValueType ValaValueType;
+typedef struct _ValaValueTypeClass ValaValueTypeClass;
+
+#define VALA_TYPE_STRUCT_VALUE_TYPE (vala_struct_value_type_get_type ())
+#define VALA_STRUCT_VALUE_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_STRUCT_VALUE_TYPE, ValaStructValueType))
+#define VALA_STRUCT_VALUE_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_STRUCT_VALUE_TYPE, ValaStructValueTypeClass))
+#define VALA_IS_STRUCT_VALUE_TYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_STRUCT_VALUE_TYPE))
+#define VALA_IS_STRUCT_VALUE_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_STRUCT_VALUE_TYPE))
+#define VALA_STRUCT_VALUE_TYPE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_STRUCT_VALUE_TYPE, ValaStructValueTypeClass))
+
+typedef struct _ValaStructValueType ValaStructValueType;
+typedef struct _ValaStructValueTypeClass ValaStructValueTypeClass;
+
 /**
  * Represents a part of the parsed source code.
  *
@@ -905,9 +935,9 @@ struct _ValaIfStatementClass {
 };
 
 struct _ValaIfStatementPrivate {
+	ValaExpression* _condition;
 	ValaBlock* _true_statement;
 	ValaBlock* _false_statement;
-	ValaExpression* _condition;
 };
 
 /**
@@ -956,6 +986,7 @@ struct _ValaCodeVisitorClass {
 	void (*visit_switch_statement) (ValaCodeVisitor* self, ValaSwitchStatement* stmt);
 	void (*visit_switch_section) (ValaCodeVisitor* self, ValaSwitchSection* section);
 	void (*visit_switch_label) (ValaCodeVisitor* self, ValaSwitchLabel* label);
+	void (*visit_loop) (ValaCodeVisitor* self, ValaLoop* stmt);
 	void (*visit_while_statement) (ValaCodeVisitor* self, ValaWhileStatement* stmt);
 	void (*visit_do_statement) (ValaCodeVisitor* self, ValaDoStatement* stmt);
 	void (*visit_for_statement) (ValaCodeVisitor* self, ValaForStatement* stmt);
@@ -1025,9 +1056,11 @@ struct _ValaSemanticAnalyzer {
 	ValaDataType* double_type;
 	ValaDataType* type_type;
 	ValaClass* object_type;
+	ValaStructValueType* gvalue_type;
 	ValaDataType* glist_type;
 	ValaDataType* gslist_type;
 	ValaDataType* garray_type;
+	ValaDataType* gvaluearray_type;
 	ValaClass* gerror_type;
 	gint next_lambda_id;
 	GeeList* replaced_nodes;
@@ -1038,6 +1071,8 @@ struct _ValaSemanticAnalyzerClass {
 };
 
 
+static gpointer vala_if_statement_parent_class = NULL;
+static ValaStatementIface* vala_if_statement_vala_statement_parent_iface = NULL;
 
 gpointer vala_code_node_ref (gpointer instance);
 void vala_code_node_unref (gpointer instance);
@@ -1076,7 +1111,6 @@ GType vala_source_reference_get_type (void);
 void vala_code_node_set_source_reference (ValaCodeNode* self, ValaSourceReference* value);
 ValaIfStatement* vala_if_statement_new (ValaExpression* cond, ValaBlock* true_stmt, ValaBlock* false_stmt, ValaSourceReference* source);
 ValaIfStatement* vala_if_statement_construct (GType object_type, ValaExpression* cond, ValaBlock* true_stmt, ValaBlock* false_stmt, ValaSourceReference* source);
-ValaIfStatement* vala_if_statement_new (ValaExpression* cond, ValaBlock* true_stmt, ValaBlock* false_stmt, ValaSourceReference* source);
 void vala_code_visitor_visit_if_statement (ValaCodeVisitor* self, ValaIfStatement* stmt);
 static void vala_if_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 ValaExpression* vala_if_statement_get_condition (ValaIfStatement* self);
@@ -1130,6 +1164,7 @@ GType vala_expression_statement_get_type (void);
 GType vala_switch_statement_get_type (void);
 GType vala_switch_section_get_type (void);
 GType vala_switch_label_get_type (void);
+GType vala_loop_get_type (void);
 GType vala_while_statement_get_type (void);
 GType vala_do_statement_get_type (void);
 GType vala_for_statement_get_type (void);
@@ -1169,14 +1204,14 @@ GType vala_typecheck_get_type (void);
 GType vala_conditional_expression_get_type (void);
 GType vala_lambda_expression_get_type (void);
 GType vala_assignment_get_type (void);
+GType vala_value_type_get_type (void);
+GType vala_struct_value_type_get_type (void);
 void vala_report_error (ValaSourceReference* source, const char* message);
 ValaSourceReference* vala_code_node_get_source_reference (ValaCodeNode* self);
 void vala_code_node_add_error_types (ValaCodeNode* self, GeeList* error_types);
 GeeList* vala_code_node_get_error_types (ValaCodeNode* self);
 static gboolean vala_if_statement_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer);
 void vala_code_node_set_parent_node (ValaCodeNode* self, ValaCodeNode* value);
-static gpointer vala_if_statement_parent_class = NULL;
-static ValaStatementIface* vala_if_statement_vala_statement_parent_iface = NULL;
 static void vala_if_statement_finalize (ValaCodeNode* obj);
 
 
@@ -1221,9 +1256,9 @@ static void vala_if_statement_real_accept_children (ValaCodeNode* base, ValaCode
 	g_return_if_fail (visitor != NULL);
 	vala_code_node_accept ((ValaCodeNode*) vala_if_statement_get_condition (self), visitor);
 	vala_code_visitor_visit_end_full_expression (visitor, vala_if_statement_get_condition (self));
-	vala_code_node_accept ((ValaCodeNode*) self->priv->_true_statement, visitor);
-	if (self->priv->_false_statement != NULL) {
-		vala_code_node_accept ((ValaCodeNode*) self->priv->_false_statement, visitor);
+	vala_code_node_accept ((ValaCodeNode*) vala_if_statement_get_true_statement (self), visitor);
+	if (vala_if_statement_get_false_statement (self) != NULL) {
+		vala_code_node_accept ((ValaCodeNode*) vala_if_statement_get_false_statement (self), visitor);
 	}
 }
 
@@ -1241,91 +1276,106 @@ static void vala_if_statement_real_replace_expression (ValaCodeNode* base, ValaE
 
 static gboolean vala_if_statement_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer) {
 	ValaIfStatement * self;
-	GeeList* _tmp3_;
-	GeeList* _tmp4_;
+	gboolean result;
+	GeeList* _tmp0_;
+	GeeList* _tmp1_;
 	self = (ValaIfStatement*) base;
 	g_return_val_if_fail (analyzer != NULL, FALSE);
 	if (vala_code_node_get_checked ((ValaCodeNode*) self)) {
-		return !vala_code_node_get_error ((ValaCodeNode*) self);
+		result = !vala_code_node_get_error ((ValaCodeNode*) self);
+		return result;
 	}
 	vala_code_node_set_checked ((ValaCodeNode*) self, TRUE);
 	vala_code_node_check ((ValaCodeNode*) vala_if_statement_get_condition (self), analyzer);
-	vala_code_node_check ((ValaCodeNode*) self->priv->_true_statement, analyzer);
-	if (self->priv->_false_statement != NULL) {
-		vala_code_node_check ((ValaCodeNode*) self->priv->_false_statement, analyzer);
+	vala_code_node_check ((ValaCodeNode*) vala_if_statement_get_true_statement (self), analyzer);
+	if (vala_if_statement_get_false_statement (self) != NULL) {
+		vala_code_node_check ((ValaCodeNode*) vala_if_statement_get_false_statement (self), analyzer);
 	}
 	if (vala_code_node_get_error ((ValaCodeNode*) vala_if_statement_get_condition (self))) {
 		/* if there was an error in the condition, skip this check */
 		vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
-		return FALSE;
+		result = FALSE;
+		return result;
 	}
 	if (!vala_data_type_compatible (vala_expression_get_value_type (vala_if_statement_get_condition (self)), analyzer->bool_type)) {
 		vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
 		vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) vala_if_statement_get_condition (self)), "Condition must be boolean");
-		return FALSE;
+		result = FALSE;
+		return result;
 	}
-	_tmp3_ = NULL;
-	vala_code_node_add_error_types ((ValaCodeNode*) self, _tmp3_ = vala_code_node_get_error_types ((ValaCodeNode*) vala_if_statement_get_condition (self)));
-	(_tmp3_ == NULL) ? NULL : (_tmp3_ = (gee_collection_object_unref (_tmp3_), NULL));
-	_tmp4_ = NULL;
-	vala_code_node_add_error_types ((ValaCodeNode*) self, _tmp4_ = vala_code_node_get_error_types ((ValaCodeNode*) self->priv->_true_statement));
-	(_tmp4_ == NULL) ? NULL : (_tmp4_ = (gee_collection_object_unref (_tmp4_), NULL));
-	if (self->priv->_false_statement != NULL) {
-		GeeList* _tmp5_;
-		_tmp5_ = NULL;
-		vala_code_node_add_error_types ((ValaCodeNode*) self, _tmp5_ = vala_code_node_get_error_types ((ValaCodeNode*) self->priv->_false_statement));
-		(_tmp5_ == NULL) ? NULL : (_tmp5_ = (gee_collection_object_unref (_tmp5_), NULL));
+	_tmp0_ = NULL;
+	vala_code_node_add_error_types ((ValaCodeNode*) self, _tmp0_ = vala_code_node_get_error_types ((ValaCodeNode*) vala_if_statement_get_condition (self)));
+	(_tmp0_ == NULL) ? NULL : (_tmp0_ = (gee_collection_object_unref (_tmp0_), NULL));
+	_tmp1_ = NULL;
+	vala_code_node_add_error_types ((ValaCodeNode*) self, _tmp1_ = vala_code_node_get_error_types ((ValaCodeNode*) vala_if_statement_get_true_statement (self)));
+	(_tmp1_ == NULL) ? NULL : (_tmp1_ = (gee_collection_object_unref (_tmp1_), NULL));
+	if (vala_if_statement_get_false_statement (self) != NULL) {
+		GeeList* _tmp2_;
+		_tmp2_ = NULL;
+		vala_code_node_add_error_types ((ValaCodeNode*) self, _tmp2_ = vala_code_node_get_error_types ((ValaCodeNode*) vala_if_statement_get_false_statement (self)));
+		(_tmp2_ == NULL) ? NULL : (_tmp2_ = (gee_collection_object_unref (_tmp2_), NULL));
 	}
-	return !vala_code_node_get_error ((ValaCodeNode*) self);
+	result = !vala_code_node_get_error ((ValaCodeNode*) self);
+	return result;
 }
 
 
 ValaExpression* vala_if_statement_get_condition (ValaIfStatement* self) {
+	ValaExpression* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_condition;
+	result = self->priv->_condition;
+	return result;
 }
 
 
 void vala_if_statement_set_condition (ValaIfStatement* self, ValaExpression* value) {
-	ValaExpression* _tmp2_;
 	ValaExpression* _tmp1_;
+	ValaExpression* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2_ = NULL;
 	_tmp1_ = NULL;
-	self->priv->_condition = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_)), (self->priv->_condition == NULL) ? NULL : (self->priv->_condition = (vala_code_node_unref (self->priv->_condition), NULL)), _tmp2_);
+	_tmp0_ = NULL;
+	self->priv->_condition = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_)), (self->priv->_condition == NULL) ? NULL : (self->priv->_condition = (vala_code_node_unref (self->priv->_condition), NULL)), _tmp1_);
 	vala_code_node_set_parent_node ((ValaCodeNode*) self->priv->_condition, (ValaCodeNode*) self);
 }
 
 
 ValaBlock* vala_if_statement_get_true_statement (ValaIfStatement* self) {
+	ValaBlock* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_true_statement;
+	result = self->priv->_true_statement;
+	return result;
 }
 
 
 void vala_if_statement_set_true_statement (ValaIfStatement* self, ValaBlock* value) {
-	ValaBlock* _tmp2_;
 	ValaBlock* _tmp1_;
+	ValaBlock* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2_ = NULL;
 	_tmp1_ = NULL;
-	self->priv->_true_statement = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_)), (self->priv->_true_statement == NULL) ? NULL : (self->priv->_true_statement = (vala_code_node_unref (self->priv->_true_statement), NULL)), _tmp2_);
+	_tmp0_ = NULL;
+	self->priv->_true_statement = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_)), (self->priv->_true_statement == NULL) ? NULL : (self->priv->_true_statement = (vala_code_node_unref (self->priv->_true_statement), NULL)), _tmp1_);
+	vala_code_node_set_parent_node ((ValaCodeNode*) self->priv->_true_statement, (ValaCodeNode*) self);
 }
 
 
 ValaBlock* vala_if_statement_get_false_statement (ValaIfStatement* self) {
+	ValaBlock* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_false_statement;
+	result = self->priv->_false_statement;
+	return result;
 }
 
 
 void vala_if_statement_set_false_statement (ValaIfStatement* self, ValaBlock* value) {
-	ValaBlock* _tmp2_;
 	ValaBlock* _tmp1_;
+	ValaBlock* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2_ = NULL;
 	_tmp1_ = NULL;
-	self->priv->_false_statement = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_)), (self->priv->_false_statement == NULL) ? NULL : (self->priv->_false_statement = (vala_code_node_unref (self->priv->_false_statement), NULL)), _tmp2_);
+	_tmp0_ = NULL;
+	self->priv->_false_statement = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_)), (self->priv->_false_statement == NULL) ? NULL : (self->priv->_false_statement = (vala_code_node_unref (self->priv->_false_statement), NULL)), _tmp1_);
+	if (self->priv->_false_statement != NULL) {
+		vala_code_node_set_parent_node ((ValaCodeNode*) self->priv->_false_statement, (ValaCodeNode*) self);
+	}
 }
 
 
@@ -1353,9 +1403,9 @@ static void vala_if_statement_instance_init (ValaIfStatement * self) {
 static void vala_if_statement_finalize (ValaCodeNode* obj) {
 	ValaIfStatement * self;
 	self = VALA_IF_STATEMENT (obj);
+	(self->priv->_condition == NULL) ? NULL : (self->priv->_condition = (vala_code_node_unref (self->priv->_condition), NULL));
 	(self->priv->_true_statement == NULL) ? NULL : (self->priv->_true_statement = (vala_code_node_unref (self->priv->_true_statement), NULL));
 	(self->priv->_false_statement == NULL) ? NULL : (self->priv->_false_statement = (vala_code_node_unref (self->priv->_false_statement), NULL));
-	(self->priv->_condition == NULL) ? NULL : (self->priv->_condition = (vala_code_node_unref (self->priv->_condition), NULL));
 	VALA_CODE_NODE_CLASS (vala_if_statement_parent_class)->finalize (obj);
 }
 
