@@ -209,6 +209,7 @@ struct _ValaPointerIndirectionPrivate {
 };
 
 
+static gpointer vala_pointer_indirection_parent_class = NULL;
 
 gpointer vala_code_node_ref (gpointer instance);
 void vala_code_node_unref (gpointer instance);
@@ -243,7 +244,6 @@ void vala_code_node_set_source_reference (ValaCodeNode* self, ValaSourceReferenc
 void vala_pointer_indirection_set_inner (ValaPointerIndirection* self, ValaExpression* value);
 ValaPointerIndirection* vala_pointer_indirection_new (ValaExpression* inner, ValaSourceReference* source_reference);
 ValaPointerIndirection* vala_pointer_indirection_construct (GType object_type, ValaExpression* inner, ValaSourceReference* source_reference);
-ValaPointerIndirection* vala_pointer_indirection_new (ValaExpression* inner, ValaSourceReference* source_reference);
 ValaExpression* vala_pointer_indirection_get_inner (ValaPointerIndirection* self);
 void vala_code_node_accept (ValaCodeNode* self, ValaCodeVisitor* visitor);
 void vala_code_visitor_visit_pointer_indirection (ValaCodeVisitor* self, ValaPointerIndirection* expr);
@@ -270,7 +270,6 @@ static void vala_pointer_indirection_real_get_defined_variables (ValaCodeNode* b
 void vala_code_node_get_used_variables (ValaCodeNode* self, GeeCollection* collection);
 static void vala_pointer_indirection_real_get_used_variables (ValaCodeNode* base, GeeCollection* collection);
 void vala_code_node_set_parent_node (ValaCodeNode* self, ValaCodeNode* value);
-static gpointer vala_pointer_indirection_parent_class = NULL;
 static void vala_pointer_indirection_finalize (ValaCodeNode* obj);
 
 
@@ -319,46 +318,55 @@ static void vala_pointer_indirection_real_replace_expression (ValaCodeNode* base
 
 static gboolean vala_pointer_indirection_real_is_pure (ValaExpression* base) {
 	ValaPointerIndirection * self;
+	gboolean result;
 	self = (ValaPointerIndirection*) base;
-	return vala_expression_is_pure (vala_pointer_indirection_get_inner (self));
+	result = vala_expression_is_pure (vala_pointer_indirection_get_inner (self));
+	return result;
 }
 
 
 static gboolean vala_pointer_indirection_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer) {
 	ValaPointerIndirection * self;
+	gboolean result;
 	self = (ValaPointerIndirection*) base;
 	g_return_val_if_fail (analyzer != NULL, FALSE);
 	if (vala_code_node_get_checked ((ValaCodeNode*) self)) {
-		return !vala_code_node_get_error ((ValaCodeNode*) self);
+		result = !vala_code_node_get_error ((ValaCodeNode*) self);
+		return result;
 	}
 	vala_code_node_set_checked ((ValaCodeNode*) self, TRUE);
 	if (!vala_code_node_check ((ValaCodeNode*) vala_pointer_indirection_get_inner (self), analyzer)) {
-		return FALSE;
+		result = FALSE;
+		return result;
 	}
 	if (vala_expression_get_value_type (vala_pointer_indirection_get_inner (self)) == NULL) {
 		vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
 		vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), "internal error: unknown type of inner expression");
-		return FALSE;
+		result = FALSE;
+		return result;
 	}
 	if (VALA_IS_POINTER_TYPE (vala_expression_get_value_type (vala_pointer_indirection_get_inner (self)))) {
-		ValaPointerType* _tmp3;
+		ValaPointerType* _tmp0_;
 		ValaPointerType* pointer_type;
-		_tmp3 = NULL;
-		pointer_type = (_tmp3 = VALA_POINTER_TYPE (vala_expression_get_value_type (vala_pointer_indirection_get_inner (self))), (_tmp3 == NULL) ? NULL : vala_code_node_ref (_tmp3));
+		_tmp0_ = NULL;
+		pointer_type = (_tmp0_ = VALA_POINTER_TYPE (vala_expression_get_value_type (vala_pointer_indirection_get_inner (self))), (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_));
 		if (VALA_IS_REFERENCE_TYPE (vala_pointer_type_get_base_type (pointer_type))) {
-			gboolean _tmp4;
 			vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
 			vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), "Pointer indirection not supported for this expression");
-			return (_tmp4 = FALSE, (pointer_type == NULL) ? NULL : (pointer_type = (vala_code_node_unref (pointer_type), NULL)), _tmp4);
+			result = FALSE;
+			(pointer_type == NULL) ? NULL : (pointer_type = (vala_code_node_unref (pointer_type), NULL));
+			return result;
 		}
 		vala_expression_set_value_type ((ValaExpression*) self, vala_pointer_type_get_base_type (pointer_type));
 		(pointer_type == NULL) ? NULL : (pointer_type = (vala_code_node_unref (pointer_type), NULL));
 	} else {
 		vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
 		vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), "Pointer indirection not supported for this expression");
-		return FALSE;
+		result = FALSE;
+		return result;
 	}
-	return !vala_code_node_get_error ((ValaCodeNode*) self);
+	result = !vala_code_node_get_error ((ValaCodeNode*) self);
+	return result;
 }
 
 
@@ -379,18 +387,20 @@ static void vala_pointer_indirection_real_get_used_variables (ValaCodeNode* base
 
 
 ValaExpression* vala_pointer_indirection_get_inner (ValaPointerIndirection* self) {
+	ValaExpression* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_inner;
+	result = self->priv->_inner;
+	return result;
 }
 
 
 void vala_pointer_indirection_set_inner (ValaPointerIndirection* self, ValaExpression* value) {
-	ValaExpression* _tmp2;
-	ValaExpression* _tmp1;
+	ValaExpression* _tmp1_;
+	ValaExpression* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_inner = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_code_node_ref (_tmp1)), (self->priv->_inner == NULL) ? NULL : (self->priv->_inner = (vala_code_node_unref (self->priv->_inner), NULL)), _tmp2);
+	_tmp1_ = NULL;
+	_tmp0_ = NULL;
+	self->priv->_inner = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_)), (self->priv->_inner == NULL) ? NULL : (self->priv->_inner = (vala_code_node_unref (self->priv->_inner), NULL)), _tmp1_);
 	vala_code_node_set_parent_node ((ValaCodeNode*) self->priv->_inner, (ValaCodeNode*) self);
 }
 
