@@ -246,6 +246,7 @@ struct _ValaPointerTypePrivate {
 };
 
 
+static gpointer vala_pointer_type_parent_class = NULL;
 
 gpointer vala_code_node_ref (gpointer instance);
 void vala_code_node_unref (gpointer instance);
@@ -288,7 +289,6 @@ GType vala_source_reference_get_type (void);
 void vala_code_node_set_source_reference (ValaCodeNode* self, ValaSourceReference* value);
 ValaPointerType* vala_pointer_type_new (ValaDataType* base_type, ValaSourceReference* source_reference);
 ValaPointerType* vala_pointer_type_construct (GType object_type, ValaDataType* base_type, ValaSourceReference* source_reference);
-ValaPointerType* vala_pointer_type_new (ValaDataType* base_type, ValaSourceReference* source_reference);
 ValaDataType* vala_pointer_type_get_base_type (ValaPointerType* self);
 char* vala_data_type_to_qualified_string (ValaDataType* self, ValaScope* scope);
 static char* vala_pointer_type_real_to_qualified_string (ValaDataType* base, ValaScope* scope);
@@ -319,7 +319,6 @@ void vala_code_node_set_error (ValaCodeNode* self, gboolean value);
 gboolean vala_code_node_get_error (ValaCodeNode* self);
 static gboolean vala_pointer_type_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer);
 void vala_code_node_set_parent_node (ValaCodeNode* self, ValaCodeNode* value);
-static gpointer vala_pointer_type_parent_class = NULL;
 static void vala_pointer_type_finalize (ValaCodeNode* obj);
 
 
@@ -342,17 +341,20 @@ ValaPointerType* vala_pointer_type_new (ValaDataType* base_type, ValaSourceRefer
 
 static char* vala_pointer_type_real_to_qualified_string (ValaDataType* base, ValaScope* scope) {
 	ValaPointerType * self;
+	char* result;
 	char* _tmp0_;
 	char* _tmp1_;
 	self = (ValaPointerType*) base;
 	_tmp0_ = NULL;
 	_tmp1_ = NULL;
-	return (_tmp1_ = g_strconcat (_tmp0_ = vala_data_type_to_qualified_string (vala_pointer_type_get_base_type (self), scope), "*", NULL), _tmp0_ = (g_free (_tmp0_), NULL), _tmp1_);
+	result = (_tmp1_ = g_strconcat (_tmp0_ = vala_data_type_to_qualified_string (vala_pointer_type_get_base_type (self), scope), "*", NULL), _tmp0_ = (g_free (_tmp0_), NULL), _tmp1_);
+	return result;
 }
 
 
 static char* vala_pointer_type_real_get_cname (ValaDataType* base) {
 	ValaPointerType * self;
+	char* result;
 	gboolean _tmp0_;
 	self = (ValaPointerType*) base;
 	_tmp0_ = FALSE;
@@ -362,30 +364,35 @@ static char* vala_pointer_type_real_get_cname (ValaDataType* base) {
 		_tmp0_ = FALSE;
 	}
 	if (_tmp0_) {
-		return vala_data_type_get_cname (vala_pointer_type_get_base_type (self));
+		result = vala_data_type_get_cname (vala_pointer_type_get_base_type (self));
+		return result;
 	} else {
+		char* _tmp1_;
 		char* _tmp2_;
-		char* _tmp3_;
+		_tmp1_ = NULL;
 		_tmp2_ = NULL;
-		_tmp3_ = NULL;
-		return (_tmp3_ = g_strconcat (_tmp2_ = vala_data_type_get_cname (vala_pointer_type_get_base_type (self)), "*", NULL), _tmp2_ = (g_free (_tmp2_), NULL), _tmp3_);
+		result = (_tmp2_ = g_strconcat (_tmp1_ = vala_data_type_get_cname (vala_pointer_type_get_base_type (self)), "*", NULL), _tmp1_ = (g_free (_tmp1_), NULL), _tmp2_);
+		return result;
 	}
 }
 
 
 static ValaDataType* vala_pointer_type_real_copy (ValaDataType* base) {
 	ValaPointerType * self;
+	ValaDataType* result;
 	ValaDataType* _tmp0_;
 	ValaDataType* _tmp1_;
 	self = (ValaPointerType*) base;
 	_tmp0_ = NULL;
 	_tmp1_ = NULL;
-	return (_tmp1_ = (ValaDataType*) vala_pointer_type_new (_tmp0_ = vala_data_type_copy (vala_pointer_type_get_base_type (self)), NULL), (_tmp0_ == NULL) ? NULL : (_tmp0_ = (vala_code_node_unref (_tmp0_), NULL)), _tmp1_);
+	result = (_tmp1_ = (ValaDataType*) vala_pointer_type_new (_tmp0_ = vala_data_type_copy (vala_pointer_type_get_base_type (self)), NULL), (_tmp0_ == NULL) ? NULL : (_tmp0_ = (vala_code_node_unref (_tmp0_), NULL)), _tmp1_);
+	return result;
 }
 
 
 static gboolean vala_pointer_type_real_compatible (ValaDataType* base, ValaDataType* target_type) {
 	ValaPointerType * self;
+	gboolean result;
 	gboolean _tmp0_;
 	self = (ValaPointerType*) base;
 	g_return_val_if_fail (target_type != NULL, FALSE);
@@ -406,50 +413,59 @@ static gboolean vala_pointer_type_real_compatible (ValaDataType* base, ValaDataT
 		_tmp0_ = _tmp1_;
 	}
 	if (_tmp0_) {
-		return TRUE;
+		result = TRUE;
+		return result;
 	}
 	/* temporarily ignore type parameters */
 	if (vala_data_type_get_type_parameter (target_type) != NULL) {
-		return TRUE;
+		result = TRUE;
+		return result;
 	}
 	if (vala_data_type_is_reference_type_or_type_parameter (vala_pointer_type_get_base_type (self))) {
 		/* Object* is compatible with Object if Object is a reference type*/
-		return vala_data_type_compatible (vala_pointer_type_get_base_type (self), target_type);
+		result = vala_data_type_compatible (vala_pointer_type_get_base_type (self), target_type);
+		return result;
 	}
-	return FALSE;
+	result = FALSE;
+	return result;
 }
 
 
 static ValaSymbol* vala_pointer_type_real_get_pointer_member (ValaDataType* base, const char* member_name) {
 	ValaPointerType * self;
+	ValaSymbol* result;
 	ValaSymbol* _tmp0_;
 	ValaSymbol* base_symbol;
-	ValaSymbol* _tmp2_;
 	self = (ValaPointerType*) base;
 	g_return_val_if_fail (member_name != NULL, NULL);
 	_tmp0_ = NULL;
 	base_symbol = (_tmp0_ = (ValaSymbol*) vala_data_type_get_data_type (vala_pointer_type_get_base_type (self)), (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_));
 	if (base_symbol == NULL) {
-		ValaSymbol* _tmp1_;
-		_tmp1_ = NULL;
-		return (_tmp1_ = NULL, (base_symbol == NULL) ? NULL : (base_symbol = (vala_code_node_unref (base_symbol), NULL)), _tmp1_);
+		result = NULL;
+		(base_symbol == NULL) ? NULL : (base_symbol = (vala_code_node_unref (base_symbol), NULL));
+		return result;
 	}
-	_tmp2_ = NULL;
-	return (_tmp2_ = vala_semantic_analyzer_symbol_lookup_inherited (base_symbol, member_name), (base_symbol == NULL) ? NULL : (base_symbol = (vala_code_node_unref (base_symbol), NULL)), _tmp2_);
+	result = vala_semantic_analyzer_symbol_lookup_inherited (base_symbol, member_name);
+	(base_symbol == NULL) ? NULL : (base_symbol = (vala_code_node_unref (base_symbol), NULL));
+	return result;
 }
 
 
 static GeeList* vala_pointer_type_real_get_symbols (ValaDataType* base) {
 	ValaPointerType * self;
+	GeeList* result;
 	self = (ValaPointerType*) base;
-	return vala_data_type_get_symbols (vala_pointer_type_get_base_type (self));
+	result = vala_data_type_get_symbols (vala_pointer_type_get_base_type (self));
+	return result;
 }
 
 
 static char* vala_pointer_type_real_get_type_id (ValaDataType* base) {
 	ValaPointerType * self;
+	char* result;
 	self = (ValaPointerType*) base;
-	return g_strdup ("G_TYPE_POINTER");
+	result = g_strdup ("G_TYPE_POINTER");
+	return result;
 }
 
 
@@ -474,33 +490,39 @@ static void vala_pointer_type_real_replace_type (ValaCodeNode* base, ValaDataTyp
 
 static gboolean vala_pointer_type_real_is_disposable (ValaDataType* base) {
 	ValaPointerType * self;
+	gboolean result;
 	self = (ValaPointerType*) base;
-	return FALSE;
+	result = FALSE;
+	return result;
 }
 
 
 static gboolean vala_pointer_type_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer) {
 	ValaPointerType * self;
+	gboolean result;
 	self = (ValaPointerType*) base;
 	g_return_val_if_fail (analyzer != NULL, FALSE);
 	vala_code_node_set_error ((ValaCodeNode*) self, !vala_code_node_check ((ValaCodeNode*) vala_pointer_type_get_base_type (self), analyzer));
-	return !vala_code_node_get_error ((ValaCodeNode*) self);
+	result = !vala_code_node_get_error ((ValaCodeNode*) self);
+	return result;
 }
 
 
 ValaDataType* vala_pointer_type_get_base_type (ValaPointerType* self) {
+	ValaDataType* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_base_type;
+	result = self->priv->_base_type;
+	return result;
 }
 
 
 void vala_pointer_type_set_base_type (ValaPointerType* self, ValaDataType* value) {
-	ValaDataType* _tmp2_;
 	ValaDataType* _tmp1_;
+	ValaDataType* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2_ = NULL;
 	_tmp1_ = NULL;
-	self->priv->_base_type = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_)), (self->priv->_base_type == NULL) ? NULL : (self->priv->_base_type = (vala_code_node_unref (self->priv->_base_type), NULL)), _tmp2_);
+	_tmp0_ = NULL;
+	self->priv->_base_type = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_)), (self->priv->_base_type == NULL) ? NULL : (self->priv->_base_type = (vala_code_node_unref (self->priv->_base_type), NULL)), _tmp1_);
 	vala_code_node_set_parent_node ((ValaCodeNode*) self->priv->_base_type, (ValaCodeNode*) self);
 }
 
