@@ -190,6 +190,7 @@ struct _ValaPostfixExpressionPrivate {
 };
 
 
+static gpointer vala_postfix_expression_parent_class = NULL;
 
 gpointer vala_code_node_ref (gpointer instance);
 void vala_code_node_unref (gpointer instance);
@@ -225,7 +226,6 @@ GType vala_source_reference_get_type (void);
 void vala_code_node_set_source_reference (ValaCodeNode* self, ValaSourceReference* value);
 ValaPostfixExpression* vala_postfix_expression_new (ValaExpression* _inner, gboolean inc, ValaSourceReference* source);
 ValaPostfixExpression* vala_postfix_expression_construct (GType object_type, ValaExpression* _inner, gboolean inc, ValaSourceReference* source);
-ValaPostfixExpression* vala_postfix_expression_new (ValaExpression* _inner, gboolean inc, ValaSourceReference* source);
 ValaExpression* vala_postfix_expression_get_inner (ValaPostfixExpression* self);
 void vala_code_node_accept (ValaCodeNode* self, ValaCodeVisitor* visitor);
 void vala_code_visitor_visit_postfix_expression (ValaCodeVisitor* self, ValaPostfixExpression* expr);
@@ -240,7 +240,6 @@ ValaDataType* vala_expression_get_value_type (ValaExpression* self);
 void vala_expression_set_value_type (ValaExpression* self, ValaDataType* value);
 static gboolean vala_postfix_expression_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer);
 gboolean vala_postfix_expression_get_increment (ValaPostfixExpression* self);
-static gpointer vala_postfix_expression_parent_class = NULL;
 static void vala_postfix_expression_finalize (ValaCodeNode* obj);
 
 
@@ -282,44 +281,53 @@ static void vala_postfix_expression_real_accept (ValaCodeNode* base, ValaCodeVis
 
 static gboolean vala_postfix_expression_real_is_pure (ValaExpression* base) {
 	ValaPostfixExpression * self;
+	gboolean result;
 	self = (ValaPostfixExpression*) base;
-	return FALSE;
+	result = FALSE;
+	return result;
 }
 
 
 static gboolean vala_postfix_expression_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer) {
 	ValaPostfixExpression * self;
+	gboolean result;
 	self = (ValaPostfixExpression*) base;
 	g_return_val_if_fail (analyzer != NULL, FALSE);
 	if (vala_code_node_get_checked ((ValaCodeNode*) self)) {
-		return !vala_code_node_get_error ((ValaCodeNode*) self);
+		result = !vala_code_node_get_error ((ValaCodeNode*) self);
+		return result;
 	}
 	vala_code_node_set_checked ((ValaCodeNode*) self, TRUE);
 	vala_code_node_check ((ValaCodeNode*) self->priv->_inner, analyzer);
 	vala_expression_set_value_type ((ValaExpression*) self, vala_expression_get_value_type (self->priv->_inner));
-	return !vala_code_node_get_error ((ValaCodeNode*) self);
+	result = !vala_code_node_get_error ((ValaCodeNode*) self);
+	return result;
 }
 
 
 ValaExpression* vala_postfix_expression_get_inner (ValaPostfixExpression* self) {
+	ValaExpression* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_inner;
+	result = self->priv->_inner;
+	return result;
 }
 
 
 void vala_postfix_expression_set_inner (ValaPostfixExpression* self, ValaExpression* value) {
-	ValaExpression* _tmp2_;
 	ValaExpression* _tmp1_;
+	ValaExpression* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2_ = NULL;
 	_tmp1_ = NULL;
-	self->priv->_inner = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_)), (self->priv->_inner == NULL) ? NULL : (self->priv->_inner = (vala_code_node_unref (self->priv->_inner), NULL)), _tmp2_);
+	_tmp0_ = NULL;
+	self->priv->_inner = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_)), (self->priv->_inner == NULL) ? NULL : (self->priv->_inner = (vala_code_node_unref (self->priv->_inner), NULL)), _tmp1_);
 }
 
 
 gboolean vala_postfix_expression_get_increment (ValaPostfixExpression* self) {
+	gboolean result;
 	g_return_val_if_fail (self != NULL, FALSE);
-	return self->priv->_increment;
+	result = self->priv->_increment;
+	return result;
 }
 
 
