@@ -285,6 +285,8 @@ struct _ValaSymbolClass {
 	char* (*get_lower_case_cname) (ValaSymbol* self, const char* infix);
 	char* (*get_lower_case_cprefix) (ValaSymbol* self);
 	GeeList* (*get_cheader_filenames) (ValaSymbol* self);
+	gboolean (*is_instance_member) (ValaSymbol* self);
+	gboolean (*is_class_member) (ValaSymbol* self);
 };
 
 /**
@@ -337,6 +339,8 @@ struct _ValaPropertyPrivate {
 	ValaField* _field;
 	MemberBinding _binding;
 	ValaExpression* _default_expression;
+	gboolean _no_array_length;
+	gboolean _array_null_terminated;
 	gboolean lock_used;
 	ValaDataType* _data_type;
 	char* _nick;
@@ -356,6 +360,8 @@ typedef enum  {
 } ValaSymbolAccessibility;
 
 
+static gpointer vala_property_parent_class = NULL;
+static ValaLockableIface* vala_property_vala_lockable_parent_iface = NULL;
 
 gpointer vala_code_node_ref (gpointer instance);
 void vala_code_node_unref (gpointer instance);
@@ -399,7 +405,6 @@ void vala_property_set_get_accessor (ValaProperty* self, ValaPropertyAccessor* v
 void vala_property_set_set_accessor (ValaProperty* self, ValaPropertyAccessor* value);
 ValaProperty* vala_property_new (const char* name, ValaDataType* property_type, ValaPropertyAccessor* get_accessor, ValaPropertyAccessor* set_accessor, ValaSourceReference* source_reference);
 ValaProperty* vala_property_construct (GType object_type, const char* name, ValaDataType* property_type, ValaPropertyAccessor* get_accessor, ValaPropertyAccessor* set_accessor, ValaSourceReference* source_reference);
-ValaProperty* vala_property_new (const char* name, ValaDataType* property_type, ValaPropertyAccessor* get_accessor, ValaPropertyAccessor* set_accessor, ValaSourceReference* source_reference);
 void vala_code_visitor_visit_member (ValaCodeVisitor* self, ValaMember* m);
 void vala_code_visitor_visit_property (ValaCodeVisitor* self, ValaProperty* prop);
 static void vala_property_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
@@ -414,11 +419,13 @@ char* vala_symbol_get_lower_case_cname (ValaSymbol* self, const char* infix);
 char* vala_symbol_camel_case_to_lower_case (const char* camel_case);
 const char* vala_symbol_get_name (ValaSymbol* self);
 char* vala_property_get_upper_case_cname (ValaProperty* self);
-static char* vala_property_get_canonical_name (ValaProperty* self);
+char* vala_property_get_canonical_name (ValaProperty* self);
 ValaCCodeConstant* vala_property_get_canonical_cconstant (ValaProperty* self);
 gboolean vala_attribute_has_argument (ValaAttribute* self, const char* name);
 gboolean vala_attribute_get_bool (ValaAttribute* self, const char* name);
 void vala_property_set_notify (ValaProperty* self, gboolean value);
+void vala_property_set_no_array_length (ValaProperty* self, gboolean value);
+void vala_property_set_array_null_terminated (ValaProperty* self, gboolean value);
 static void vala_property_process_ccode_attribute (ValaProperty* self, ValaAttribute* a);
 const char* vala_attribute_get_name (ValaAttribute* self);
 void vala_property_set_no_accessor_method (ValaProperty* self, gboolean value);
@@ -428,6 +435,7 @@ void vala_property_set_blurb (ValaProperty* self, const char* value);
 void vala_property_process_attributes (ValaProperty* self);
 static gboolean vala_property_real_get_lock_used (ValaLockable* base);
 static void vala_property_real_set_lock_used (ValaLockable* base, gboolean used);
+ValaDataType* vala_property_accessor_get_value_type (ValaPropertyAccessor* self);
 gboolean vala_data_type_equals (ValaDataType* self, ValaDataType* type2);
 gboolean vala_property_accessor_get_writable (ValaPropertyAccessor* self);
 gboolean vala_property_accessor_get_construction (ValaPropertyAccessor* self);
@@ -502,10 +510,10 @@ MemberBinding vala_property_get_binding (ValaProperty* self);
 void vala_property_set_binding (ValaProperty* self, MemberBinding value);
 ValaProperty* vala_property_get_base_interface_property (ValaProperty* self);
 void vala_property_set_default_expression (ValaProperty* self, ValaExpression* value);
+gboolean vala_property_get_no_array_length (ValaProperty* self);
+gboolean vala_property_get_array_null_terminated (ValaProperty* self);
 const char* vala_property_get_nick (ValaProperty* self);
 const char* vala_property_get_blurb (ValaProperty* self);
-static gpointer vala_property_parent_class = NULL;
-static ValaLockableIface* vala_property_vala_lockable_parent_iface = NULL;
 static void vala_property_finalize (ValaCodeNode* obj);
 static int _vala_strcmp0 (const char * str1, const char * str2);
 
@@ -571,6 +579,7 @@ static void vala_property_real_accept_children (ValaCodeNode* base, ValaCodeVisi
  * @return the upper case name to be used in C code
  */
 char* vala_property_get_upper_case_cname (ValaProperty* self) {
+	char* result;
 	char* _tmp2_;
 	char* _tmp1_;
 	char* _tmp0_;
@@ -580,7 +589,8 @@ char* vala_property_get_upper_case_cname (ValaProperty* self) {
 	_tmp1_ = NULL;
 	_tmp0_ = NULL;
 	_tmp3_ = NULL;
-	return (_tmp3_ = g_utf8_strup (_tmp2_ = g_strdup_printf ("%s_%s", _tmp0_ = vala_symbol_get_lower_case_cname (vala_symbol_get_parent_symbol ((ValaSymbol*) self), NULL), _tmp1_ = vala_symbol_camel_case_to_lower_case (vala_symbol_get_name ((ValaSymbol*) self))), -1), _tmp2_ = (g_free (_tmp2_), NULL), _tmp1_ = (g_free (_tmp1_), NULL), _tmp0_ = (g_free (_tmp0_), NULL), _tmp3_);
+	result = (_tmp3_ = g_utf8_strup (_tmp2_ = g_strdup_printf ("%s_%s", _tmp0_ = vala_symbol_get_lower_case_cname (vala_symbol_get_parent_symbol ((ValaSymbol*) self), NULL), _tmp1_ = vala_symbol_camel_case_to_lower_case (vala_symbol_get_name ((ValaSymbol*) self))), -1), _tmp2_ = (g_free (_tmp2_), NULL), _tmp1_ = (g_free (_tmp1_), NULL), _tmp0_ = (g_free (_tmp0_), NULL), _tmp3_);
+	return result;
 }
 
 
@@ -590,6 +600,7 @@ char* vala_property_get_upper_case_cname (ValaProperty* self) {
  * @return string literal to be used in C code
  */
 ValaCCodeConstant* vala_property_get_canonical_cconstant (ValaProperty* self) {
+	ValaCCodeConstant* result;
 	char* _tmp1_;
 	char* _tmp0_;
 	ValaCCodeConstant* _tmp2_;
@@ -597,24 +608,28 @@ ValaCCodeConstant* vala_property_get_canonical_cconstant (ValaProperty* self) {
 	_tmp1_ = NULL;
 	_tmp0_ = NULL;
 	_tmp2_ = NULL;
-	return (_tmp2_ = vala_ccode_constant_new (_tmp1_ = g_strdup_printf ("\"%s\"", _tmp0_ = vala_property_get_canonical_name (self))), _tmp1_ = (g_free (_tmp1_), NULL), _tmp0_ = (g_free (_tmp0_), NULL), _tmp2_);
+	result = (_tmp2_ = vala_ccode_constant_new (_tmp1_ = g_strdup_printf ("\"%s\"", _tmp0_ = vala_property_get_canonical_name (self))), _tmp1_ = (g_free (_tmp1_), NULL), _tmp0_ = (g_free (_tmp0_), NULL), _tmp2_);
+	return result;
 }
 
 
-static char* vala_property_get_canonical_name (ValaProperty* self) {
+char* vala_property_get_canonical_name (ValaProperty* self) {
+	char* result;
 	GString* str;
 	const char* _tmp0_;
 	char* i;
 	const char* _tmp3_;
-	char* _tmp4_;
 	g_return_val_if_fail (self != NULL, NULL);
 	str = g_string_new ("");
 	_tmp0_ = NULL;
 	i = (_tmp0_ = vala_symbol_get_name ((ValaSymbol*) self), (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_));
-	while (g_utf8_strlen (i, -1) > 0) {
+	while (TRUE) {
 		gunichar c;
 		char* _tmp2_;
 		const char* _tmp1_;
+		if (!(g_utf8_strlen (i, -1) > 0)) {
+			break;
+		}
 		c = g_utf8_get_char (i);
 		if (c == '_') {
 			g_string_append_c (str, '-');
@@ -626,8 +641,12 @@ static char* vala_property_get_canonical_name (ValaProperty* self) {
 		i = (_tmp2_ = (_tmp1_ = g_utf8_next_char (i), (_tmp1_ == NULL) ? NULL : g_strdup (_tmp1_)), i = (g_free (i), NULL), _tmp2_);
 	}
 	_tmp3_ = NULL;
-	_tmp4_ = NULL;
-	return (_tmp4_ = (_tmp3_ = str->str, (_tmp3_ == NULL) ? NULL : g_strdup (_tmp3_)), (str == NULL) ? NULL : (str = (g_string_free (str, TRUE), NULL)), i = (g_free (i), NULL), _tmp4_);
+	result = (_tmp3_ = str->str, (_tmp3_ == NULL) ? NULL : g_strdup (_tmp3_));
+	(str == NULL) ? NULL : (str = (g_string_free (str, TRUE), NULL));
+	i = (g_free (i), NULL);
+	return result;
+	(str == NULL) ? NULL : (str = (g_string_free (str, TRUE), NULL));
+	i = (g_free (i), NULL);
 }
 
 
@@ -637,6 +656,12 @@ static void vala_property_process_ccode_attribute (ValaProperty* self, ValaAttri
 	if (vala_attribute_has_argument (a, "notify")) {
 		vala_property_set_notify (self, vala_attribute_get_bool (a, "notify"));
 	}
+	if (vala_attribute_has_argument (a, "array_length")) {
+		vala_property_set_no_array_length (self, !vala_attribute_get_bool (a, "array_length"));
+	}
+	if (vala_attribute_has_argument (a, "array_null_terminated")) {
+		vala_property_set_array_null_terminated (self, vala_attribute_get_bool (a, "array_null_terminated"));
+	}
 }
 
 
@@ -686,8 +711,10 @@ void vala_property_process_attributes (ValaProperty* self) {
 
 static gboolean vala_property_real_get_lock_used (ValaLockable* base) {
 	ValaProperty * self;
+	gboolean result;
 	self = (ValaProperty*) base;
-	return self->priv->lock_used;
+	result = self->priv->lock_used;
+	return result;
 }
 
 
@@ -707,68 +734,85 @@ static void vala_property_real_set_lock_used (ValaLockable* base, gboolean used)
  *             property
  */
 gboolean vala_property_equals (ValaProperty* self, ValaProperty* prop2) {
+	gboolean result;
+	gboolean _tmp0_;
 	gboolean _tmp1_;
-	gboolean _tmp2_;
-	gboolean _tmp5_;
-	gboolean _tmp6_;
+	gboolean _tmp3_;
+	gboolean _tmp4_;
 	g_return_val_if_fail (self != NULL, FALSE);
 	g_return_val_if_fail (prop2 != NULL, FALSE);
-	if (!vala_data_type_equals (vala_property_get_property_type (prop2), vala_property_get_property_type (self))) {
-		return FALSE;
-	}
+	_tmp0_ = FALSE;
 	_tmp1_ = FALSE;
-	_tmp2_ = FALSE;
 	if (vala_property_get_get_accessor (self) == NULL) {
-		_tmp2_ = vala_property_get_get_accessor (prop2) != NULL;
+		_tmp1_ = vala_property_get_get_accessor (prop2) != NULL;
 	} else {
-		_tmp2_ = FALSE;
-	}
-	if (_tmp2_) {
-		_tmp1_ = TRUE;
-	} else {
-		gboolean _tmp3_;
-		_tmp3_ = FALSE;
-		if (vala_property_get_get_accessor (self) != NULL) {
-			_tmp3_ = vala_property_get_get_accessor (prop2) == NULL;
-		} else {
-			_tmp3_ = FALSE;
-		}
-		_tmp1_ = _tmp3_;
+		_tmp1_ = FALSE;
 	}
 	if (_tmp1_) {
-		return FALSE;
-	}
-	_tmp5_ = FALSE;
-	_tmp6_ = FALSE;
-	if (vala_property_get_set_accessor (self) == NULL) {
-		_tmp6_ = vala_property_get_set_accessor (prop2) != NULL;
+		_tmp0_ = TRUE;
 	} else {
-		_tmp6_ = FALSE;
-	}
-	if (_tmp6_) {
-		_tmp5_ = TRUE;
-	} else {
-		gboolean _tmp7_;
-		_tmp7_ = FALSE;
-		if (vala_property_get_set_accessor (self) != NULL) {
-			_tmp7_ = vala_property_get_set_accessor (prop2) == NULL;
+		gboolean _tmp2_;
+		_tmp2_ = FALSE;
+		if (vala_property_get_get_accessor (self) != NULL) {
+			_tmp2_ = vala_property_get_get_accessor (prop2) == NULL;
 		} else {
-			_tmp7_ = FALSE;
+			_tmp2_ = FALSE;
 		}
-		_tmp5_ = _tmp7_;
+		_tmp0_ = _tmp2_;
 	}
-	if (_tmp5_) {
-		return FALSE;
+	if (_tmp0_) {
+		result = FALSE;
+		return result;
+	}
+	_tmp3_ = FALSE;
+	_tmp4_ = FALSE;
+	if (vala_property_get_set_accessor (self) == NULL) {
+		_tmp4_ = vala_property_get_set_accessor (prop2) != NULL;
+	} else {
+		_tmp4_ = FALSE;
+	}
+	if (_tmp4_) {
+		_tmp3_ = TRUE;
+	} else {
+		gboolean _tmp5_;
+		_tmp5_ = FALSE;
+		if (vala_property_get_set_accessor (self) != NULL) {
+			_tmp5_ = vala_property_get_set_accessor (prop2) == NULL;
+		} else {
+			_tmp5_ = FALSE;
+		}
+		_tmp3_ = _tmp5_;
+	}
+	if (_tmp3_) {
+		result = FALSE;
+		return result;
+	}
+	if (vala_property_get_get_accessor (self) != NULL) {
+		/* check accessor value_type instead of property_type
+		 due to possible ownership differences*/
+		if (!vala_data_type_equals (vala_property_accessor_get_value_type (vala_property_get_get_accessor (prop2)), vala_property_accessor_get_value_type (vala_property_get_get_accessor (self)))) {
+			result = FALSE;
+			return result;
+		}
 	}
 	if (vala_property_get_set_accessor (self) != NULL) {
+		/* check accessor value_type instead of property_type
+		 due to possible ownership differences*/
+		if (!vala_data_type_equals (vala_property_accessor_get_value_type (vala_property_get_set_accessor (prop2)), vala_property_accessor_get_value_type (vala_property_get_set_accessor (self)))) {
+			result = FALSE;
+			return result;
+		}
 		if (vala_property_accessor_get_writable (vala_property_get_set_accessor (self)) != vala_property_accessor_get_writable (vala_property_get_set_accessor (prop2))) {
-			return FALSE;
+			result = FALSE;
+			return result;
 		}
 		if (vala_property_accessor_get_construction (vala_property_get_set_accessor (self)) != vala_property_accessor_get_construction (vala_property_get_set_accessor (prop2))) {
-			return FALSE;
+			result = FALSE;
+			return result;
 		}
 	}
-	return TRUE;
+	result = TRUE;
+	return result;
 }
 
 
@@ -883,9 +927,14 @@ static void vala_property_find_base_interface_property (ValaProperty* self, Vala
 		_tmp1_ = NULL;
 		_type_it = (_tmp1_ = gee_iterable_iterator ((GeeIterable*) (_tmp0_ = vala_class_get_base_types (cl))), (_tmp0_ == NULL) ? NULL : (_tmp0_ = (gee_collection_object_unref (_tmp0_), NULL)), _tmp1_);
 		/* FIXME report error if multiple possible base properties are found*/
-		while (gee_iterator_next (_type_it)) {
+		while (TRUE) {
 			ValaDataType* type;
 			/* FIXME report error if multiple possible base properties are found*/
+			if (!gee_iterator_next (_type_it)) {
+				/* FIXME report error if multiple possible base properties are found*/
+				break;
+			}
+			/* FIXME report error if multiple possible base properties are found*/
 			type = (ValaDataType*) gee_iterator_get (_type_it);
 			if (VALA_IS_INTERFACE (vala_data_type_get_data_type (type))) {
 				ValaSymbol* sym;
@@ -938,29 +987,30 @@ static void vala_property_find_base_interface_property (ValaProperty* self, Vala
 
 static gboolean vala_property_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer) {
 	ValaProperty * self;
-	ValaSourceFile* _tmp1_;
+	gboolean result;
+	ValaSourceFile* _tmp0_;
 	ValaSourceFile* old_source_file;
-	ValaSymbol* _tmp2_;
+	ValaSymbol* _tmp1_;
 	ValaSymbol* old_symbol;
-	gboolean _tmp6_;
+	gboolean _tmp5_;
+	gboolean _tmp8_;
 	gboolean _tmp9_;
 	gboolean _tmp10_;
-	gboolean _tmp11_;
-	gboolean _tmp17_;
+	gboolean _tmp16_;
+	gboolean _tmp19_;
 	gboolean _tmp20_;
-	gboolean _tmp21_;
-	gboolean _tmp25_;
 	self = (ValaProperty*) base;
 	g_return_val_if_fail (analyzer != NULL, FALSE);
 	if (vala_code_node_get_checked ((ValaCodeNode*) self)) {
-		return !vala_code_node_get_error ((ValaCodeNode*) self);
+		result = !vala_code_node_get_error ((ValaCodeNode*) self);
+		return result;
 	}
 	vala_code_node_set_checked ((ValaCodeNode*) self, TRUE);
 	vala_property_process_attributes (self);
+	_tmp0_ = NULL;
+	old_source_file = (_tmp0_ = vala_semantic_analyzer_get_current_source_file (analyzer), (_tmp0_ == NULL) ? NULL : vala_source_file_ref (_tmp0_));
 	_tmp1_ = NULL;
-	old_source_file = (_tmp1_ = vala_semantic_analyzer_get_current_source_file (analyzer), (_tmp1_ == NULL) ? NULL : vala_source_file_ref (_tmp1_));
-	_tmp2_ = NULL;
-	old_symbol = (_tmp2_ = vala_semantic_analyzer_get_current_symbol (analyzer), (_tmp2_ == NULL) ? NULL : vala_code_node_ref (_tmp2_));
+	old_symbol = (_tmp1_ = vala_semantic_analyzer_get_current_symbol (analyzer), (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_));
 	if (vala_code_node_get_source_reference ((ValaCodeNode*) self) != NULL) {
 		vala_semantic_analyzer_set_current_source_file (analyzer, vala_source_reference_get_file (vala_code_node_get_source_reference ((ValaCodeNode*) self)));
 	}
@@ -977,132 +1027,137 @@ static gboolean vala_property_real_check (ValaCodeNode* base, ValaSemanticAnalyz
 	}
 	/* check whether property type is at least as accessible as the property*/
 	if (!vala_semantic_analyzer_is_type_accessible (analyzer, (ValaSymbol*) self, vala_property_get_property_type (self))) {
-		char* _tmp5_;
 		char* _tmp4_;
 		char* _tmp3_;
+		char* _tmp2_;
 		vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
-		_tmp5_ = NULL;
 		_tmp4_ = NULL;
 		_tmp3_ = NULL;
-		vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp5_ = g_strdup_printf ("property type `%s` is less accessible than property `%s`", _tmp3_ = vala_code_node_to_string ((ValaCodeNode*) vala_property_get_property_type (self)), _tmp4_ = vala_symbol_get_full_name ((ValaSymbol*) self)));
-		_tmp5_ = (g_free (_tmp5_), NULL);
+		_tmp2_ = NULL;
+		vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp4_ = g_strdup_printf ("property type `%s` is less accessible than property `%s`", _tmp2_ = vala_code_node_to_string ((ValaCodeNode*) vala_property_get_property_type (self)), _tmp3_ = vala_symbol_get_full_name ((ValaSymbol*) self)));
 		_tmp4_ = (g_free (_tmp4_), NULL);
 		_tmp3_ = (g_free (_tmp3_), NULL);
+		_tmp2_ = (g_free (_tmp2_), NULL);
 	}
-	_tmp6_ = FALSE;
+	_tmp5_ = FALSE;
 	if (self->priv->_overrides) {
-		_tmp6_ = vala_property_get_base_property (self) == NULL;
+		_tmp5_ = vala_property_get_base_property (self) == NULL;
 	} else {
-		_tmp6_ = FALSE;
+		_tmp5_ = FALSE;
 	}
-	if (_tmp6_) {
-		char* _tmp8_;
+	if (_tmp5_) {
 		char* _tmp7_;
-		_tmp8_ = NULL;
+		char* _tmp6_;
 		_tmp7_ = NULL;
-		vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp8_ = g_strdup_printf ("%s: no suitable property found to override", _tmp7_ = vala_symbol_get_full_name ((ValaSymbol*) self)));
-		_tmp8_ = (g_free (_tmp8_), NULL);
+		_tmp6_ = NULL;
+		vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp7_ = g_strdup_printf ("%s: no suitable property found to override", _tmp6_ = vala_symbol_get_full_name ((ValaSymbol*) self)));
 		_tmp7_ = (g_free (_tmp7_), NULL);
+		_tmp6_ = (g_free (_tmp6_), NULL);
 	}
+	_tmp8_ = FALSE;
 	_tmp9_ = FALSE;
 	_tmp10_ = FALSE;
-	_tmp11_ = FALSE;
 	if (!vala_symbol_get_external_package ((ValaSymbol*) self)) {
-		_tmp11_ = !self->priv->_overrides;
-	} else {
-		_tmp11_ = FALSE;
-	}
-	if (_tmp11_) {
-		_tmp10_ = !vala_member_get_hides ((ValaMember*) self);
+		_tmp10_ = !self->priv->_overrides;
 	} else {
 		_tmp10_ = FALSE;
 	}
 	if (_tmp10_) {
-		ValaSymbol* _tmp12_;
-		_tmp12_ = NULL;
-		_tmp9_ = (_tmp12_ = vala_member_get_hidden_member ((ValaMember*) self)) != NULL;
-		(_tmp12_ == NULL) ? NULL : (_tmp12_ = (vala_code_node_unref (_tmp12_), NULL));
+		_tmp9_ = !vala_member_get_hides ((ValaMember*) self);
 	} else {
 		_tmp9_ = FALSE;
 	}
 	if (_tmp9_) {
-		char* _tmp16_;
+		ValaSymbol* _tmp11_;
+		_tmp11_ = NULL;
+		_tmp8_ = (_tmp11_ = vala_member_get_hidden_member ((ValaMember*) self)) != NULL;
+		(_tmp11_ == NULL) ? NULL : (_tmp11_ = (vala_code_node_unref (_tmp11_), NULL));
+	} else {
+		_tmp8_ = FALSE;
+	}
+	if (_tmp8_) {
 		char* _tmp15_;
-		ValaSymbol* _tmp14_;
-		char* _tmp13_;
-		_tmp16_ = NULL;
+		char* _tmp14_;
+		ValaSymbol* _tmp13_;
+		char* _tmp12_;
 		_tmp15_ = NULL;
 		_tmp14_ = NULL;
 		_tmp13_ = NULL;
-		vala_report_warning (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp16_ = g_strdup_printf ("%s hides inherited property `%s'. Use the `new' keyword if hiding was intentional", _tmp13_ = vala_symbol_get_full_name ((ValaSymbol*) self), _tmp15_ = vala_symbol_get_full_name (_tmp14_ = vala_member_get_hidden_member ((ValaMember*) self))));
-		_tmp16_ = (g_free (_tmp16_), NULL);
+		_tmp12_ = NULL;
+		vala_report_warning (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp15_ = g_strdup_printf ("%s hides inherited property `%s'. Use the `new' keyword if hiding was intentional", _tmp12_ = vala_symbol_get_full_name ((ValaSymbol*) self), _tmp14_ = vala_symbol_get_full_name (_tmp13_ = vala_member_get_hidden_member ((ValaMember*) self))));
 		_tmp15_ = (g_free (_tmp15_), NULL);
-		(_tmp14_ == NULL) ? NULL : (_tmp14_ = (vala_code_node_unref (_tmp14_), NULL));
-		_tmp13_ = (g_free (_tmp13_), NULL);
+		_tmp14_ = (g_free (_tmp14_), NULL);
+		(_tmp13_ == NULL) ? NULL : (_tmp13_ = (vala_code_node_unref (_tmp13_), NULL));
+		_tmp12_ = (g_free (_tmp12_), NULL);
 	}
-	_tmp17_ = FALSE;
+	_tmp16_ = FALSE;
 	if (vala_property_get_set_accessor (self) != NULL) {
-		_tmp17_ = vala_property_accessor_get_construction (vala_property_get_set_accessor (self));
+		_tmp16_ = vala_property_accessor_get_construction (vala_property_get_set_accessor (self));
 	} else {
-		_tmp17_ = FALSE;
+		_tmp16_ = FALSE;
 	}
 	/* construct properties must be public */
-	if (_tmp17_) {
+	if (_tmp16_) {
 		if (vala_symbol_get_access ((ValaSymbol*) self) != VALA_SYMBOL_ACCESSIBILITY_PUBLIC) {
-			char* _tmp19_;
 			char* _tmp18_;
+			char* _tmp17_;
 			vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
-			_tmp19_ = NULL;
 			_tmp18_ = NULL;
-			vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp19_ = g_strdup_printf ("%s: construct properties must be public", _tmp18_ = vala_symbol_get_full_name ((ValaSymbol*) self)));
-			_tmp19_ = (g_free (_tmp19_), NULL);
+			_tmp17_ = NULL;
+			vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp18_ = g_strdup_printf ("%s: construct properties must be public", _tmp17_ = vala_symbol_get_full_name ((ValaSymbol*) self)));
 			_tmp18_ = (g_free (_tmp18_), NULL);
+			_tmp17_ = (g_free (_tmp17_), NULL);
 		}
 	}
+	_tmp19_ = FALSE;
 	_tmp20_ = FALSE;
-	_tmp21_ = FALSE;
 	if (self->priv->_default_expression != NULL) {
-		_tmp21_ = !vala_code_node_get_error ((ValaCodeNode*) self->priv->_default_expression);
-	} else {
-		_tmp21_ = FALSE;
-	}
-	if (_tmp21_) {
-		_tmp20_ = !vala_data_type_compatible (vala_expression_get_value_type (self->priv->_default_expression), vala_property_get_property_type (self));
+		_tmp20_ = !vala_code_node_get_error ((ValaCodeNode*) self->priv->_default_expression);
 	} else {
 		_tmp20_ = FALSE;
 	}
 	if (_tmp20_) {
-		char* _tmp24_;
+		_tmp19_ = !vala_data_type_compatible (vala_expression_get_value_type (self->priv->_default_expression), vala_property_get_property_type (self));
+	} else {
+		_tmp19_ = FALSE;
+	}
+	if (_tmp19_) {
 		char* _tmp23_;
 		char* _tmp22_;
+		char* _tmp21_;
 		vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
-		_tmp24_ = NULL;
 		_tmp23_ = NULL;
 		_tmp22_ = NULL;
-		vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self->priv->_default_expression), _tmp24_ = g_strdup_printf ("Expected initializer of type `%s' but got `%s'", _tmp22_ = vala_code_node_to_string ((ValaCodeNode*) vala_property_get_property_type (self)), _tmp23_ = vala_code_node_to_string ((ValaCodeNode*) vala_expression_get_value_type (self->priv->_default_expression))));
-		_tmp24_ = (g_free (_tmp24_), NULL);
+		_tmp21_ = NULL;
+		vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self->priv->_default_expression), _tmp23_ = g_strdup_printf ("Expected initializer of type `%s' but got `%s'", _tmp21_ = vala_code_node_to_string ((ValaCodeNode*) vala_property_get_property_type (self)), _tmp22_ = vala_code_node_to_string ((ValaCodeNode*) vala_expression_get_value_type (self->priv->_default_expression))));
 		_tmp23_ = (g_free (_tmp23_), NULL);
 		_tmp22_ = (g_free (_tmp22_), NULL);
+		_tmp21_ = (g_free (_tmp21_), NULL);
 	}
 	vala_semantic_analyzer_set_current_source_file (analyzer, old_source_file);
 	vala_semantic_analyzer_set_current_symbol (analyzer, old_symbol);
-	return (_tmp25_ = !vala_code_node_get_error ((ValaCodeNode*) self), (old_source_file == NULL) ? NULL : (old_source_file = (vala_source_file_unref (old_source_file), NULL)), (old_symbol == NULL) ? NULL : (old_symbol = (vala_code_node_unref (old_symbol), NULL)), _tmp25_);
+	result = !vala_code_node_get_error ((ValaCodeNode*) self);
+	(old_source_file == NULL) ? NULL : (old_source_file = (vala_source_file_unref (old_source_file), NULL));
+	(old_symbol == NULL) ? NULL : (old_symbol = (vala_code_node_unref (old_symbol), NULL));
+	return result;
 }
 
 
 ValaDataType* vala_property_get_property_type (ValaProperty* self) {
+	ValaDataType* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_data_type;
+	result = self->priv->_data_type;
+	return result;
 }
 
 
 void vala_property_set_property_type (ValaProperty* self, ValaDataType* value) {
-	ValaDataType* _tmp2_;
 	ValaDataType* _tmp1_;
+	ValaDataType* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2_ = NULL;
 	_tmp1_ = NULL;
-	self->priv->_data_type = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_)), (self->priv->_data_type == NULL) ? NULL : (self->priv->_data_type = (vala_code_node_unref (self->priv->_data_type), NULL)), _tmp2_);
+	_tmp0_ = NULL;
+	self->priv->_data_type = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_)), (self->priv->_data_type == NULL) ? NULL : (self->priv->_data_type = (vala_code_node_unref (self->priv->_data_type), NULL)), _tmp1_);
 	if (value != NULL) {
 		vala_code_node_set_parent_node ((ValaCodeNode*) self->priv->_data_type, (ValaCodeNode*) self);
 	}
@@ -1110,18 +1165,20 @@ void vala_property_set_property_type (ValaProperty* self, ValaDataType* value) {
 
 
 ValaPropertyAccessor* vala_property_get_get_accessor (ValaProperty* self) {
+	ValaPropertyAccessor* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_get_accessor;
+	result = self->priv->_get_accessor;
+	return result;
 }
 
 
 void vala_property_set_get_accessor (ValaProperty* self, ValaPropertyAccessor* value) {
-	ValaPropertyAccessor* _tmp2_;
 	ValaPropertyAccessor* _tmp1_;
+	ValaPropertyAccessor* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2_ = NULL;
 	_tmp1_ = NULL;
-	self->priv->_get_accessor = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_)), (self->priv->_get_accessor == NULL) ? NULL : (self->priv->_get_accessor = (vala_code_node_unref (self->priv->_get_accessor), NULL)), _tmp2_);
+	_tmp0_ = NULL;
+	self->priv->_get_accessor = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_)), (self->priv->_get_accessor == NULL) ? NULL : (self->priv->_get_accessor = (vala_code_node_unref (self->priv->_get_accessor), NULL)), _tmp1_);
 	if (value != NULL) {
 		vala_property_accessor_set_prop (value, self);
 	}
@@ -1129,18 +1186,20 @@ void vala_property_set_get_accessor (ValaProperty* self, ValaPropertyAccessor* v
 
 
 ValaPropertyAccessor* vala_property_get_set_accessor (ValaProperty* self) {
+	ValaPropertyAccessor* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_set_accessor;
+	result = self->priv->_set_accessor;
+	return result;
 }
 
 
 void vala_property_set_set_accessor (ValaProperty* self, ValaPropertyAccessor* value) {
-	ValaPropertyAccessor* _tmp2_;
 	ValaPropertyAccessor* _tmp1_;
+	ValaPropertyAccessor* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2_ = NULL;
 	_tmp1_ = NULL;
-	self->priv->_set_accessor = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_)), (self->priv->_set_accessor == NULL) ? NULL : (self->priv->_set_accessor = (vala_code_node_unref (self->priv->_set_accessor), NULL)), _tmp2_);
+	_tmp0_ = NULL;
+	self->priv->_set_accessor = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_)), (self->priv->_set_accessor == NULL) ? NULL : (self->priv->_set_accessor = (vala_code_node_unref (self->priv->_set_accessor), NULL)), _tmp1_);
 	if (value != NULL) {
 		vala_property_accessor_set_prop (value, self);
 	}
@@ -1148,24 +1207,28 @@ void vala_property_set_set_accessor (ValaProperty* self, ValaPropertyAccessor* v
 
 
 ValaFormalParameter* vala_property_get_this_parameter (ValaProperty* self) {
+	ValaFormalParameter* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_this_parameter;
+	result = self->priv->_this_parameter;
+	return result;
 }
 
 
 void vala_property_set_this_parameter (ValaProperty* self, ValaFormalParameter* value) {
-	ValaFormalParameter* _tmp2_;
 	ValaFormalParameter* _tmp1_;
+	ValaFormalParameter* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2_ = NULL;
 	_tmp1_ = NULL;
-	self->priv->_this_parameter = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_)), (self->priv->_this_parameter == NULL) ? NULL : (self->priv->_this_parameter = (vala_code_node_unref (self->priv->_this_parameter), NULL)), _tmp2_);
+	_tmp0_ = NULL;
+	self->priv->_this_parameter = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_)), (self->priv->_this_parameter == NULL) ? NULL : (self->priv->_this_parameter = (vala_code_node_unref (self->priv->_this_parameter), NULL)), _tmp1_);
 }
 
 
 gboolean vala_property_get_notify (ValaProperty* self) {
+	gboolean result;
 	g_return_val_if_fail (self != NULL, FALSE);
-	return self->priv->_notify;
+	result = self->priv->_notify;
+	return result;
 }
 
 
@@ -1176,8 +1239,10 @@ void vala_property_set_notify (ValaProperty* self, gboolean value) {
 
 
 gboolean vala_property_get_no_accessor_method (ValaProperty* self) {
+	gboolean result;
 	g_return_val_if_fail (self != NULL, FALSE);
-	return self->priv->_no_accessor_method;
+	result = self->priv->_no_accessor_method;
+	return result;
 }
 
 
@@ -1188,8 +1253,10 @@ void vala_property_set_no_accessor_method (ValaProperty* self, gboolean value) {
 
 
 gboolean vala_property_get_interface_only (ValaProperty* self) {
+	gboolean result;
 	g_return_val_if_fail (self != NULL, FALSE);
-	return self->priv->_interface_only;
+	result = self->priv->_interface_only;
+	return result;
 }
 
 
@@ -1200,8 +1267,10 @@ void vala_property_set_interface_only (ValaProperty* self, gboolean value) {
 
 
 gboolean vala_property_get_is_abstract (ValaProperty* self) {
+	gboolean result;
 	g_return_val_if_fail (self != NULL, FALSE);
-	return self->priv->_is_abstract;
+	result = self->priv->_is_abstract;
+	return result;
 }
 
 
@@ -1212,8 +1281,10 @@ void vala_property_set_is_abstract (ValaProperty* self, gboolean value) {
 
 
 gboolean vala_property_get_is_virtual (ValaProperty* self) {
+	gboolean result;
 	g_return_val_if_fail (self != NULL, FALSE);
-	return self->priv->_is_virtual;
+	result = self->priv->_is_virtual;
+	return result;
 }
 
 
@@ -1224,8 +1295,10 @@ void vala_property_set_is_virtual (ValaProperty* self, gboolean value) {
 
 
 gboolean vala_property_get_overrides (ValaProperty* self) {
+	gboolean result;
 	g_return_val_if_fail (self != NULL, FALSE);
-	return self->priv->_overrides;
+	result = self->priv->_overrides;
+	return result;
 }
 
 
@@ -1236,24 +1309,28 @@ void vala_property_set_overrides (ValaProperty* self, gboolean value) {
 
 
 ValaField* vala_property_get_field (ValaProperty* self) {
+	ValaField* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_field;
+	result = self->priv->_field;
+	return result;
 }
 
 
 void vala_property_set_field (ValaProperty* self, ValaField* value) {
-	ValaField* _tmp2_;
 	ValaField* _tmp1_;
+	ValaField* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2_ = NULL;
 	_tmp1_ = NULL;
-	self->priv->_field = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_)), (self->priv->_field == NULL) ? NULL : (self->priv->_field = (vala_code_node_unref (self->priv->_field), NULL)), _tmp2_);
+	_tmp0_ = NULL;
+	self->priv->_field = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_)), (self->priv->_field == NULL) ? NULL : (self->priv->_field = (vala_code_node_unref (self->priv->_field), NULL)), _tmp1_);
 }
 
 
 MemberBinding vala_property_get_binding (ValaProperty* self) {
+	MemberBinding result;
 	g_return_val_if_fail (self != NULL, 0);
-	return self->priv->_binding;
+	result = self->priv->_binding;
+	return result;
 }
 
 
@@ -1264,74 +1341,112 @@ void vala_property_set_binding (ValaProperty* self, MemberBinding value) {
 
 
 ValaProperty* vala_property_get_base_property (ValaProperty* self) {
+	ValaProperty* result;
 	g_return_val_if_fail (self != NULL, NULL);
 	vala_property_find_base_properties (self);
-	return self->priv->_base_property;
+	result = self->priv->_base_property;
+	return result;
 }
 
 
 ValaProperty* vala_property_get_base_interface_property (ValaProperty* self) {
+	ValaProperty* result;
 	g_return_val_if_fail (self != NULL, NULL);
 	vala_property_find_base_properties (self);
-	return self->priv->_base_interface_property;
+	result = self->priv->_base_interface_property;
+	return result;
 }
 
 
 ValaExpression* vala_property_get_default_expression (ValaProperty* self) {
+	ValaExpression* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_default_expression;
+	result = self->priv->_default_expression;
+	return result;
 }
 
 
 void vala_property_set_default_expression (ValaProperty* self, ValaExpression* value) {
-	ValaExpression* _tmp2_;
 	ValaExpression* _tmp1_;
+	ValaExpression* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2_ = NULL;
 	_tmp1_ = NULL;
-	self->priv->_default_expression = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_)), (self->priv->_default_expression == NULL) ? NULL : (self->priv->_default_expression = (vala_code_node_unref (self->priv->_default_expression), NULL)), _tmp2_);
+	_tmp0_ = NULL;
+	self->priv->_default_expression = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_)), (self->priv->_default_expression == NULL) ? NULL : (self->priv->_default_expression = (vala_code_node_unref (self->priv->_default_expression), NULL)), _tmp1_);
+}
+
+
+gboolean vala_property_get_no_array_length (ValaProperty* self) {
+	gboolean result;
+	g_return_val_if_fail (self != NULL, FALSE);
+	result = self->priv->_no_array_length;
+	return result;
+}
+
+
+void vala_property_set_no_array_length (ValaProperty* self, gboolean value) {
+	g_return_if_fail (self != NULL);
+	self->priv->_no_array_length = value;
+}
+
+
+gboolean vala_property_get_array_null_terminated (ValaProperty* self) {
+	gboolean result;
+	g_return_val_if_fail (self != NULL, FALSE);
+	result = self->priv->_array_null_terminated;
+	return result;
+}
+
+
+void vala_property_set_array_null_terminated (ValaProperty* self, gboolean value) {
+	g_return_if_fail (self != NULL);
+	self->priv->_array_null_terminated = value;
 }
 
 
 const char* vala_property_get_nick (ValaProperty* self) {
+	const char* result;
 	g_return_val_if_fail (self != NULL, NULL);
 	if (self->priv->_nick == NULL) {
 		char* _tmp0_;
 		_tmp0_ = NULL;
 		self->priv->_nick = (_tmp0_ = vala_property_get_canonical_name (self), self->priv->_nick = (g_free (self->priv->_nick), NULL), _tmp0_);
 	}
-	return self->priv->_nick;
+	result = self->priv->_nick;
+	return result;
 }
 
 
 void vala_property_set_nick (ValaProperty* self, const char* value) {
-	char* _tmp3_;
-	const char* _tmp2_;
+	char* _tmp2_;
+	const char* _tmp1_;
 	g_return_if_fail (self != NULL);
-	_tmp3_ = NULL;
 	_tmp2_ = NULL;
-	self->priv->_nick = (_tmp3_ = (_tmp2_ = value, (_tmp2_ == NULL) ? NULL : g_strdup (_tmp2_)), self->priv->_nick = (g_free (self->priv->_nick), NULL), _tmp3_);
+	_tmp1_ = NULL;
+	self->priv->_nick = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : g_strdup (_tmp1_)), self->priv->_nick = (g_free (self->priv->_nick), NULL), _tmp2_);
 }
 
 
 const char* vala_property_get_blurb (ValaProperty* self) {
+	const char* result;
 	g_return_val_if_fail (self != NULL, NULL);
 	if (self->priv->_blurb == NULL) {
 		char* _tmp0_;
 		_tmp0_ = NULL;
 		self->priv->_blurb = (_tmp0_ = vala_property_get_canonical_name (self), self->priv->_blurb = (g_free (self->priv->_blurb), NULL), _tmp0_);
 	}
-	return self->priv->_blurb;
+	result = self->priv->_blurb;
+	return result;
 }
 
 
 void vala_property_set_blurb (ValaProperty* self, const char* value) {
-	char* _tmp3_;
-	const char* _tmp2_;
+	char* _tmp2_;
+	const char* _tmp1_;
 	g_return_if_fail (self != NULL);
-	_tmp3_ = NULL;
 	_tmp2_ = NULL;
-	self->priv->_blurb = (_tmp3_ = (_tmp2_ = value, (_tmp2_ == NULL) ? NULL : g_strdup (_tmp2_)), self->priv->_blurb = (g_free (self->priv->_blurb), NULL), _tmp3_);
+	_tmp1_ = NULL;
+	self->priv->_blurb = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : g_strdup (_tmp1_)), self->priv->_blurb = (g_free (self->priv->_blurb), NULL), _tmp2_);
 }
 
 
