@@ -482,6 +482,16 @@ typedef struct _ValaSwitchSectionClass ValaSwitchSectionClass;
 typedef struct _ValaSwitchLabel ValaSwitchLabel;
 typedef struct _ValaSwitchLabelClass ValaSwitchLabelClass;
 
+#define VALA_TYPE_LOOP (vala_loop_get_type ())
+#define VALA_LOOP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_LOOP, ValaLoop))
+#define VALA_LOOP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_LOOP, ValaLoopClass))
+#define VALA_IS_LOOP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_LOOP))
+#define VALA_IS_LOOP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_LOOP))
+#define VALA_LOOP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_LOOP, ValaLoopClass))
+
+typedef struct _ValaLoop ValaLoop;
+typedef struct _ValaLoopClass ValaLoopClass;
+
 #define VALA_TYPE_WHILE_STATEMENT (vala_while_statement_get_type ())
 #define VALA_WHILE_STATEMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_WHILE_STATEMENT, ValaWhileStatement))
 #define VALA_WHILE_STATEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_WHILE_STATEMENT, ValaWhileStatementClass))
@@ -853,16 +863,6 @@ typedef struct _ValaAssignment ValaAssignment;
 typedef struct _ValaAssignmentClass ValaAssignmentClass;
 typedef struct _ValaSemanticAnalyzerPrivate ValaSemanticAnalyzerPrivate;
 
-#define VALA_TYPE_SCOPE (vala_scope_get_type ())
-#define VALA_SCOPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SCOPE, ValaScope))
-#define VALA_SCOPE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_SCOPE, ValaScopeClass))
-#define VALA_IS_SCOPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_SCOPE))
-#define VALA_IS_SCOPE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_SCOPE))
-#define VALA_SCOPE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_SCOPE, ValaScopeClass))
-
-typedef struct _ValaScope ValaScope;
-typedef struct _ValaScopeClass ValaScopeClass;
-
 #define VALA_TYPE_VALUE_TYPE (vala_value_type_get_type ())
 #define VALA_VALUE_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_VALUE_TYPE, ValaValueType))
 #define VALA_VALUE_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_VALUE_TYPE, ValaValueTypeClass))
@@ -873,6 +873,26 @@ typedef struct _ValaScopeClass ValaScopeClass;
 typedef struct _ValaValueType ValaValueType;
 typedef struct _ValaValueTypeClass ValaValueTypeClass;
 
+#define VALA_TYPE_STRUCT_VALUE_TYPE (vala_struct_value_type_get_type ())
+#define VALA_STRUCT_VALUE_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_STRUCT_VALUE_TYPE, ValaStructValueType))
+#define VALA_STRUCT_VALUE_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_STRUCT_VALUE_TYPE, ValaStructValueTypeClass))
+#define VALA_IS_STRUCT_VALUE_TYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_STRUCT_VALUE_TYPE))
+#define VALA_IS_STRUCT_VALUE_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_STRUCT_VALUE_TYPE))
+#define VALA_STRUCT_VALUE_TYPE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_STRUCT_VALUE_TYPE, ValaStructValueTypeClass))
+
+typedef struct _ValaStructValueType ValaStructValueType;
+typedef struct _ValaStructValueTypeClass ValaStructValueTypeClass;
+
+#define VALA_TYPE_SCOPE (vala_scope_get_type ())
+#define VALA_SCOPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SCOPE, ValaScope))
+#define VALA_SCOPE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_SCOPE, ValaScopeClass))
+#define VALA_IS_SCOPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_SCOPE))
+#define VALA_IS_SCOPE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_SCOPE))
+#define VALA_SCOPE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_SCOPE, ValaScopeClass))
+
+typedef struct _ValaScope ValaScope;
+typedef struct _ValaScopeClass ValaScopeClass;
+
 #define VALA_TYPE_FLOATING_TYPE (vala_floating_type_get_type ())
 #define VALA_FLOATING_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_FLOATING_TYPE, ValaFloatingType))
 #define VALA_FLOATING_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_FLOATING_TYPE, ValaFloatingTypeClass))
@@ -999,6 +1019,7 @@ struct _ValaCodeVisitorClass {
 	void (*visit_switch_statement) (ValaCodeVisitor* self, ValaSwitchStatement* stmt);
 	void (*visit_switch_section) (ValaCodeVisitor* self, ValaSwitchSection* section);
 	void (*visit_switch_label) (ValaCodeVisitor* self, ValaSwitchLabel* label);
+	void (*visit_loop) (ValaCodeVisitor* self, ValaLoop* stmt);
 	void (*visit_while_statement) (ValaCodeVisitor* self, ValaWhileStatement* stmt);
 	void (*visit_do_statement) (ValaCodeVisitor* self, ValaDoStatement* stmt);
 	void (*visit_for_statement) (ValaCodeVisitor* self, ValaForStatement* stmt);
@@ -1068,9 +1089,11 @@ struct _ValaSemanticAnalyzer {
 	ValaDataType* double_type;
 	ValaDataType* type_type;
 	ValaClass* object_type;
+	ValaStructValueType* gvalue_type;
 	ValaDataType* glist_type;
 	ValaDataType* gslist_type;
 	ValaDataType* garray_type;
+	ValaDataType* gvaluearray_type;
 	ValaClass* gerror_type;
 	gint next_lambda_id;
 	GeeList* replaced_nodes;
@@ -1081,6 +1104,7 @@ struct _ValaSemanticAnalyzerClass {
 };
 
 
+static gpointer vala_real_literal_parent_class = NULL;
 
 gpointer vala_code_node_ref (gpointer instance);
 void vala_code_node_unref (gpointer instance);
@@ -1116,7 +1140,6 @@ GType vala_source_reference_get_type (void);
 void vala_code_node_set_source_reference (ValaCodeNode* self, ValaSourceReference* value);
 ValaRealLiteral* vala_real_literal_new (const char* r, ValaSourceReference* source);
 ValaRealLiteral* vala_real_literal_construct (GType object_type, const char* r, ValaSourceReference* source);
-ValaRealLiteral* vala_real_literal_new (const char* r, ValaSourceReference* source);
 void vala_code_visitor_visit_real_literal (ValaCodeVisitor* self, ValaRealLiteral* lit);
 void vala_code_visitor_visit_expression (ValaCodeVisitor* self, ValaExpression* expr);
 static void vala_real_literal_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
@@ -1166,6 +1189,7 @@ GType vala_if_statement_get_type (void);
 GType vala_switch_statement_get_type (void);
 GType vala_switch_section_get_type (void);
 GType vala_switch_label_get_type (void);
+GType vala_loop_get_type (void);
 GType vala_while_statement_get_type (void);
 GType vala_do_statement_get_type (void);
 GType vala_for_statement_get_type (void);
@@ -1203,6 +1227,8 @@ GType vala_typecheck_get_type (void);
 GType vala_conditional_expression_get_type (void);
 GType vala_lambda_expression_get_type (void);
 GType vala_assignment_get_type (void);
+GType vala_value_type_get_type (void);
+GType vala_struct_value_type_get_type (void);
 gpointer vala_scope_ref (gpointer instance);
 void vala_scope_unref (gpointer instance);
 GParamSpec* vala_param_spec_scope (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
@@ -1213,11 +1239,9 @@ ValaScope* vala_symbol_get_scope (ValaSymbol* self);
 ValaSymbol* vala_scope_lookup (ValaScope* self, const char* name);
 ValaFloatingType* vala_floating_type_new (ValaStruct* type_symbol);
 ValaFloatingType* vala_floating_type_construct (GType object_type, ValaStruct* type_symbol);
-GType vala_value_type_get_type (void);
 GType vala_floating_type_get_type (void);
 void vala_expression_set_value_type (ValaExpression* self, ValaDataType* value);
 static gboolean vala_real_literal_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer);
-static gpointer vala_real_literal_parent_class = NULL;
 static void vala_real_literal_finalize (ValaCodeNode* obj);
 
 
@@ -1260,6 +1284,7 @@ static void vala_real_literal_real_accept (ValaCodeNode* base, ValaCodeVisitor*
  * @return the name of literal type
  */
 char* vala_real_literal_get_type_name (ValaRealLiteral* self) {
+	char* result;
 	gboolean _tmp0_;
 	g_return_val_if_fail (self != NULL, NULL);
 	_tmp0_ = FALSE;
@@ -1269,63 +1294,74 @@ char* vala_real_literal_get_type_name (ValaRealLiteral* self) {
 		_tmp0_ = g_str_has_suffix (self->priv->_value, "F");
 	}
 	if (_tmp0_) {
-		return g_strdup ("float");
+		result = g_strdup ("float");
+		return result;
 	}
-	return g_strdup ("double");
+	result = g_strdup ("double");
+	return result;
 }
 
 
 static gboolean vala_real_literal_real_is_pure (ValaExpression* base) {
 	ValaRealLiteral * self;
+	gboolean result;
 	self = (ValaRealLiteral*) base;
-	return TRUE;
+	result = TRUE;
+	return result;
 }
 
 
 static char* vala_real_literal_real_to_string (ValaCodeNode* base) {
 	ValaRealLiteral * self;
+	char* result;
 	const char* _tmp0_;
 	self = (ValaRealLiteral*) base;
 	_tmp0_ = NULL;
-	return (_tmp0_ = self->priv->_value, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_));
+	result = (_tmp0_ = self->priv->_value, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_));
+	return result;
 }
 
 
 static gboolean vala_real_literal_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer) {
 	ValaRealLiteral * self;
-	ValaFloatingType* _tmp3_;
-	ValaStruct* _tmp2_;
-	char* _tmp1_;
+	gboolean result;
+	ValaFloatingType* _tmp2_;
+	ValaStruct* _tmp1_;
+	char* _tmp0_;
 	self = (ValaRealLiteral*) base;
 	g_return_val_if_fail (analyzer != NULL, FALSE);
 	if (vala_code_node_get_checked ((ValaCodeNode*) self)) {
-		return !vala_code_node_get_error ((ValaCodeNode*) self);
+		result = !vala_code_node_get_error ((ValaCodeNode*) self);
+		return result;
 	}
 	vala_code_node_set_checked ((ValaCodeNode*) self, TRUE);
-	_tmp3_ = NULL;
 	_tmp2_ = NULL;
 	_tmp1_ = NULL;
-	vala_expression_set_value_type ((ValaExpression*) self, (ValaDataType*) (_tmp3_ = vala_floating_type_new (_tmp2_ = VALA_STRUCT (vala_scope_lookup (vala_symbol_get_scope (analyzer->root_symbol), _tmp1_ = vala_real_literal_get_type_name (self))))));
-	(_tmp3_ == NULL) ? NULL : (_tmp3_ = (vala_code_node_unref (_tmp3_), NULL));
+	_tmp0_ = NULL;
+	vala_expression_set_value_type ((ValaExpression*) self, (ValaDataType*) (_tmp2_ = vala_floating_type_new (_tmp1_ = VALA_STRUCT (vala_scope_lookup (vala_symbol_get_scope (analyzer->root_symbol), _tmp0_ = vala_real_literal_get_type_name (self))))));
 	(_tmp2_ == NULL) ? NULL : (_tmp2_ = (vala_code_node_unref (_tmp2_), NULL));
-	_tmp1_ = (g_free (_tmp1_), NULL);
-	return !vala_code_node_get_error ((ValaCodeNode*) self);
+	(_tmp1_ == NULL) ? NULL : (_tmp1_ = (vala_code_node_unref (_tmp1_), NULL));
+	_tmp0_ = (g_free (_tmp0_), NULL);
+	result = !vala_code_node_get_error ((ValaCodeNode*) self);
+	return result;
 }
 
 
 const char* vala_real_literal_get_value (ValaRealLiteral* self) {
+	const char* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_value;
+	result = self->priv->_value;
+	return result;
 }
 
 
 void vala_real_literal_set_value (ValaRealLiteral* self, const char* value) {
-	char* _tmp2_;
-	const char* _tmp1_;
+	char* _tmp1_;
+	const char* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2_ = NULL;
 	_tmp1_ = NULL;
-	self->priv->_value = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : g_strdup (_tmp1_)), self->priv->_value = (g_free (self->priv->_value), NULL), _tmp2_);
+	_tmp0_ = NULL;
+	self->priv->_value = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_)), self->priv->_value = (g_free (self->priv->_value), NULL), _tmp1_);
 }
 
 
