@@ -478,6 +478,16 @@ typedef struct _ValaSwitchSectionClass ValaSwitchSectionClass;
 typedef struct _ValaSwitchLabel ValaSwitchLabel;
 typedef struct _ValaSwitchLabelClass ValaSwitchLabelClass;
 
+#define VALA_TYPE_LOOP (vala_loop_get_type ())
+#define VALA_LOOP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_LOOP, ValaLoop))
+#define VALA_LOOP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_LOOP, ValaLoopClass))
+#define VALA_IS_LOOP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_LOOP))
+#define VALA_IS_LOOP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_LOOP))
+#define VALA_LOOP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_LOOP, ValaLoopClass))
+
+typedef struct _ValaLoop ValaLoop;
+typedef struct _ValaLoopClass ValaLoopClass;
+
 #define VALA_TYPE_WHILE_STATEMENT (vala_while_statement_get_type ())
 #define VALA_WHILE_STATEMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_WHILE_STATEMENT, ValaWhileStatement))
 #define VALA_WHILE_STATEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_WHILE_STATEMENT, ValaWhileStatementClass))
@@ -859,6 +869,26 @@ typedef struct _ValaAssignment ValaAssignment;
 typedef struct _ValaAssignmentClass ValaAssignmentClass;
 typedef struct _ValaSemanticAnalyzerPrivate ValaSemanticAnalyzerPrivate;
 
+#define VALA_TYPE_VALUE_TYPE (vala_value_type_get_type ())
+#define VALA_VALUE_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_VALUE_TYPE, ValaValueType))
+#define VALA_VALUE_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_VALUE_TYPE, ValaValueTypeClass))
+#define VALA_IS_VALUE_TYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_VALUE_TYPE))
+#define VALA_IS_VALUE_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_VALUE_TYPE))
+#define VALA_VALUE_TYPE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_VALUE_TYPE, ValaValueTypeClass))
+
+typedef struct _ValaValueType ValaValueType;
+typedef struct _ValaValueTypeClass ValaValueTypeClass;
+
+#define VALA_TYPE_STRUCT_VALUE_TYPE (vala_struct_value_type_get_type ())
+#define VALA_STRUCT_VALUE_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_STRUCT_VALUE_TYPE, ValaStructValueType))
+#define VALA_STRUCT_VALUE_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_STRUCT_VALUE_TYPE, ValaStructValueTypeClass))
+#define VALA_IS_STRUCT_VALUE_TYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_STRUCT_VALUE_TYPE))
+#define VALA_IS_STRUCT_VALUE_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_STRUCT_VALUE_TYPE))
+#define VALA_STRUCT_VALUE_TYPE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_STRUCT_VALUE_TYPE, ValaStructValueTypeClass))
+
+typedef struct _ValaStructValueType ValaStructValueType;
+typedef struct _ValaStructValueTypeClass ValaStructValueTypeClass;
+
 #define VALA_TYPE_VOID_TYPE (vala_void_type_get_type ())
 #define VALA_VOID_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_VOID_TYPE, ValaVoidType))
 #define VALA_VOID_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_VOID_TYPE, ValaVoidTypeClass))
@@ -964,6 +994,7 @@ struct _ValaCodeVisitorClass {
 	void (*visit_switch_statement) (ValaCodeVisitor* self, ValaSwitchStatement* stmt);
 	void (*visit_switch_section) (ValaCodeVisitor* self, ValaSwitchSection* section);
 	void (*visit_switch_label) (ValaCodeVisitor* self, ValaSwitchLabel* label);
+	void (*visit_loop) (ValaCodeVisitor* self, ValaLoop* stmt);
 	void (*visit_while_statement) (ValaCodeVisitor* self, ValaWhileStatement* stmt);
 	void (*visit_do_statement) (ValaCodeVisitor* self, ValaDoStatement* stmt);
 	void (*visit_for_statement) (ValaCodeVisitor* self, ValaForStatement* stmt);
@@ -1028,15 +1059,16 @@ struct _ValaSemanticAnalyzer {
 	ValaDataType* ulong_type;
 	ValaDataType* size_t_type;
 	ValaDataType* ssize_t_type;
-	ValaDataType* uint64_type;
 	ValaDataType* int8_type;
 	ValaDataType* unichar_type;
 	ValaDataType* double_type;
 	ValaDataType* type_type;
 	ValaClass* object_type;
+	ValaStructValueType* gvalue_type;
 	ValaDataType* glist_type;
 	ValaDataType* gslist_type;
 	ValaDataType* garray_type;
+	ValaDataType* gvaluearray_type;
 	ValaClass* gerror_type;
 	gint next_lambda_id;
 	GeeList* replaced_nodes;
@@ -1047,6 +1079,8 @@ struct _ValaSemanticAnalyzerClass {
 };
 
 
+static gpointer vala_return_statement_parent_class = NULL;
+static ValaStatementIface* vala_return_statement_vala_statement_parent_iface = NULL;
 
 gpointer vala_code_node_ref (gpointer instance);
 void vala_code_node_unref (gpointer instance);
@@ -1082,7 +1116,6 @@ void vala_code_node_set_source_reference (ValaCodeNode* self, ValaSourceReferenc
 void vala_return_statement_set_return_expression (ValaReturnStatement* self, ValaExpression* value);
 ValaReturnStatement* vala_return_statement_new (ValaExpression* return_expression, ValaSourceReference* source_reference);
 ValaReturnStatement* vala_return_statement_construct (GType object_type, ValaExpression* return_expression, ValaSourceReference* source_reference);
-ValaReturnStatement* vala_return_statement_new (ValaExpression* return_expression, ValaSourceReference* source_reference);
 void vala_code_visitor_visit_return_statement (ValaCodeVisitor* self, ValaReturnStatement* stmt);
 static void vala_return_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 ValaExpression* vala_return_statement_get_return_expression (ValaReturnStatement* self);
@@ -1132,6 +1165,7 @@ GType vala_if_statement_get_type (void);
 GType vala_switch_statement_get_type (void);
 GType vala_switch_section_get_type (void);
 GType vala_switch_label_get_type (void);
+GType vala_loop_get_type (void);
 GType vala_while_statement_get_type (void);
 GType vala_do_statement_get_type (void);
 GType vala_for_statement_get_type (void);
@@ -1170,6 +1204,8 @@ GType vala_typecheck_get_type (void);
 GType vala_conditional_expression_get_type (void);
 GType vala_lambda_expression_get_type (void);
 GType vala_assignment_get_type (void);
+GType vala_value_type_get_type (void);
+GType vala_struct_value_type_get_type (void);
 void vala_expression_set_target_type (ValaExpression* self, ValaDataType* value);
 gboolean vala_code_node_check (ValaCodeNode* self, ValaSemanticAnalyzer* analyzer);
 void vala_code_node_set_error (ValaCodeNode* self, gboolean value);
@@ -1193,8 +1229,6 @@ static void vala_return_statement_real_get_defined_variables (ValaCodeNode* base
 void vala_code_node_get_used_variables (ValaCodeNode* self, GeeCollection* collection);
 static void vala_return_statement_real_get_used_variables (ValaCodeNode* base, GeeCollection* collection);
 void vala_code_node_set_parent_node (ValaCodeNode* self, ValaCodeNode* value);
-static gpointer vala_return_statement_parent_class = NULL;
-static ValaStatementIface* vala_return_statement_vala_statement_parent_iface = NULL;
 static void vala_return_statement_finalize (ValaCodeNode* obj);
 
 
@@ -1252,122 +1286,133 @@ static void vala_return_statement_real_replace_expression (ValaCodeNode* base, V
 
 static gboolean vala_return_statement_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer) {
 	ValaReturnStatement * self;
-	gboolean _tmp1_;
-	gboolean _tmp11_;
-	ValaLocalVariable* _tmp14_;
-	ValaSymbol* _tmp13_;
+	gboolean result;
+	gboolean _tmp0_;
+	gboolean _tmp4_;
+	ValaLocalVariable* _tmp6_;
+	ValaSymbol* _tmp5_;
 	ValaLocalVariable* local;
-	gboolean _tmp15_;
-	gboolean _tmp16_;
-	gboolean _tmp18_;
-	GeeList* _tmp21_;
-	gboolean _tmp22_;
+	gboolean _tmp7_;
+	gboolean _tmp8_;
+	gboolean _tmp9_;
+	GeeList* _tmp12_;
 	self = (ValaReturnStatement*) base;
 	g_return_val_if_fail (analyzer != NULL, FALSE);
 	if (vala_code_node_get_checked ((ValaCodeNode*) self)) {
-		return !vala_code_node_get_error ((ValaCodeNode*) self);
+		result = !vala_code_node_get_error ((ValaCodeNode*) self);
+		return result;
 	}
 	vala_code_node_set_checked ((ValaCodeNode*) self, TRUE);
 	if (vala_return_statement_get_return_expression (self) != NULL) {
 		vala_expression_set_target_type (vala_return_statement_get_return_expression (self), analyzer->current_return_type);
 	}
-	_tmp1_ = FALSE;
+	_tmp0_ = FALSE;
 	if (vala_return_statement_get_return_expression (self) != NULL) {
-		_tmp1_ = !vala_code_node_check ((ValaCodeNode*) vala_return_statement_get_return_expression (self), analyzer);
+		_tmp0_ = !vala_code_node_check ((ValaCodeNode*) vala_return_statement_get_return_expression (self), analyzer);
 	} else {
-		_tmp1_ = FALSE;
+		_tmp0_ = FALSE;
 	}
-	if (_tmp1_) {
+	if (_tmp0_) {
 		/* ignore inner error*/
 		vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
-		return FALSE;
+		result = FALSE;
+		return result;
 	}
 	if (analyzer->current_return_type == NULL) {
 		vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
 		vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), "Return not allowed in this context");
-		return FALSE;
+		result = FALSE;
+		return result;
 	}
 	if (vala_return_statement_get_return_expression (self) == NULL) {
 		if (!VALA_IS_VOID_TYPE (analyzer->current_return_type)) {
 			vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
 			vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), "Return without value in non-void function");
 		}
-		return !vala_code_node_get_error ((ValaCodeNode*) self);
+		result = !vala_code_node_get_error ((ValaCodeNode*) self);
+		return result;
 	}
 	if (VALA_IS_VOID_TYPE (analyzer->current_return_type)) {
 		vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), "Return with value in void function");
-		return FALSE;
+		result = FALSE;
+		return result;
 	}
 	if (vala_expression_get_value_type (vala_return_statement_get_return_expression (self)) == NULL) {
 		vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
 		vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), "Invalid expression in return value");
-		return FALSE;
+		result = FALSE;
+		return result;
 	}
 	if (!vala_data_type_compatible (vala_expression_get_value_type (vala_return_statement_get_return_expression (self)), analyzer->current_return_type)) {
-		char* _tmp9_;
-		char* _tmp8_;
-		char* _tmp7_;
+		char* _tmp3_;
+		char* _tmp2_;
+		char* _tmp1_;
 		vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
-		_tmp9_ = NULL;
-		_tmp8_ = NULL;
-		_tmp7_ = NULL;
-		vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp9_ = g_strdup_printf ("Return: Cannot convert from `%s' to `%s'", _tmp7_ = vala_code_node_to_string ((ValaCodeNode*) vala_expression_get_value_type (vala_return_statement_get_return_expression (self))), _tmp8_ = vala_code_node_to_string ((ValaCodeNode*) analyzer->current_return_type)));
-		_tmp9_ = (g_free (_tmp9_), NULL);
-		_tmp8_ = (g_free (_tmp8_), NULL);
-		_tmp7_ = (g_free (_tmp7_), NULL);
-		return FALSE;
+		_tmp3_ = NULL;
+		_tmp2_ = NULL;
+		_tmp1_ = NULL;
+		vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp3_ = g_strdup_printf ("Return: Cannot convert from `%s' to `%s'", _tmp1_ = vala_code_node_to_string ((ValaCodeNode*) vala_expression_get_value_type (vala_return_statement_get_return_expression (self))), _tmp2_ = vala_code_node_to_string ((ValaCodeNode*) analyzer->current_return_type)));
+		_tmp3_ = (g_free (_tmp3_), NULL);
+		_tmp2_ = (g_free (_tmp2_), NULL);
+		_tmp1_ = (g_free (_tmp1_), NULL);
+		result = FALSE;
+		return result;
 	}
-	_tmp11_ = FALSE;
+	_tmp4_ = FALSE;
 	if (vala_data_type_is_disposable (vala_expression_get_value_type (vala_return_statement_get_return_expression (self)))) {
-		_tmp11_ = !vala_data_type_get_value_owned (analyzer->current_return_type);
+		_tmp4_ = !vala_data_type_get_value_owned (analyzer->current_return_type);
 	} else {
-		_tmp11_ = FALSE;
+		_tmp4_ = FALSE;
 	}
-	if (_tmp11_) {
+	if (_tmp4_) {
 		vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
 		vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), "Return value transfers ownership but method return type hasn't been declared to transfer ownership");
-		return FALSE;
+		result = FALSE;
+		return result;
 	}
-	_tmp14_ = NULL;
-	_tmp13_ = NULL;
-	local = (_tmp14_ = (_tmp13_ = vala_expression_get_symbol_reference (vala_return_statement_get_return_expression (self)), VALA_IS_LOCAL_VARIABLE (_tmp13_) ? ((ValaLocalVariable*) _tmp13_) : NULL), (_tmp14_ == NULL) ? NULL : vala_code_node_ref (_tmp14_));
-	_tmp15_ = FALSE;
-	_tmp16_ = FALSE;
+	_tmp6_ = NULL;
+	_tmp5_ = NULL;
+	local = (_tmp6_ = (_tmp5_ = vala_expression_get_symbol_reference (vala_return_statement_get_return_expression (self)), VALA_IS_LOCAL_VARIABLE (_tmp5_) ? ((ValaLocalVariable*) _tmp5_) : NULL), (_tmp6_ == NULL) ? NULL : vala_code_node_ref (_tmp6_));
+	_tmp7_ = FALSE;
+	_tmp8_ = FALSE;
 	if (local != NULL) {
-		_tmp16_ = vala_data_type_is_disposable (vala_local_variable_get_variable_type (local));
+		_tmp8_ = vala_data_type_is_disposable (vala_local_variable_get_variable_type (local));
 	} else {
-		_tmp16_ = FALSE;
+		_tmp8_ = FALSE;
 	}
-	if (_tmp16_) {
-		_tmp15_ = !vala_data_type_get_value_owned (analyzer->current_return_type);
+	if (_tmp8_) {
+		_tmp7_ = !vala_data_type_get_value_owned (analyzer->current_return_type);
 	} else {
-		_tmp15_ = FALSE;
+		_tmp7_ = FALSE;
 	}
-	if (_tmp15_) {
-		gboolean _tmp17_;
+	if (_tmp7_) {
 		vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
 		vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), "Local variable with strong reference used as return value and method return type has not been declared to transfer ownership");
-		return (_tmp17_ = FALSE, (local == NULL) ? NULL : (local = (vala_code_node_unref (local), NULL)), _tmp17_);
+		result = FALSE;
+		(local == NULL) ? NULL : (local = (vala_code_node_unref (local), NULL));
+		return result;
 	}
-	_tmp18_ = FALSE;
+	_tmp9_ = FALSE;
 	if (VALA_IS_NULL_LITERAL (vala_return_statement_get_return_expression (self))) {
-		_tmp18_ = !vala_data_type_get_nullable (analyzer->current_return_type);
+		_tmp9_ = !vala_data_type_get_nullable (analyzer->current_return_type);
 	} else {
-		_tmp18_ = FALSE;
+		_tmp9_ = FALSE;
 	}
-	if (_tmp18_) {
-		char* _tmp20_;
-		char* _tmp19_;
-		_tmp20_ = NULL;
-		_tmp19_ = NULL;
-		vala_report_warning (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp20_ = g_strdup_printf ("`null' incompatible with return type `%s`", _tmp19_ = vala_code_node_to_string ((ValaCodeNode*) analyzer->current_return_type)));
-		_tmp20_ = (g_free (_tmp20_), NULL);
-		_tmp19_ = (g_free (_tmp19_), NULL);
+	if (_tmp9_) {
+		char* _tmp11_;
+		char* _tmp10_;
+		_tmp11_ = NULL;
+		_tmp10_ = NULL;
+		vala_report_warning (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp11_ = g_strdup_printf ("`null' incompatible with return type `%s`", _tmp10_ = vala_code_node_to_string ((ValaCodeNode*) analyzer->current_return_type)));
+		_tmp11_ = (g_free (_tmp11_), NULL);
+		_tmp10_ = (g_free (_tmp10_), NULL);
 	}
-	_tmp21_ = NULL;
-	vala_code_node_add_error_types ((ValaCodeNode*) self, _tmp21_ = vala_code_node_get_error_types ((ValaCodeNode*) vala_return_statement_get_return_expression (self)));
-	(_tmp21_ == NULL) ? NULL : (_tmp21_ = (gee_collection_object_unref (_tmp21_), NULL));
-	return (_tmp22_ = !vala_code_node_get_error ((ValaCodeNode*) self), (local == NULL) ? NULL : (local = (vala_code_node_unref (local), NULL)), _tmp22_);
+	_tmp12_ = NULL;
+	vala_code_node_add_error_types ((ValaCodeNode*) self, _tmp12_ = vala_code_node_get_error_types ((ValaCodeNode*) vala_return_statement_get_return_expression (self)));
+	(_tmp12_ == NULL) ? NULL : (_tmp12_ = (gee_collection_object_unref (_tmp12_), NULL));
+	result = !vala_code_node_get_error ((ValaCodeNode*) self);
+	(local == NULL) ? NULL : (local = (vala_code_node_unref (local), NULL));
+	return result;
 }
 
 
@@ -1392,18 +1437,20 @@ static void vala_return_statement_real_get_used_variables (ValaCodeNode* base, G
 
 
 ValaExpression* vala_return_statement_get_return_expression (ValaReturnStatement* self) {
+	ValaExpression* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_return_expression;
+	result = self->priv->_return_expression;
+	return result;
 }
 
 
 void vala_return_statement_set_return_expression (ValaReturnStatement* self, ValaExpression* value) {
-	ValaExpression* _tmp2_;
 	ValaExpression* _tmp1_;
+	ValaExpression* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2_ = NULL;
 	_tmp1_ = NULL;
-	self->priv->_return_expression = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_)), (self->priv->_return_expression == NULL) ? NULL : (self->priv->_return_expression = (vala_code_node_unref (self->priv->_return_expression), NULL)), _tmp2_);
+	_tmp0_ = NULL;
+	self->priv->_return_expression = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_)), (self->priv->_return_expression == NULL) ? NULL : (self->priv->_return_expression = (vala_code_node_unref (self->priv->_return_expression), NULL)), _tmp1_);
 	if (self->priv->_return_expression != NULL) {
 		vala_code_node_set_parent_node ((ValaCodeNode*) self->priv->_return_expression, (ValaCodeNode*) self);
 	}
