@@ -184,6 +184,8 @@ struct _ValaStatementListPrivate {
 };
 
 
+static gpointer vala_statement_list_parent_class = NULL;
+static ValaStatementIface* vala_statement_list_vala_statement_parent_iface = NULL;
 
 gpointer vala_code_node_ref (gpointer instance);
 void vala_code_node_unref (gpointer instance);
@@ -218,7 +220,6 @@ GType vala_source_reference_get_type (void);
 void vala_code_node_set_source_reference (ValaCodeNode* self, ValaSourceReference* value);
 ValaStatementList* vala_statement_list_new (ValaSourceReference* source_reference);
 ValaStatementList* vala_statement_list_construct (GType object_type, ValaSourceReference* source_reference);
-ValaStatementList* vala_statement_list_new (ValaSourceReference* source_reference);
 ValaStatement* vala_statement_list_get (ValaStatementList* self, gint index);
 void vala_statement_list_set (ValaStatementList* self, gint index, ValaStatement* stmt);
 void vala_statement_list_add (ValaStatementList* self, ValaStatement* stmt);
@@ -226,8 +227,6 @@ void vala_statement_list_insert (ValaStatementList* self, gint index, ValaStatem
 void vala_code_node_accept (ValaCodeNode* self, ValaCodeVisitor* visitor);
 static void vala_statement_list_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 gint vala_statement_list_get_length (ValaStatementList* self);
-static gpointer vala_statement_list_parent_class = NULL;
-static ValaStatementIface* vala_statement_list_vala_statement_parent_iface = NULL;
 static void vala_statement_list_finalize (ValaCodeNode* obj);
 
 
@@ -247,8 +246,10 @@ ValaStatementList* vala_statement_list_new (ValaSourceReference* source_referenc
 
 
 ValaStatement* vala_statement_list_get (ValaStatementList* self, gint index) {
+	ValaStatement* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return (ValaStatement*) gee_list_get (self->priv->list, index);
+	result = (ValaStatement*) gee_list_get (self->priv->list, index);
+	return result;
 }
 
 
@@ -280,8 +281,11 @@ static void vala_statement_list_real_accept (ValaCodeNode* base, ValaCodeVisitor
 	{
 		GeeIterator* _stmt_it;
 		_stmt_it = gee_iterable_iterator ((GeeIterable*) self->priv->list);
-		while (gee_iterator_next (_stmt_it)) {
+		while (TRUE) {
 			ValaStatement* stmt;
+			if (!gee_iterator_next (_stmt_it)) {
+				break;
+			}
 			stmt = (ValaStatement*) gee_iterator_get (_stmt_it);
 			vala_code_node_accept ((ValaCodeNode*) stmt, visitor);
 			(stmt == NULL) ? NULL : (stmt = (vala_code_node_unref (stmt), NULL));
@@ -292,8 +296,10 @@ static void vala_statement_list_real_accept (ValaCodeNode* base, ValaCodeVisitor
 
 
 gint vala_statement_list_get_length (ValaStatementList* self) {
+	gint result;
 	g_return_val_if_fail (self != NULL, 0);
-	return gee_collection_get_size ((GeeCollection*) self->priv->list);
+	result = gee_collection_get_size ((GeeCollection*) self->priv->list);
+	return result;
 }
 
 
