@@ -482,6 +482,16 @@ typedef struct _ValaSwitchSectionClass ValaSwitchSectionClass;
 typedef struct _ValaSwitchLabel ValaSwitchLabel;
 typedef struct _ValaSwitchLabelClass ValaSwitchLabelClass;
 
+#define VALA_TYPE_LOOP (vala_loop_get_type ())
+#define VALA_LOOP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_LOOP, ValaLoop))
+#define VALA_LOOP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_LOOP, ValaLoopClass))
+#define VALA_IS_LOOP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_LOOP))
+#define VALA_IS_LOOP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_LOOP))
+#define VALA_LOOP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_LOOP, ValaLoopClass))
+
+typedef struct _ValaLoop ValaLoop;
+typedef struct _ValaLoopClass ValaLoopClass;
+
 #define VALA_TYPE_WHILE_STATEMENT (vala_while_statement_get_type ())
 #define VALA_WHILE_STATEMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_WHILE_STATEMENT, ValaWhileStatement))
 #define VALA_WHILE_STATEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_WHILE_STATEMENT, ValaWhileStatementClass))
@@ -853,6 +863,26 @@ typedef struct _ValaAssignment ValaAssignment;
 typedef struct _ValaAssignmentClass ValaAssignmentClass;
 typedef struct _ValaSemanticAnalyzerPrivate ValaSemanticAnalyzerPrivate;
 
+#define VALA_TYPE_VALUE_TYPE (vala_value_type_get_type ())
+#define VALA_VALUE_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_VALUE_TYPE, ValaValueType))
+#define VALA_VALUE_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_VALUE_TYPE, ValaValueTypeClass))
+#define VALA_IS_VALUE_TYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_VALUE_TYPE))
+#define VALA_IS_VALUE_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_VALUE_TYPE))
+#define VALA_VALUE_TYPE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_VALUE_TYPE, ValaValueTypeClass))
+
+typedef struct _ValaValueType ValaValueType;
+typedef struct _ValaValueTypeClass ValaValueTypeClass;
+
+#define VALA_TYPE_STRUCT_VALUE_TYPE (vala_struct_value_type_get_type ())
+#define VALA_STRUCT_VALUE_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_STRUCT_VALUE_TYPE, ValaStructValueType))
+#define VALA_STRUCT_VALUE_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_STRUCT_VALUE_TYPE, ValaStructValueTypeClass))
+#define VALA_IS_STRUCT_VALUE_TYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_STRUCT_VALUE_TYPE))
+#define VALA_IS_STRUCT_VALUE_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_STRUCT_VALUE_TYPE))
+#define VALA_STRUCT_VALUE_TYPE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_STRUCT_VALUE_TYPE, ValaStructValueTypeClass))
+
+typedef struct _ValaStructValueType ValaStructValueType;
+typedef struct _ValaStructValueTypeClass ValaStructValueTypeClass;
+
 /**
  * Represents a part of the parsed source code.
  *
@@ -969,6 +999,7 @@ struct _ValaCodeVisitorClass {
 	void (*visit_switch_statement) (ValaCodeVisitor* self, ValaSwitchStatement* stmt);
 	void (*visit_switch_section) (ValaCodeVisitor* self, ValaSwitchSection* section);
 	void (*visit_switch_label) (ValaCodeVisitor* self, ValaSwitchLabel* label);
+	void (*visit_loop) (ValaCodeVisitor* self, ValaLoop* stmt);
 	void (*visit_while_statement) (ValaCodeVisitor* self, ValaWhileStatement* stmt);
 	void (*visit_do_statement) (ValaCodeVisitor* self, ValaDoStatement* stmt);
 	void (*visit_for_statement) (ValaCodeVisitor* self, ValaForStatement* stmt);
@@ -1038,9 +1069,11 @@ struct _ValaSemanticAnalyzer {
 	ValaDataType* double_type;
 	ValaDataType* type_type;
 	ValaClass* object_type;
+	ValaStructValueType* gvalue_type;
 	ValaDataType* glist_type;
 	ValaDataType* gslist_type;
 	ValaDataType* garray_type;
+	ValaDataType* gvaluearray_type;
 	ValaClass* gerror_type;
 	gint next_lambda_id;
 	GeeList* replaced_nodes;
@@ -1051,6 +1084,7 @@ struct _ValaSemanticAnalyzerClass {
 };
 
 
+static gpointer vala_string_literal_parent_class = NULL;
 
 gpointer vala_code_node_ref (gpointer instance);
 void vala_code_node_unref (gpointer instance);
@@ -1086,7 +1120,6 @@ GType vala_source_reference_get_type (void);
 void vala_code_node_set_source_reference (ValaCodeNode* self, ValaSourceReference* value);
 ValaStringLiteral* vala_string_literal_new (const char* value, ValaSourceReference* source_reference);
 ValaStringLiteral* vala_string_literal_construct (GType object_type, const char* value, ValaSourceReference* source_reference);
-ValaStringLiteral* vala_string_literal_new (const char* value, ValaSourceReference* source_reference);
 const char* vala_string_literal_get_value (ValaStringLiteral* self);
 char* vala_string_literal_eval (ValaStringLiteral* self);
 void vala_code_visitor_visit_string_literal (ValaCodeVisitor* self, ValaStringLiteral* lit);
@@ -1137,6 +1170,7 @@ GType vala_if_statement_get_type (void);
 GType vala_switch_statement_get_type (void);
 GType vala_switch_section_get_type (void);
 GType vala_switch_label_get_type (void);
+GType vala_loop_get_type (void);
 GType vala_while_statement_get_type (void);
 GType vala_do_statement_get_type (void);
 GType vala_for_statement_get_type (void);
@@ -1174,10 +1208,11 @@ GType vala_typecheck_get_type (void);
 GType vala_conditional_expression_get_type (void);
 GType vala_lambda_expression_get_type (void);
 GType vala_assignment_get_type (void);
+GType vala_value_type_get_type (void);
+GType vala_struct_value_type_get_type (void);
 ValaDataType* vala_data_type_copy (ValaDataType* self);
 void vala_expression_set_value_type (ValaExpression* self, ValaDataType* value);
 static gboolean vala_string_literal_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer);
-static gpointer vala_string_literal_parent_class = NULL;
 static void vala_string_literal_finalize (ValaCodeNode* obj);
 
 
@@ -1205,6 +1240,7 @@ ValaStringLiteral* vala_string_literal_new (const char* value, ValaSourceReferen
 
 
 static char* string_substring (const char* self, glong offset, glong len) {
+	char* result;
 	glong string_length;
 	const char* start;
 	g_return_val_if_fail (self != NULL, NULL);
@@ -1220,7 +1256,8 @@ static char* string_substring (const char* self, glong offset, glong len) {
 	}
 	g_return_val_if_fail ((offset + len) <= string_length, NULL);
 	start = g_utf8_offset_to_pointer (self, offset);
-	return g_strndup (start, ((gchar*) g_utf8_offset_to_pointer (start, len)) - ((gchar*) start));
+	result = g_strndup (start, ((gchar*) g_utf8_offset_to_pointer (start, len)) - ((gchar*) start));
+	return result;
 }
 
 
@@ -1230,17 +1267,19 @@ static char* string_substring (const char* self, glong offset, glong len) {
  * @return the unescaped string
  */
 char* vala_string_literal_eval (ValaStringLiteral* self) {
+	char* result;
 	char* noquotes;
-	char* _tmp1_;
 	g_return_val_if_fail (self != NULL, NULL);
 	if (self->priv->_value == NULL) {
-		return NULL;
+		result = NULL;
+		return result;
 	}
 	/* remove quotes */
 	noquotes = string_substring (self->priv->_value, (glong) 1, (glong) ((guint) (g_utf8_strlen (self->priv->_value, -1) - 2)));
 	/* unescape string */
-	_tmp1_ = NULL;
-	return (_tmp1_ = g_strcompress (noquotes), noquotes = (g_free (noquotes), NULL), _tmp1_);
+	result = g_strcompress (noquotes);
+	noquotes = (g_free (noquotes), NULL);
+	return result;
 }
 
 
@@ -1255,56 +1294,67 @@ static void vala_string_literal_real_accept (ValaCodeNode* base, ValaCodeVisitor
 
 static gboolean vala_string_literal_real_is_pure (ValaExpression* base) {
 	ValaStringLiteral * self;
+	gboolean result;
 	self = (ValaStringLiteral*) base;
-	return TRUE;
+	result = TRUE;
+	return result;
 }
 
 
 static gboolean vala_string_literal_real_is_non_null (ValaExpression* base) {
 	ValaStringLiteral * self;
+	gboolean result;
 	self = (ValaStringLiteral*) base;
-	return TRUE;
+	result = TRUE;
+	return result;
 }
 
 
 static char* vala_string_literal_real_to_string (ValaCodeNode* base) {
 	ValaStringLiteral * self;
+	char* result;
 	const char* _tmp0_;
 	self = (ValaStringLiteral*) base;
 	_tmp0_ = NULL;
-	return (_tmp0_ = self->priv->_value, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_));
+	result = (_tmp0_ = self->priv->_value, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_));
+	return result;
 }
 
 
 static gboolean vala_string_literal_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer) {
 	ValaStringLiteral * self;
-	ValaDataType* _tmp1_;
+	gboolean result;
+	ValaDataType* _tmp0_;
 	self = (ValaStringLiteral*) base;
 	g_return_val_if_fail (analyzer != NULL, FALSE);
 	if (vala_code_node_get_checked ((ValaCodeNode*) self)) {
-		return !vala_code_node_get_error ((ValaCodeNode*) self);
+		result = !vala_code_node_get_error ((ValaCodeNode*) self);
+		return result;
 	}
 	vala_code_node_set_checked ((ValaCodeNode*) self, TRUE);
-	_tmp1_ = NULL;
-	vala_expression_set_value_type ((ValaExpression*) self, _tmp1_ = vala_data_type_copy (analyzer->string_type));
-	(_tmp1_ == NULL) ? NULL : (_tmp1_ = (vala_code_node_unref (_tmp1_), NULL));
-	return !vala_code_node_get_error ((ValaCodeNode*) self);
+	_tmp0_ = NULL;
+	vala_expression_set_value_type ((ValaExpression*) self, _tmp0_ = vala_data_type_copy (analyzer->string_type));
+	(_tmp0_ == NULL) ? NULL : (_tmp0_ = (vala_code_node_unref (_tmp0_), NULL));
+	result = !vala_code_node_get_error ((ValaCodeNode*) self);
+	return result;
 }
 
 
 const char* vala_string_literal_get_value (ValaStringLiteral* self) {
+	const char* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_value;
+	result = self->priv->_value;
+	return result;
 }
 
 
 void vala_string_literal_set_value (ValaStringLiteral* self, const char* value) {
-	char* _tmp2_;
-	const char* _tmp1_;
+	char* _tmp1_;
+	const char* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2_ = NULL;
 	_tmp1_ = NULL;
-	self->priv->_value = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : g_strdup (_tmp1_)), self->priv->_value = (g_free (self->priv->_value), NULL), _tmp2_);
+	_tmp0_ = NULL;
+	self->priv->_value = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_)), self->priv->_value = (g_free (self->priv->_value), NULL), _tmp1_);
 }
 
 
