@@ -480,6 +480,16 @@ typedef struct _ValaIfStatementClass ValaIfStatementClass;
 typedef struct _ValaSwitchStatement ValaSwitchStatement;
 typedef struct _ValaSwitchStatementClass ValaSwitchStatementClass;
 
+#define VALA_TYPE_LOOP (vala_loop_get_type ())
+#define VALA_LOOP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_LOOP, ValaLoop))
+#define VALA_LOOP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_LOOP, ValaLoopClass))
+#define VALA_IS_LOOP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_LOOP))
+#define VALA_IS_LOOP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_LOOP))
+#define VALA_LOOP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_LOOP, ValaLoopClass))
+
+typedef struct _ValaLoop ValaLoop;
+typedef struct _ValaLoopClass ValaLoopClass;
+
 #define VALA_TYPE_WHILE_STATEMENT (vala_while_statement_get_type ())
 #define VALA_WHILE_STATEMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_WHILE_STATEMENT, ValaWhileStatement))
 #define VALA_WHILE_STATEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_WHILE_STATEMENT, ValaWhileStatementClass))
@@ -871,6 +881,26 @@ typedef struct _ValaAssignment ValaAssignment;
 typedef struct _ValaAssignmentClass ValaAssignmentClass;
 typedef struct _ValaSemanticAnalyzerPrivate ValaSemanticAnalyzerPrivate;
 
+#define VALA_TYPE_VALUE_TYPE (vala_value_type_get_type ())
+#define VALA_VALUE_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_VALUE_TYPE, ValaValueType))
+#define VALA_VALUE_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_VALUE_TYPE, ValaValueTypeClass))
+#define VALA_IS_VALUE_TYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_VALUE_TYPE))
+#define VALA_IS_VALUE_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_VALUE_TYPE))
+#define VALA_VALUE_TYPE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_VALUE_TYPE, ValaValueTypeClass))
+
+typedef struct _ValaValueType ValaValueType;
+typedef struct _ValaValueTypeClass ValaValueTypeClass;
+
+#define VALA_TYPE_STRUCT_VALUE_TYPE (vala_struct_value_type_get_type ())
+#define VALA_STRUCT_VALUE_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_STRUCT_VALUE_TYPE, ValaStructValueType))
+#define VALA_STRUCT_VALUE_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_STRUCT_VALUE_TYPE, ValaStructValueTypeClass))
+#define VALA_IS_STRUCT_VALUE_TYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_STRUCT_VALUE_TYPE))
+#define VALA_IS_STRUCT_VALUE_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_STRUCT_VALUE_TYPE))
+#define VALA_STRUCT_VALUE_TYPE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_STRUCT_VALUE_TYPE, ValaStructValueTypeClass))
+
+typedef struct _ValaStructValueType ValaStructValueType;
+typedef struct _ValaStructValueTypeClass ValaStructValueTypeClass;
+
 /**
  * Represents a part of the parsed source code.
  *
@@ -911,6 +941,8 @@ struct _ValaSymbolClass {
 	char* (*get_lower_case_cname) (ValaSymbol* self, const char* infix);
 	char* (*get_lower_case_cprefix) (ValaSymbol* self);
 	GeeList* (*get_cheader_filenames) (ValaSymbol* self);
+	gboolean (*is_instance_member) (ValaSymbol* self);
+	gboolean (*is_class_member) (ValaSymbol* self);
 };
 
 /**
@@ -994,6 +1026,7 @@ struct _ValaCodeVisitorClass {
 	void (*visit_switch_statement) (ValaCodeVisitor* self, ValaSwitchStatement* stmt);
 	void (*visit_switch_section) (ValaCodeVisitor* self, ValaSwitchSection* section);
 	void (*visit_switch_label) (ValaCodeVisitor* self, ValaSwitchLabel* label);
+	void (*visit_loop) (ValaCodeVisitor* self, ValaLoop* stmt);
 	void (*visit_while_statement) (ValaCodeVisitor* self, ValaWhileStatement* stmt);
 	void (*visit_do_statement) (ValaCodeVisitor* self, ValaDoStatement* stmt);
 	void (*visit_for_statement) (ValaCodeVisitor* self, ValaForStatement* stmt);
@@ -1063,9 +1096,11 @@ struct _ValaSemanticAnalyzer {
 	ValaDataType* double_type;
 	ValaDataType* type_type;
 	ValaClass* object_type;
+	ValaStructValueType* gvalue_type;
 	ValaDataType* glist_type;
 	ValaDataType* gslist_type;
 	ValaDataType* garray_type;
+	ValaDataType* gvaluearray_type;
 	ValaClass* gerror_type;
 	gint next_lambda_id;
 	GeeList* replaced_nodes;
@@ -1076,6 +1111,7 @@ struct _ValaSemanticAnalyzerClass {
 };
 
 
+static gpointer vala_switch_section_parent_class = NULL;
 
 gpointer vala_code_node_ref (gpointer instance);
 void vala_code_node_unref (gpointer instance);
@@ -1113,7 +1149,6 @@ ValaBlock* vala_block_new (ValaSourceReference* source_reference);
 ValaBlock* vala_block_construct (GType object_type, ValaSourceReference* source_reference);
 ValaSwitchSection* vala_switch_section_new (ValaSourceReference* source_reference);
 ValaSwitchSection* vala_switch_section_construct (GType object_type, ValaSourceReference* source_reference);
-ValaSwitchSection* vala_switch_section_new (ValaSourceReference* source_reference);
 void vala_switch_section_add_label (ValaSwitchSection* self, ValaSwitchLabel* label);
 GeeList* vala_switch_section_get_labels (ValaSwitchSection* self);
 ValaExpression* vala_switch_label_get_expression (ValaSwitchLabel* self);
@@ -1172,6 +1207,7 @@ GType vala_initializer_list_get_type (void);
 GType vala_expression_statement_get_type (void);
 GType vala_if_statement_get_type (void);
 GType vala_switch_statement_get_type (void);
+GType vala_loop_get_type (void);
 GType vala_while_statement_get_type (void);
 GType vala_do_statement_get_type (void);
 GType vala_for_statement_get_type (void);
@@ -1211,11 +1247,12 @@ GType vala_typecheck_get_type (void);
 GType vala_conditional_expression_get_type (void);
 GType vala_lambda_expression_get_type (void);
 GType vala_assignment_get_type (void);
+GType vala_value_type_get_type (void);
+GType vala_struct_value_type_get_type (void);
 void vala_semantic_analyzer_set_current_symbol (ValaSemanticAnalyzer* self, ValaSymbol* value);
 GeeList* vala_block_get_local_variables (ValaBlock* self);
 void vala_symbol_set_active (ValaSymbol* self, gboolean value);
 static gboolean vala_switch_section_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer);
-static gpointer vala_switch_section_parent_class = NULL;
 static void vala_switch_section_finalize (ValaCodeNode* obj);
 
 
@@ -1257,28 +1294,37 @@ void vala_switch_section_add_label (ValaSwitchSection* self, ValaSwitchLabel* la
  * @return switch label list
  */
 GeeList* vala_switch_section_get_labels (ValaSwitchSection* self) {
+	GeeList* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return (GeeList*) gee_read_only_list_new (VALA_TYPE_SWITCH_LABEL, (GBoxedCopyFunc) vala_code_node_ref, vala_code_node_unref, self->priv->labels);
+	result = (GeeList*) gee_read_only_list_new (VALA_TYPE_SWITCH_LABEL, (GBoxedCopyFunc) vala_code_node_ref, vala_code_node_unref, self->priv->labels);
+	return result;
 }
 
 
 gboolean vala_switch_section_has_default_label (ValaSwitchSection* self) {
+	gboolean result;
 	g_return_val_if_fail (self != NULL, FALSE);
 	{
 		GeeIterator* _label_it;
 		_label_it = gee_iterable_iterator ((GeeIterable*) self->priv->labels);
-		while (gee_iterator_next (_label_it)) {
+		while (TRUE) {
 			ValaSwitchLabel* label;
+			if (!gee_iterator_next (_label_it)) {
+				break;
+			}
 			label = (ValaSwitchLabel*) gee_iterator_get (_label_it);
 			if (vala_switch_label_get_expression (label) == NULL) {
-				gboolean _tmp0_;
-				return (_tmp0_ = TRUE, (label == NULL) ? NULL : (label = (vala_code_node_unref (label), NULL)), (_label_it == NULL) ? NULL : (_label_it = (gee_collection_object_unref (_label_it), NULL)), _tmp0_);
+				result = TRUE;
+				(label == NULL) ? NULL : (label = (vala_code_node_unref (label), NULL));
+				(_label_it == NULL) ? NULL : (_label_it = (gee_collection_object_unref (_label_it), NULL));
+				return result;
 			}
 			(label == NULL) ? NULL : (label = (vala_code_node_unref (label), NULL));
 		}
 		(_label_it == NULL) ? NULL : (_label_it = (gee_collection_object_unref (_label_it), NULL));
 	}
-	return FALSE;
+	result = FALSE;
+	return result;
 }
 
 
@@ -1297,8 +1343,11 @@ static void vala_switch_section_real_accept_children (ValaCodeNode* base, ValaCo
 	{
 		GeeIterator* _label_it;
 		_label_it = gee_iterable_iterator ((GeeIterable*) self->priv->labels);
-		while (gee_iterator_next (_label_it)) {
+		while (TRUE) {
 			ValaSwitchLabel* label;
+			if (!gee_iterator_next (_label_it)) {
+				break;
+			}
 			label = (ValaSwitchLabel*) gee_iterator_get (_label_it);
 			vala_code_node_accept ((ValaCodeNode*) label, visitor);
 			(label == NULL) ? NULL : (label = (vala_code_node_unref (label), NULL));
@@ -1312,8 +1361,11 @@ static void vala_switch_section_real_accept_children (ValaCodeNode* base, ValaCo
 		_tmp0_ = NULL;
 		_tmp1_ = NULL;
 		_st_it = (_tmp1_ = gee_iterable_iterator ((GeeIterable*) (_tmp0_ = vala_block_get_statements ((ValaBlock*) self))), (_tmp0_ == NULL) ? NULL : (_tmp0_ = (gee_collection_object_unref (_tmp0_), NULL)), _tmp1_);
-		while (gee_iterator_next (_st_it)) {
+		while (TRUE) {
 			ValaStatement* st;
+			if (!gee_iterator_next (_st_it)) {
+				break;
+			}
 			st = (ValaStatement*) gee_iterator_get (_st_it);
 			vala_code_node_accept ((ValaCodeNode*) st, visitor);
 			(st == NULL) ? NULL : (st = (vala_code_node_unref (st), NULL));
@@ -1325,30 +1377,34 @@ static void vala_switch_section_real_accept_children (ValaCodeNode* base, ValaCo
 
 static gboolean vala_switch_section_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer) {
 	ValaSwitchSection * self;
-	ValaSymbol* _tmp3_;
+	gboolean result;
+	ValaSymbol* _tmp2_;
 	ValaSymbol* old_symbol;
-	ValaBlock* _tmp4_;
+	ValaBlock* _tmp3_;
 	ValaBlock* old_insert_block;
-	ValaBlock* _tmp6_;
 	ValaBlock* _tmp5_;
-	ValaBlock* _tmp12_;
+	ValaBlock* _tmp4_;
 	ValaBlock* _tmp11_;
-	gboolean _tmp13_;
+	ValaBlock* _tmp10_;
 	self = (ValaSwitchSection*) base;
 	g_return_val_if_fail (analyzer != NULL, FALSE);
 	if (vala_code_node_get_checked ((ValaCodeNode*) self)) {
-		return !vala_code_node_get_error ((ValaCodeNode*) self);
+		result = !vala_code_node_get_error ((ValaCodeNode*) self);
+		return result;
 	}
 	vala_code_node_set_checked ((ValaCodeNode*) self, TRUE);
 	{
-		GeeList* _tmp1_;
-		GeeIterator* _tmp2_;
+		GeeList* _tmp0_;
+		GeeIterator* _tmp1_;
 		GeeIterator* _label_it;
+		_tmp0_ = NULL;
 		_tmp1_ = NULL;
-		_tmp2_ = NULL;
-		_label_it = (_tmp2_ = gee_iterable_iterator ((GeeIterable*) (_tmp1_ = vala_switch_section_get_labels (self))), (_tmp1_ == NULL) ? NULL : (_tmp1_ = (gee_collection_object_unref (_tmp1_), NULL)), _tmp2_);
-		while (gee_iterator_next (_label_it)) {
+		_label_it = (_tmp1_ = gee_iterable_iterator ((GeeIterable*) (_tmp0_ = vala_switch_section_get_labels (self))), (_tmp0_ == NULL) ? NULL : (_tmp0_ = (gee_collection_object_unref (_tmp0_), NULL)), _tmp1_);
+		while (TRUE) {
 			ValaSwitchLabel* label;
+			if (!gee_iterator_next (_label_it)) {
+				break;
+			}
 			label = (ValaSwitchLabel*) gee_iterator_get (_label_it);
 			vala_code_node_check ((ValaCodeNode*) label, analyzer);
 			(label == NULL) ? NULL : (label = (vala_code_node_unref (label), NULL));
@@ -1356,23 +1412,26 @@ static gboolean vala_switch_section_real_check (ValaCodeNode* base, ValaSemantic
 		(_label_it == NULL) ? NULL : (_label_it = (gee_collection_object_unref (_label_it), NULL));
 	}
 	vala_symbol_set_owner ((ValaSymbol*) self, vala_symbol_get_scope (vala_semantic_analyzer_get_current_symbol (analyzer)));
+	_tmp2_ = NULL;
+	old_symbol = (_tmp2_ = vala_semantic_analyzer_get_current_symbol (analyzer), (_tmp2_ == NULL) ? NULL : vala_code_node_ref (_tmp2_));
 	_tmp3_ = NULL;
-	old_symbol = (_tmp3_ = vala_semantic_analyzer_get_current_symbol (analyzer), (_tmp3_ == NULL) ? NULL : vala_code_node_ref (_tmp3_));
-	_tmp4_ = NULL;
-	old_insert_block = (_tmp4_ = analyzer->insert_block, (_tmp4_ == NULL) ? NULL : vala_code_node_ref (_tmp4_));
+	old_insert_block = (_tmp3_ = analyzer->insert_block, (_tmp3_ == NULL) ? NULL : vala_code_node_ref (_tmp3_));
 	vala_semantic_analyzer_set_current_symbol (analyzer, (ValaSymbol*) self);
-	_tmp6_ = NULL;
 	_tmp5_ = NULL;
-	analyzer->insert_block = (_tmp6_ = (_tmp5_ = (ValaBlock*) self, (_tmp5_ == NULL) ? NULL : vala_code_node_ref (_tmp5_)), (analyzer->insert_block == NULL) ? NULL : (analyzer->insert_block = (vala_code_node_unref (analyzer->insert_block), NULL)), _tmp6_);
+	_tmp4_ = NULL;
+	analyzer->insert_block = (_tmp5_ = (_tmp4_ = (ValaBlock*) self, (_tmp4_ == NULL) ? NULL : vala_code_node_ref (_tmp4_)), (analyzer->insert_block == NULL) ? NULL : (analyzer->insert_block = (vala_code_node_unref (analyzer->insert_block), NULL)), _tmp5_);
 	{
-		GeeList* _tmp7_;
-		GeeIterator* _tmp8_;
+		GeeList* _tmp6_;
+		GeeIterator* _tmp7_;
 		GeeIterator* _st_it;
+		_tmp6_ = NULL;
 		_tmp7_ = NULL;
-		_tmp8_ = NULL;
-		_st_it = (_tmp8_ = gee_iterable_iterator ((GeeIterable*) (_tmp7_ = vala_block_get_statements ((ValaBlock*) self))), (_tmp7_ == NULL) ? NULL : (_tmp7_ = (gee_collection_object_unref (_tmp7_), NULL)), _tmp8_);
-		while (gee_iterator_next (_st_it)) {
+		_st_it = (_tmp7_ = gee_iterable_iterator ((GeeIterable*) (_tmp6_ = vala_block_get_statements ((ValaBlock*) self))), (_tmp6_ == NULL) ? NULL : (_tmp6_ = (gee_collection_object_unref (_tmp6_), NULL)), _tmp7_);
+		while (TRUE) {
 			ValaStatement* st;
+			if (!gee_iterator_next (_st_it)) {
+				break;
+			}
 			st = (ValaStatement*) gee_iterator_get (_st_it);
 			vala_code_node_check ((ValaCodeNode*) st, analyzer);
 			(st == NULL) ? NULL : (st = (vala_code_node_unref (st), NULL));
@@ -1380,14 +1439,17 @@ static gboolean vala_switch_section_real_check (ValaCodeNode* base, ValaSemantic
 		(_st_it == NULL) ? NULL : (_st_it = (gee_collection_object_unref (_st_it), NULL));
 	}
 	{
-		GeeList* _tmp9_;
-		GeeIterator* _tmp10_;
+		GeeList* _tmp8_;
+		GeeIterator* _tmp9_;
 		GeeIterator* _local_it;
+		_tmp8_ = NULL;
 		_tmp9_ = NULL;
-		_tmp10_ = NULL;
-		_local_it = (_tmp10_ = gee_iterable_iterator ((GeeIterable*) (_tmp9_ = vala_block_get_local_variables ((ValaBlock*) self))), (_tmp9_ == NULL) ? NULL : (_tmp9_ = (gee_collection_object_unref (_tmp9_), NULL)), _tmp10_);
-		while (gee_iterator_next (_local_it)) {
+		_local_it = (_tmp9_ = gee_iterable_iterator ((GeeIterable*) (_tmp8_ = vala_block_get_local_variables ((ValaBlock*) self))), (_tmp8_ == NULL) ? NULL : (_tmp8_ = (gee_collection_object_unref (_tmp8_), NULL)), _tmp9_);
+		while (TRUE) {
 			ValaLocalVariable* local;
+			if (!gee_iterator_next (_local_it)) {
+				break;
+			}
 			local = (ValaLocalVariable*) gee_iterator_get (_local_it);
 			vala_symbol_set_active ((ValaSymbol*) local, FALSE);
 			(local == NULL) ? NULL : (local = (vala_code_node_unref (local), NULL));
@@ -1395,10 +1457,13 @@ static gboolean vala_switch_section_real_check (ValaCodeNode* base, ValaSemantic
 		(_local_it == NULL) ? NULL : (_local_it = (gee_collection_object_unref (_local_it), NULL));
 	}
 	vala_semantic_analyzer_set_current_symbol (analyzer, old_symbol);
-	_tmp12_ = NULL;
 	_tmp11_ = NULL;
-	analyzer->insert_block = (_tmp12_ = (_tmp11_ = old_insert_block, (_tmp11_ == NULL) ? NULL : vala_code_node_ref (_tmp11_)), (analyzer->insert_block == NULL) ? NULL : (analyzer->insert_block = (vala_code_node_unref (analyzer->insert_block), NULL)), _tmp12_);
-	return (_tmp13_ = !vala_code_node_get_error ((ValaCodeNode*) self), (old_symbol == NULL) ? NULL : (old_symbol = (vala_code_node_unref (old_symbol), NULL)), (old_insert_block == NULL) ? NULL : (old_insert_block = (vala_code_node_unref (old_insert_block), NULL)), _tmp13_);
+	_tmp10_ = NULL;
+	analyzer->insert_block = (_tmp11_ = (_tmp10_ = old_insert_block, (_tmp10_ == NULL) ? NULL : vala_code_node_ref (_tmp10_)), (analyzer->insert_block == NULL) ? NULL : (analyzer->insert_block = (vala_code_node_unref (analyzer->insert_block), NULL)), _tmp11_);
+	result = !vala_code_node_get_error ((ValaCodeNode*) self);
+	(old_symbol == NULL) ? NULL : (old_symbol = (vala_code_node_unref (old_symbol), NULL));
+	(old_insert_block == NULL) ? NULL : (old_insert_block = (vala_code_node_unref (old_insert_block), NULL));
+	return result;
 }
 
 
