@@ -131,6 +131,88 @@ typedef struct _ValaScopeClass ValaScopeClass;
 typedef struct _ValaSourceReference ValaSourceReference;
 typedef struct _ValaSourceReferenceClass ValaSourceReferenceClass;
 
+#define VALA_TYPE_MEMBER (vala_member_get_type ())
+#define VALA_MEMBER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_MEMBER, ValaMember))
+#define VALA_MEMBER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_MEMBER, ValaMemberClass))
+#define VALA_IS_MEMBER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_MEMBER))
+#define VALA_IS_MEMBER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_MEMBER))
+#define VALA_MEMBER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_MEMBER, ValaMemberClass))
+
+typedef struct _ValaMember ValaMember;
+typedef struct _ValaMemberClass ValaMemberClass;
+
+#define VALA_TYPE_FIELD (vala_field_get_type ())
+#define VALA_FIELD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_FIELD, ValaField))
+#define VALA_FIELD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_FIELD, ValaFieldClass))
+#define VALA_IS_FIELD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_FIELD))
+#define VALA_IS_FIELD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_FIELD))
+#define VALA_FIELD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_FIELD, ValaFieldClass))
+
+typedef struct _ValaField ValaField;
+typedef struct _ValaFieldClass ValaFieldClass;
+
+#define TYPE_MEMBER_BINDING (member_binding_get_type ())
+
+#define VALA_TYPE_METHOD (vala_method_get_type ())
+#define VALA_METHOD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_METHOD, ValaMethod))
+#define VALA_METHOD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_METHOD, ValaMethodClass))
+#define VALA_IS_METHOD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_METHOD))
+#define VALA_IS_METHOD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_METHOD))
+#define VALA_METHOD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_METHOD, ValaMethodClass))
+
+typedef struct _ValaMethod ValaMethod;
+typedef struct _ValaMethodClass ValaMethodClass;
+
+#define VALA_TYPE_CREATION_METHOD (vala_creation_method_get_type ())
+#define VALA_CREATION_METHOD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_CREATION_METHOD, ValaCreationMethod))
+#define VALA_CREATION_METHOD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_CREATION_METHOD, ValaCreationMethodClass))
+#define VALA_IS_CREATION_METHOD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_CREATION_METHOD))
+#define VALA_IS_CREATION_METHOD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_CREATION_METHOD))
+#define VALA_CREATION_METHOD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_CREATION_METHOD, ValaCreationMethodClass))
+
+typedef struct _ValaCreationMethod ValaCreationMethod;
+typedef struct _ValaCreationMethodClass ValaCreationMethodClass;
+
+#define VALA_TYPE_PROPERTY (vala_property_get_type ())
+#define VALA_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_PROPERTY, ValaProperty))
+#define VALA_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_PROPERTY, ValaPropertyClass))
+#define VALA_IS_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_PROPERTY))
+#define VALA_IS_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_PROPERTY))
+#define VALA_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_PROPERTY, ValaPropertyClass))
+
+typedef struct _ValaProperty ValaProperty;
+typedef struct _ValaPropertyClass ValaPropertyClass;
+
+#define VALA_TYPE_ENUM_VALUE (vala_enum_value_get_type ())
+#define VALA_ENUM_VALUE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_ENUM_VALUE, ValaEnumValue))
+#define VALA_ENUM_VALUE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_ENUM_VALUE, ValaEnumValueClass))
+#define VALA_IS_ENUM_VALUE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_ENUM_VALUE))
+#define VALA_IS_ENUM_VALUE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_ENUM_VALUE))
+#define VALA_ENUM_VALUE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_ENUM_VALUE, ValaEnumValueClass))
+
+typedef struct _ValaEnumValue ValaEnumValue;
+typedef struct _ValaEnumValueClass ValaEnumValueClass;
+
+#define VALA_TYPE_TYPESYMBOL (vala_typesymbol_get_type ())
+#define VALA_TYPESYMBOL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_TYPESYMBOL, ValaTypeSymbol))
+#define VALA_TYPESYMBOL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_TYPESYMBOL, ValaTypeSymbolClass))
+#define VALA_IS_TYPESYMBOL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_TYPESYMBOL))
+#define VALA_IS_TYPESYMBOL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_TYPESYMBOL))
+#define VALA_TYPESYMBOL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_TYPESYMBOL, ValaTypeSymbolClass))
+
+typedef struct _ValaTypeSymbol ValaTypeSymbol;
+typedef struct _ValaTypeSymbolClass ValaTypeSymbolClass;
+
+#define VALA_TYPE_ERROR_CODE (vala_error_code_get_type ())
+#define VALA_ERROR_CODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_ERROR_CODE, ValaErrorCode))
+#define VALA_ERROR_CODE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_ERROR_CODE, ValaErrorCodeClass))
+#define VALA_IS_ERROR_CODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_ERROR_CODE))
+#define VALA_IS_ERROR_CODE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_ERROR_CODE))
+#define VALA_ERROR_CODE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_ERROR_CODE, ValaErrorCodeClass))
+
+typedef struct _ValaErrorCode ValaErrorCode;
+typedef struct _ValaErrorCodeClass ValaErrorCodeClass;
+
 #define VALA_TYPE_SOURCE_FILE (vala_source_file_get_type ())
 #define VALA_SOURCE_FILE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SOURCE_FILE, ValaSourceFile))
 #define VALA_SOURCE_FILE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_SOURCE_FILE, ValaSourceFileClass))
@@ -181,6 +263,8 @@ struct _ValaSymbolClass {
 	char* (*get_lower_case_cname) (ValaSymbol* self, const char* infix);
 	char* (*get_lower_case_cprefix) (ValaSymbol* self);
 	GeeList* (*get_cheader_filenames) (ValaSymbol* self);
+	gboolean (*is_instance_member) (ValaSymbol* self);
+	gboolean (*is_class_member) (ValaSymbol* self);
 };
 
 typedef enum  {
@@ -200,8 +284,15 @@ struct _ValaSymbolPrivate {
 	ValaScope* _scope;
 };
 
+typedef enum  {
+	MEMBER_BINDING_INSTANCE,
+	MEMBER_BINDING_CLASS,
+	MEMBER_BINDING_STATIC
+} MemberBinding;
 
 
+static gpointer vala_symbol_parent_class = NULL;
+
 gpointer vala_code_node_ref (gpointer instance);
 void vala_code_node_unref (gpointer instance);
 GParamSpec* vala_param_spec_code_node (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
@@ -249,7 +340,6 @@ ValaScope* vala_scope_new (ValaSymbol* owner);
 ValaScope* vala_scope_construct (GType object_type, ValaSymbol* owner);
 ValaSymbol* vala_symbol_new (const char* name, ValaSourceReference* source_reference);
 ValaSymbol* vala_symbol_construct (GType object_type, const char* name, ValaSourceReference* source_reference);
-ValaSymbol* vala_symbol_new (const char* name, ValaSourceReference* source_reference);
 const char* vala_symbol_get_name (ValaSymbol* self);
 char* vala_symbol_get_full_name (ValaSymbol* self);
 char* vala_symbol_get_cprefix (ValaSymbol* self);
@@ -265,6 +355,22 @@ char* vala_symbol_lower_case_to_camel_case (const char* lower_case);
 ValaScope* vala_symbol_get_owner (ValaSymbol* self);
 ValaScope* vala_symbol_get_scope (ValaSymbol* self);
 ValaScope* vala_symbol_get_top_accessible_scope (ValaSymbol* self, gboolean is_internal);
+GType vala_member_get_type (void);
+GType vala_field_get_type (void);
+GType member_binding_get_type (void);
+MemberBinding vala_field_get_binding (ValaField* self);
+GType vala_method_get_type (void);
+GType vala_creation_method_get_type (void);
+MemberBinding vala_method_get_binding (ValaMethod* self);
+GType vala_property_get_type (void);
+MemberBinding vala_property_get_binding (ValaProperty* self);
+GType vala_enum_value_get_type (void);
+GType vala_typesymbol_get_type (void);
+GType vala_error_code_get_type (void);
+gboolean vala_symbol_is_instance_member (ValaSymbol* self);
+static gboolean vala_symbol_real_is_instance_member (ValaSymbol* self);
+gboolean vala_symbol_is_class_member (ValaSymbol* self);
+static gboolean vala_symbol_real_is_class_member (ValaSymbol* self);
 ValaSymbol* vala_scope_get_owner (ValaScope* self);
 void vala_scope_set_parent_scope (ValaScope* self, ValaScope* value);
 void vala_symbol_set_owner (ValaSymbol* self, ValaScope* value);
@@ -283,7 +389,6 @@ gpointer vala_value_get_source_file (const GValue* value);
 GType vala_source_file_get_type (void);
 ValaSourceFile* vala_source_reference_get_file (ValaSourceReference* self);
 gboolean vala_source_file_get_external_package (ValaSourceFile* self);
-static gpointer vala_symbol_parent_class = NULL;
 static void vala_symbol_finalize (ValaCodeNode* obj);
 
 
@@ -294,6 +399,7 @@ static void vala_symbol_finalize (ValaCodeNode* obj);
  * and checking their accessibility.
  */
 gboolean vala_symbol_is_internal_symbol (ValaSymbol* self) {
+	gboolean result;
 	gboolean _tmp0_;
 	g_return_val_if_fail (self != NULL, FALSE);
 	_tmp0_ = FALSE;
@@ -304,37 +410,52 @@ gboolean vala_symbol_is_internal_symbol (ValaSymbol* self) {
 	}
 	if (_tmp0_) {
 		/* non-external symbols in VAPI files are internal symbols*/
-		return TRUE;
+		result = TRUE;
+		return result;
 	}
 	{
-		ValaSymbol* _tmp2_;
+		ValaSymbol* _tmp1_;
 		ValaSymbol* sym;
-		ValaSymbol* _tmp4_;
-		ValaSymbol* _tmp3_;
-		_tmp2_ = NULL;
-		sym = (_tmp2_ = self, (_tmp2_ == NULL) ? NULL : vala_code_node_ref (_tmp2_));
-		_tmp4_ = NULL;
-		_tmp3_ = NULL;
-		for (; NULL != sym; sym = (_tmp4_ = (_tmp3_ = vala_symbol_get_parent_symbol (sym), (_tmp3_ == NULL) ? NULL : vala_code_node_ref (_tmp3_)), (sym == NULL) ? NULL : (sym = (vala_code_node_unref (sym), NULL)), _tmp4_)) {
-			gboolean _tmp5_;
-			_tmp5_ = FALSE;
-			if (sym->priv->_access == VALA_SYMBOL_ACCESSIBILITY_PRIVATE) {
-				_tmp5_ = TRUE;
-			} else {
-				_tmp5_ = sym->priv->_access == VALA_SYMBOL_ACCESSIBILITY_INTERNAL;
-			}
-			if (_tmp5_) {
-				gboolean _tmp6_;
-				return (_tmp6_ = TRUE, (sym == NULL) ? NULL : (sym = (vala_code_node_unref (sym), NULL)), _tmp6_);
+		_tmp1_ = NULL;
+		sym = (_tmp1_ = self, (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_));
+		{
+			gboolean _tmp2_;
+			_tmp2_ = TRUE;
+			while (TRUE) {
+				gboolean _tmp5_;
+				if (!_tmp2_) {
+					ValaSymbol* _tmp4_;
+					ValaSymbol* _tmp3_;
+					_tmp4_ = NULL;
+					_tmp3_ = NULL;
+					sym = (_tmp4_ = (_tmp3_ = vala_symbol_get_parent_symbol (sym), (_tmp3_ == NULL) ? NULL : vala_code_node_ref (_tmp3_)), (sym == NULL) ? NULL : (sym = (vala_code_node_unref (sym), NULL)), _tmp4_);
+				}
+				_tmp2_ = FALSE;
+				if (!(NULL != sym)) {
+					break;
+				}
+				_tmp5_ = FALSE;
+				if (sym->priv->_access == VALA_SYMBOL_ACCESSIBILITY_PRIVATE) {
+					_tmp5_ = TRUE;
+				} else {
+					_tmp5_ = sym->priv->_access == VALA_SYMBOL_ACCESSIBILITY_INTERNAL;
+				}
+				if (_tmp5_) {
+					result = TRUE;
+					(sym == NULL) ? NULL : (sym = (vala_code_node_unref (sym), NULL));
+					return result;
+				}
 			}
 		}
 		(sym == NULL) ? NULL : (sym = (vala_code_node_unref (sym), NULL));
 	}
-	return FALSE;
+	result = FALSE;
+	return result;
 }
 
 
 gboolean vala_symbol_is_private_symbol (ValaSymbol* self) {
+	gboolean result;
 	gboolean _tmp0_;
 	g_return_val_if_fail (self != NULL, FALSE);
 	_tmp0_ = FALSE;
@@ -345,26 +466,40 @@ gboolean vala_symbol_is_private_symbol (ValaSymbol* self) {
 	}
 	if (_tmp0_) {
 		/* non-external symbols in VAPI files are private symbols*/
-		return TRUE;
+		result = TRUE;
+		return result;
 	}
 	{
-		ValaSymbol* _tmp2_;
+		ValaSymbol* _tmp1_;
 		ValaSymbol* sym;
-		ValaSymbol* _tmp4_;
-		ValaSymbol* _tmp3_;
-		_tmp2_ = NULL;
-		sym = (_tmp2_ = self, (_tmp2_ == NULL) ? NULL : vala_code_node_ref (_tmp2_));
-		_tmp4_ = NULL;
-		_tmp3_ = NULL;
-		for (; NULL != sym; sym = (_tmp4_ = (_tmp3_ = vala_symbol_get_parent_symbol (sym), (_tmp3_ == NULL) ? NULL : vala_code_node_ref (_tmp3_)), (sym == NULL) ? NULL : (sym = (vala_code_node_unref (sym), NULL)), _tmp4_)) {
-			if (sym->priv->_access == VALA_SYMBOL_ACCESSIBILITY_PRIVATE) {
-				gboolean _tmp5_;
-				return (_tmp5_ = TRUE, (sym == NULL) ? NULL : (sym = (vala_code_node_unref (sym), NULL)), _tmp5_);
+		_tmp1_ = NULL;
+		sym = (_tmp1_ = self, (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_));
+		{
+			gboolean _tmp2_;
+			_tmp2_ = TRUE;
+			while (TRUE) {
+				if (!_tmp2_) {
+					ValaSymbol* _tmp4_;
+					ValaSymbol* _tmp3_;
+					_tmp4_ = NULL;
+					_tmp3_ = NULL;
+					sym = (_tmp4_ = (_tmp3_ = vala_symbol_get_parent_symbol (sym), (_tmp3_ == NULL) ? NULL : vala_code_node_ref (_tmp3_)), (sym == NULL) ? NULL : (sym = (vala_code_node_unref (sym), NULL)), _tmp4_);
+				}
+				_tmp2_ = FALSE;
+				if (!(NULL != sym)) {
+					break;
+				}
+				if (sym->priv->_access == VALA_SYMBOL_ACCESSIBILITY_PRIVATE) {
+					result = TRUE;
+					(sym == NULL) ? NULL : (sym = (vala_code_node_unref (sym), NULL));
+					return result;
+				}
 			}
 		}
 		(sym == NULL) ? NULL : (sym = (vala_code_node_unref (sym), NULL));
 	}
-	return FALSE;
+	result = FALSE;
+	return result;
 }
 
 
@@ -392,28 +527,33 @@ ValaSymbol* vala_symbol_new (const char* name, ValaSourceReference* source_refer
  * @return full name
  */
 char* vala_symbol_get_full_name (ValaSymbol* self) {
-	char* _tmp3_;
-	gboolean _tmp4_;
-	char* _tmp7_;
-	char* _tmp8_;
+	char* result;
+	char* _tmp1_;
+	gboolean _tmp2_;
+	char* _tmp4_;
+	char* _tmp5_;
 	g_return_val_if_fail (self != NULL, NULL);
 	if (vala_symbol_get_parent_symbol (self) == NULL) {
 		const char* _tmp0_;
 		_tmp0_ = NULL;
-		return (_tmp0_ = self->priv->_name, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_));
+		result = (_tmp0_ = self->priv->_name, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_));
+		return result;
 	}
 	if (self->priv->_name == NULL) {
-		return vala_symbol_get_full_name (vala_symbol_get_parent_symbol (self));
+		result = vala_symbol_get_full_name (vala_symbol_get_parent_symbol (self));
+		return result;
 	}
-	_tmp3_ = NULL;
-	if ((_tmp4_ = (_tmp3_ = vala_symbol_get_full_name (vala_symbol_get_parent_symbol (self))) == NULL, _tmp3_ = (g_free (_tmp3_), NULL), _tmp4_)) {
-		const char* _tmp5_;
-		_tmp5_ = NULL;
-		return (_tmp5_ = self->priv->_name, (_tmp5_ == NULL) ? NULL : g_strdup (_tmp5_));
+	_tmp1_ = NULL;
+	if ((_tmp2_ = (_tmp1_ = vala_symbol_get_full_name (vala_symbol_get_parent_symbol (self))) == NULL, _tmp1_ = (g_free (_tmp1_), NULL), _tmp2_)) {
+		const char* _tmp3_;
+		_tmp3_ = NULL;
+		result = (_tmp3_ = self->priv->_name, (_tmp3_ == NULL) ? NULL : g_strdup (_tmp3_));
+		return result;
 	}
-	_tmp7_ = NULL;
-	_tmp8_ = NULL;
-	return (_tmp8_ = g_strdup_printf ("%s.%s", _tmp7_ = vala_symbol_get_full_name (vala_symbol_get_parent_symbol (self)), self->priv->_name), _tmp7_ = (g_free (_tmp7_), NULL), _tmp8_);
+	_tmp4_ = NULL;
+	_tmp5_ = NULL;
+	result = (_tmp5_ = g_strdup_printf ("%s.%s", _tmp4_ = vala_symbol_get_full_name (vala_symbol_get_parent_symbol (self)), self->priv->_name), _tmp4_ = (g_free (_tmp4_), NULL), _tmp5_);
+	return result;
 }
 
 
@@ -424,13 +564,16 @@ char* vala_symbol_get_full_name (ValaSymbol* self) {
  * @return the camel case prefix to be used in C code
  */
 static char* vala_symbol_real_get_cprefix (ValaSymbol* self) {
+	char* result;
 	g_return_val_if_fail (self != NULL, NULL);
 	if (self->priv->_name == NULL) {
-		return g_strdup ("");
+		result = g_strdup ("");
+		return result;
 	} else {
-		const char* _tmp1_;
-		_tmp1_ = NULL;
-		return (_tmp1_ = self->priv->_name, (_tmp1_ == NULL) ? NULL : g_strdup (_tmp1_));
+		const char* _tmp0_;
+		_tmp0_ = NULL;
+		result = (_tmp0_ = self->priv->_name, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_));
+		return result;
 	}
 }
 
@@ -450,8 +593,10 @@ char* vala_symbol_get_cprefix (ValaSymbol* self) {
  * @return      the lower case name to be used in C code
  */
 static char* vala_symbol_real_get_lower_case_cname (ValaSymbol* self, const char* infix) {
+	char* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return NULL;
+	result = NULL;
+	return result;
 }
 
 
@@ -467,8 +612,10 @@ char* vala_symbol_get_lower_case_cname (ValaSymbol* self, const char* infix) {
  * @return      the lower case prefix to be used in C code
  */
 static char* vala_symbol_real_get_lower_case_cprefix (ValaSymbol* self) {
+	char* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return g_strdup ("");
+	result = g_strdup ("");
+	return result;
 }
 
 
@@ -484,8 +631,10 @@ char* vala_symbol_get_lower_case_cprefix (ValaSymbol* self) {
  * @return list of C header filenames for this symbol
  */
 static GeeList* vala_symbol_real_get_cheader_filenames (ValaSymbol* self) {
+	GeeList* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return (GeeList*) gee_array_list_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, g_direct_equal);
+	result = (GeeList*) gee_array_list_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, g_direct_equal);
+	return result;
 }
 
 
@@ -494,6 +643,15 @@ GeeList* vala_symbol_get_cheader_filenames (ValaSymbol* self) {
 }
 
 
+static gboolean string_contains (const char* self, const char* needle) {
+	gboolean result;
+	g_return_val_if_fail (self != NULL, FALSE);
+	g_return_val_if_fail (needle != NULL, FALSE);
+	result = strstr (self, needle) != NULL;
+	return result;
+}
+
+
 /**
  * Converts a string from CamelCase to lower_case.
  *
@@ -501,18 +659,26 @@ GeeList* vala_symbol_get_cheader_filenames (ValaSymbol* self) {
  * @return           the specified string converted to lower case
  */
 char* vala_symbol_camel_case_to_lower_case (const char* camel_case) {
+	char* result;
 	GString* result_builder;
 	const char* i;
 	gboolean first;
 	const char* _tmp4_;
-	char* _tmp5_;
 	g_return_val_if_fail (camel_case != NULL, NULL);
+	if (string_contains (camel_case, "_")) {
+		/* do not insert additional underscores if input is not real camel case*/
+		result = g_utf8_strdown (camel_case, -1);
+		return result;
+	}
 	result_builder = g_string_new ("");
 	i = camel_case;
 	first = TRUE;
-	while (g_utf8_strlen (i, -1) > 0) {
+	while (TRUE) {
 		gunichar c;
 		gboolean _tmp0_;
+		if (!(g_utf8_strlen (i, -1) > 0)) {
+			break;
+		}
 		c = g_utf8_get_char (i);
 		_tmp0_ = FALSE;
 		if (g_unichar_isupper (c)) {
@@ -567,8 +733,10 @@ char* vala_symbol_camel_case_to_lower_case (const char* camel_case) {
 		i = g_utf8_next_char (i);
 	}
 	_tmp4_ = NULL;
-	_tmp5_ = NULL;
-	return (_tmp5_ = (_tmp4_ = result_builder->str, (_tmp4_ == NULL) ? NULL : g_strdup (_tmp4_)), (result_builder == NULL) ? NULL : (result_builder = (g_string_free (result_builder, TRUE), NULL)), _tmp5_);
+	result = (_tmp4_ = result_builder->str, (_tmp4_ == NULL) ? NULL : g_strdup (_tmp4_));
+	(result_builder == NULL) ? NULL : (result_builder = (g_string_free (result_builder, TRUE), NULL));
+	return result;
+	(result_builder == NULL) ? NULL : (result_builder = (g_string_free (result_builder, TRUE), NULL));
 }
 
 
@@ -579,28 +747,31 @@ char* vala_symbol_camel_case_to_lower_case (const char* camel_case) {
  * @return           the specified string converted to camel case
  */
 char* vala_symbol_lower_case_to_camel_case (const char* lower_case) {
+	char* result;
 	GString* result_builder;
 	const char* i;
 	gboolean last_underscore;
-	const char* _tmp2_;
-	char* _tmp3_;
+	const char* _tmp1_;
 	g_return_val_if_fail (lower_case != NULL, NULL);
 	result_builder = g_string_new ("");
 	i = lower_case;
 	last_underscore = TRUE;
-	while (g_utf8_strlen (i, -1) > 0) {
+	while (TRUE) {
 		gunichar c;
+		if (!(g_utf8_strlen (i, -1) > 0)) {
+			break;
+		}
 		c = g_utf8_get_char (i);
 		if (c == '_') {
 			last_underscore = TRUE;
 		} else {
 			if (g_unichar_isupper (c)) {
 				const char* _tmp0_;
-				char* _tmp1_;
 				/* original string is not lower_case, don't apply transformation*/
 				_tmp0_ = NULL;
-				_tmp1_ = NULL;
-				return (_tmp1_ = (_tmp0_ = lower_case, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_)), (result_builder == NULL) ? NULL : (result_builder = (g_string_free (result_builder, TRUE), NULL)), _tmp1_);
+				result = (_tmp0_ = lower_case, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_));
+				(result_builder == NULL) ? NULL : (result_builder = (g_string_free (result_builder, TRUE), NULL));
+				return result;
 			} else {
 				if (last_underscore) {
 					g_string_append_unichar (result_builder, g_unichar_toupper (c));
@@ -612,20 +783,24 @@ char* vala_symbol_lower_case_to_camel_case (const char* lower_case) {
 		}
 		i = g_utf8_next_char (i);
 	}
-	_tmp2_ = NULL;
-	_tmp3_ = NULL;
-	return (_tmp3_ = (_tmp2_ = result_builder->str, (_tmp2_ == NULL) ? NULL : g_strdup (_tmp2_)), (result_builder == NULL) ? NULL : (result_builder = (g_string_free (result_builder, TRUE), NULL)), _tmp3_);
+	_tmp1_ = NULL;
+	result = (_tmp1_ = result_builder->str, (_tmp1_ == NULL) ? NULL : g_strdup (_tmp1_));
+	(result_builder == NULL) ? NULL : (result_builder = (g_string_free (result_builder, TRUE), NULL));
+	return result;
+	(result_builder == NULL) ? NULL : (result_builder = (g_string_free (result_builder, TRUE), NULL));
 }
 
 
 /* get the top scope from where this symbol is still accessible*/
 ValaScope* vala_symbol_get_top_accessible_scope (ValaSymbol* self, gboolean is_internal) {
+	ValaScope* result;
 	g_return_val_if_fail (self != NULL, NULL);
 	if (self->priv->_access == VALA_SYMBOL_ACCESSIBILITY_PRIVATE) {
 		ValaScope* _tmp0_;
 		/* private symbols are accessible within the scope where the symbol has been declared*/
 		_tmp0_ = NULL;
-		return (_tmp0_ = vala_symbol_get_owner (self), (_tmp0_ == NULL) ? NULL : vala_scope_ref (_tmp0_));
+		result = (_tmp0_ = vala_symbol_get_owner (self), (_tmp0_ == NULL) ? NULL : vala_scope_ref (_tmp0_));
+		return result;
 	}
 	if (self->priv->_access == VALA_SYMBOL_ACCESSIBILITY_INTERNAL) {
 		is_internal = TRUE;
@@ -633,34 +808,144 @@ ValaScope* vala_symbol_get_top_accessible_scope (ValaSymbol* self, gboolean is_i
 	if (vala_symbol_get_parent_symbol (self) == NULL) {
 		/* this is the root symbol*/
 		if (is_internal) {
-			ValaScope* _tmp2_;
+			ValaScope* _tmp1_;
 			/* only accessible within the same library
 			 return root scope*/
-			_tmp2_ = NULL;
-			return (_tmp2_ = vala_symbol_get_scope (self), (_tmp2_ == NULL) ? NULL : vala_scope_ref (_tmp2_));
+			_tmp1_ = NULL;
+			result = (_tmp1_ = vala_symbol_get_scope (self), (_tmp1_ == NULL) ? NULL : vala_scope_ref (_tmp1_));
+			return result;
 		} else {
 			/* unlimited access*/
-			return NULL;
+			result = NULL;
+			return result;
 		}
 	}
 	/* if this is a public symbol, it's equally accessible as the parent symbol*/
-	return vala_symbol_get_top_accessible_scope (vala_symbol_get_parent_symbol (self), is_internal);
+	result = vala_symbol_get_top_accessible_scope (vala_symbol_get_parent_symbol (self), is_internal);
+	return result;
+}
+
+
+static gboolean vala_symbol_real_is_instance_member (ValaSymbol* self) {
+	gboolean result;
+	gboolean instance;
+	g_return_val_if_fail (self != NULL, FALSE);
+	instance = TRUE;
+	if (VALA_IS_FIELD (self)) {
+		ValaField* _tmp0_;
+		ValaField* f;
+		_tmp0_ = NULL;
+		f = (_tmp0_ = VALA_FIELD (self), (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_));
+		instance = vala_field_get_binding (f) == MEMBER_BINDING_INSTANCE;
+		(f == NULL) ? NULL : (f = (vala_code_node_unref (f), NULL));
+	} else {
+		if (VALA_IS_METHOD (self)) {
+			ValaMethod* _tmp1_;
+			ValaMethod* m;
+			_tmp1_ = NULL;
+			m = (_tmp1_ = VALA_METHOD (self), (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_));
+			if (!VALA_IS_CREATION_METHOD (m)) {
+				instance = vala_method_get_binding (m) == MEMBER_BINDING_INSTANCE;
+			}
+			(m == NULL) ? NULL : (m = (vala_code_node_unref (m), NULL));
+		} else {
+			if (VALA_IS_PROPERTY (self)) {
+				ValaProperty* _tmp2_;
+				ValaProperty* prop;
+				_tmp2_ = NULL;
+				prop = (_tmp2_ = VALA_PROPERTY (self), (_tmp2_ == NULL) ? NULL : vala_code_node_ref (_tmp2_));
+				instance = vala_property_get_binding (prop) == MEMBER_BINDING_INSTANCE;
+				(prop == NULL) ? NULL : (prop = (vala_code_node_unref (prop), NULL));
+			} else {
+				if (VALA_IS_ENUM_VALUE (self)) {
+					instance = FALSE;
+				} else {
+					if (VALA_IS_ERROR_CODE (self)) {
+						instance = FALSE;
+					}
+				}
+			}
+		}
+	}
+	result = instance;
+	return result;
+}
+
+
+gboolean vala_symbol_is_instance_member (ValaSymbol* self) {
+	return VALA_SYMBOL_GET_CLASS (self)->is_instance_member (self);
+}
+
+
+static gboolean vala_symbol_real_is_class_member (ValaSymbol* self) {
+	gboolean result;
+	gboolean isclass;
+	g_return_val_if_fail (self != NULL, FALSE);
+	isclass = TRUE;
+	if (VALA_IS_FIELD (self)) {
+		ValaField* _tmp0_;
+		ValaField* f;
+		_tmp0_ = NULL;
+		f = (_tmp0_ = VALA_FIELD (self), (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_));
+		isclass = vala_field_get_binding (f) == MEMBER_BINDING_CLASS;
+		(f == NULL) ? NULL : (f = (vala_code_node_unref (f), NULL));
+	} else {
+		if (VALA_IS_METHOD (self)) {
+			ValaMethod* _tmp1_;
+			ValaMethod* m;
+			_tmp1_ = NULL;
+			m = (_tmp1_ = VALA_METHOD (self), (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_));
+			if (!VALA_IS_CREATION_METHOD (m)) {
+				isclass = vala_method_get_binding (m) == MEMBER_BINDING_CLASS;
+			}
+			(m == NULL) ? NULL : (m = (vala_code_node_unref (m), NULL));
+		} else {
+			if (VALA_IS_PROPERTY (self)) {
+				ValaProperty* _tmp2_;
+				ValaProperty* prop;
+				_tmp2_ = NULL;
+				prop = (_tmp2_ = VALA_PROPERTY (self), (_tmp2_ == NULL) ? NULL : vala_code_node_ref (_tmp2_));
+				isclass = vala_property_get_binding (prop) == MEMBER_BINDING_CLASS;
+				(prop == NULL) ? NULL : (prop = (vala_code_node_unref (prop), NULL));
+			} else {
+				if (VALA_IS_ENUM_VALUE (self)) {
+					isclass = FALSE;
+				} else {
+					if (VALA_IS_ERROR_CODE (self)) {
+						isclass = FALSE;
+					}
+				}
+			}
+		}
+	}
+	result = isclass;
+	return result;
+}
+
+
+gboolean vala_symbol_is_class_member (ValaSymbol* self) {
+	return VALA_SYMBOL_GET_CLASS (self)->is_class_member (self);
 }
 
 
 ValaSymbol* vala_symbol_get_parent_symbol (ValaSymbol* self) {
+	ValaSymbol* result;
 	g_return_val_if_fail (self != NULL, NULL);
 	if (vala_symbol_get_owner (self) == NULL) {
-		return NULL;
+		result = NULL;
+		return result;
 	} else {
-		return vala_scope_get_owner (vala_symbol_get_owner (self));
+		result = vala_scope_get_owner (vala_symbol_get_owner (self));
+		return result;
 	}
 }
 
 
 ValaScope* vala_symbol_get_owner (ValaSymbol* self) {
+	ValaScope* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_owner;
+	result = self->priv->_owner;
+	return result;
 }
 
 
@@ -672,24 +957,28 @@ void vala_symbol_set_owner (ValaSymbol* self, ValaScope* value) {
 
 
 const char* vala_symbol_get_name (ValaSymbol* self) {
+	const char* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_name;
+	result = self->priv->_name;
+	return result;
 }
 
 
 void vala_symbol_set_name (ValaSymbol* self, const char* value) {
-	char* _tmp2_;
-	const char* _tmp1_;
+	char* _tmp1_;
+	const char* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2_ = NULL;
 	_tmp1_ = NULL;
-	self->priv->_name = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : g_strdup (_tmp1_)), self->priv->_name = (g_free (self->priv->_name), NULL), _tmp2_);
+	_tmp0_ = NULL;
+	self->priv->_name = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_)), self->priv->_name = (g_free (self->priv->_name), NULL), _tmp1_);
 }
 
 
 gboolean vala_symbol_get_active (ValaSymbol* self) {
+	gboolean result;
 	g_return_val_if_fail (self != NULL, FALSE);
-	return self->priv->_active;
+	result = self->priv->_active;
+	return result;
 }
 
 
@@ -700,8 +989,10 @@ void vala_symbol_set_active (ValaSymbol* self, gboolean value) {
 
 
 gboolean vala_symbol_get_used (ValaSymbol* self) {
+	gboolean result;
 	g_return_val_if_fail (self != NULL, FALSE);
-	return self->priv->_used;
+	result = self->priv->_used;
+	return result;
 }
 
 
@@ -712,8 +1003,10 @@ void vala_symbol_set_used (ValaSymbol* self, gboolean value) {
 
 
 ValaSymbolAccessibility vala_symbol_get_access (ValaSymbol* self) {
+	ValaSymbolAccessibility result;
 	g_return_val_if_fail (self != NULL, 0);
-	return self->priv->_access;
+	result = self->priv->_access;
+	return result;
 }
 
 
@@ -724,14 +1017,18 @@ void vala_symbol_set_access (ValaSymbol* self, ValaSymbolAccessibility value) {
 
 
 ValaScope* vala_symbol_get_scope (ValaSymbol* self) {
+	ValaScope* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_scope;
+	result = self->priv->_scope;
+	return result;
 }
 
 
 gboolean vala_symbol_get_external (ValaSymbol* self) {
+	gboolean result;
 	g_return_val_if_fail (self != NULL, FALSE);
-	return self->priv->_external;
+	result = self->priv->_external;
+	return result;
 }
 
 
@@ -742,6 +1039,7 @@ void vala_symbol_set_external (ValaSymbol* self, gboolean value) {
 
 
 gboolean vala_symbol_get_external_package (ValaSymbol* self) {
+	gboolean result;
 	gboolean _tmp0_;
 	g_return_val_if_fail (self != NULL, FALSE);
 	_tmp0_ = FALSE;
@@ -750,7 +1048,8 @@ gboolean vala_symbol_get_external_package (ValaSymbol* self) {
 	} else {
 		_tmp0_ = FALSE;
 	}
-	return _tmp0_;
+	result = _tmp0_;
+	return result;
 }
 
 
@@ -762,6 +1061,8 @@ static void vala_symbol_class_init (ValaSymbolClass * klass) {
 	VALA_SYMBOL_CLASS (klass)->get_lower_case_cname = vala_symbol_real_get_lower_case_cname;
 	VALA_SYMBOL_CLASS (klass)->get_lower_case_cprefix = vala_symbol_real_get_lower_case_cprefix;
 	VALA_SYMBOL_CLASS (klass)->get_cheader_filenames = vala_symbol_real_get_cheader_filenames;
+	VALA_SYMBOL_CLASS (klass)->is_instance_member = vala_symbol_real_is_instance_member;
+	VALA_SYMBOL_CLASS (klass)->is_class_member = vala_symbol_real_is_class_member;
 }
 
 
