@@ -181,6 +181,8 @@ struct _ValaSymbolClass {
 	char* (*get_lower_case_cname) (ValaSymbol* self, const char* infix);
 	char* (*get_lower_case_cprefix) (ValaSymbol* self);
 	GeeList* (*get_cheader_filenames) (ValaSymbol* self);
+	gboolean (*is_instance_member) (ValaSymbol* self);
+	gboolean (*is_class_member) (ValaSymbol* self);
 };
 
 /**
@@ -256,7 +258,6 @@ ValaSymbol* vala_symbol_new (const char* name, ValaSourceReference* source_refer
 ValaSymbol* vala_symbol_construct (GType object_type, const char* name, ValaSourceReference* source_reference);
 ValaTypeSymbol* vala_typesymbol_new (const char* name, ValaSourceReference* source_reference);
 ValaTypeSymbol* vala_typesymbol_construct (GType object_type, const char* name, ValaSourceReference* source_reference);
-ValaTypeSymbol* vala_typesymbol_new (const char* name, ValaSourceReference* source_reference);
 char* vala_typesymbol_get_cname (ValaTypeSymbol* self, gboolean const_type);
 static char* vala_typesymbol_real_get_cname (ValaTypeSymbol* self, gboolean const_type);
 gboolean vala_typesymbol_is_reference_type (ValaTypeSymbol* self);
